Class: Aws::IAM::AccessKey

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/access_key.rbs,
lib/aws-sdk-iam/access_key.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(user_name, id, options = {}) ⇒ AccessKey #initialize(options = {}) ⇒ AccessKey

Returns a new instance of AccessKey.

Overloads:

  • #initialize(user_name, id, options = {}) ⇒ AccessKey

    Parameters:

    • user_name (String)
    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ AccessKey

    Options Hash (options):

    • :user_name (required, String)
    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/access_key.rbs', line 13

def initialize: (String user_name, String id, Hash[Symbol, untyped] options) -> void
| (user_name: String, id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#activate(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


access_key.activate()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


41
# File 'sig/access_key.rbs', line 41

def activate: (

#clientClient

Returns:



62
# File 'lib/aws-sdk-iam/access_key.rb', line 62

def client: () -> Client

#create_dateTime

The date when the access key was created.

Returns:

  • (Time)


28
# File 'sig/access_key.rbs', line 28

def create_date: () -> ::Time

#dataTypes::AccessKeyMetadata

Returns the data for this Aws::IAM::AccessKey.

Returns:

Raises:



34
# File 'sig/access_key.rbs', line 34

def data: () -> Types::AccessKeyMetadata

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



37
# File 'sig/access_key.rbs', line 37

def data_loaded?: () -> bool

#deactivate(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


access_key.deactivate()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


46
# File 'sig/access_key.rbs', line 46

def deactivate: (

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


access_key.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


51
# File 'sig/access_key.rbs', line 51

def delete: (

#idString Also known as: access_key_id

Returns:

  • (String)


21
# File 'sig/access_key.rbs', line 21

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


252
253
254
255
256
257
# File 'lib/aws-sdk-iam/access_key.rb', line 252

def identifiers
  {
    user_name: @user_name,
    id: @id
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


68
69
70
71
# File 'lib/aws-sdk-iam/access_key.rb', line 68

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#statusString

The status of the access key. Active means that the key is valid for API calls; Inactive means it is not.

Returns:

  • (String)


25
# File 'sig/access_key.rbs', line 25

def status: () -> ("Active" | "Inactive" | "Expired")

#userUser

Returns:



56
# File 'sig/access_key.rbs', line 56

def user: () -> User

#user_nameString

Returns:

  • (String)


18
# File 'sig/access_key.rbs', line 18

def user_name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/aws-sdk-iam/access_key.rb', line 169

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end