Class: Aws::IAM::AccessKeyPair
- Inherits:
-
Object
- Object
- Aws::IAM::AccessKeyPair
- Extended by:
- Deprecations
- Defined in:
- sig/access_key_pair.rbs,
lib/aws-sdk-iam/access_key_pair.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#create_date ⇒ Time
The date when the access key was created.
- #id ⇒ String (also: #access_key_id)
- #secret ⇒ String (also: #secret_access_key)
-
#status ⇒ String
The status of the access key.
- #user_name ⇒ String
Actions collapse
- #activate(options = {}) ⇒ EmptyStructure
- #deactivate(options = {}) ⇒ EmptyStructure
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::AccessKey
Returns the data for this AccessKeyPair.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ AccessKeyPair
constructor
A new instance of AccessKeyPair.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(user_name, id, secret, options = {}) ⇒ AccessKeyPair #initialize(options = {}) ⇒ AccessKeyPair
Returns a new instance of AccessKeyPair.
13 14 15 |
# File 'sig/access_key_pair.rbs', line 13
def initialize: (String user_name, String id, String secret, Hash[Symbol, untyped] options) -> void
| (user_name: String, id: String, secret: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#activate(options = {}) ⇒ EmptyStructure
45 |
# File 'sig/access_key_pair.rbs', line 45
def activate: (
|
#create_date ⇒ Time
The date when the access key was created.
32 |
# File 'sig/access_key_pair.rbs', line 32
def create_date: () -> ::Time
|
#data ⇒ Types::AccessKey
Returns the data for this Aws::IAM::AccessKeyPair.
38 |
# File 'sig/access_key_pair.rbs', line 38
def data: () -> Types::AccessKey
|
#data_loaded? ⇒ Boolean
41 |
# File 'sig/access_key_pair.rbs', line 41
def data_loaded?: () -> bool
|
#deactivate(options = {}) ⇒ EmptyStructure
50 |
# File 'sig/access_key_pair.rbs', line 50
def deactivate: (
|
#delete(options = {}) ⇒ EmptyStructure
55 |
# File 'sig/access_key_pair.rbs', line 55
def delete: (
|
#id ⇒ String Also known as: access_key_id
21 |
# File 'sig/access_key_pair.rbs', line 21
def id: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-iam/access_key_pair.rb', line 251 def identifiers { user_name: @user_name, id: @id, secret: @secret } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
77 78 79 80 |
# File 'lib/aws-sdk-iam/access_key_pair.rb', line 77 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#secret ⇒ String Also known as: secret_access_key
25 |
# File 'sig/access_key_pair.rbs', line 25
def secret: () -> String
|
#status ⇒ String
The status of the access key. Active means that the key is valid for
API calls, while Inactive means it is not.
29 |
# File 'sig/access_key_pair.rbs', line 29
def status: () -> ("Active" | "Inactive" | "Expired")
|
#user_name ⇒ String
18 |
# File 'sig/access_key_pair.rbs', line 18
def user_name: () -> String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-iam/access_key_pair.rb', line 178 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |