Class: Aws::IAM::CurrentUser
- Inherits:
-
Object
- Object
- Aws::IAM::CurrentUser
- Extended by:
- Deprecations
- Defined in:
- sig/current_user.rbs,
lib/aws-sdk-iam/current_user.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the user.
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the user was created.
-
#password_last_used ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the user's password was last used to sign in to an Amazon Web Services website.
-
#path ⇒ String
The path to the user.
-
#permissions_boundary ⇒ Types::AttachedPermissionsBoundary
For more information about permissions boundaries, see [Permissions boundaries for IAM identities ][1] in the IAM User Guide.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are associated with the user.
-
#user_id ⇒ String
The stable and unique string identifying the user.
-
#user_name ⇒ String
The friendly name identifying the user.
Associations collapse
- #access_keys(options = {}) ⇒ AccessKey::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #mfa_devices(options = {}) ⇒ MfaDevice::Collection
- #signing_certificates(options = {}) ⇒ SigningCertificate::Collection
- #user ⇒ User?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::User
Returns the data for this CurrentUser.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(options = {}) ⇒ CurrentUser
constructor
A new instance of CurrentUser.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current CurrentUser.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(options = {}) ⇒ CurrentUser
Returns a new instance of CurrentUser.
13 |
# File 'sig/current_user.rbs', line 13
def initialize: (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#access_keys(options = {}) ⇒ AccessKey::Collection
53 |
# File 'sig/current_user.rbs', line 53
def access_keys: (
|
#arn ⇒ String
The Amazon Resource Name (ARN) that identifies the user. For more information about ARNs and how to use ARNs in policies, see IAM Identifiers in the IAM User Guide.
25 |
# File 'sig/current_user.rbs', line 25
def arn: () -> ::String
|
#create_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the user was created.
28 |
# File 'sig/current_user.rbs', line 28
def create_date: () -> ::Time
|
#data ⇒ Types::User
Returns the data for this Aws::IAM::CurrentUser. Calls
Aws::IAM::Client#get_user if #data_loaded? is false.
46 |
# File 'sig/current_user.rbs', line 46
def data: () -> Types::User
|
#data_loaded? ⇒ Boolean
49 |
# File 'sig/current_user.rbs', line 49
def data_loaded?: () -> bool
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
407 408 409 |
# File 'lib/aws-sdk-iam/current_user.rb', line 407 def identifiers {} end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::CurrentUser.
Returns self making it possible to chain methods.
current_user.reload.data
42 |
# File 'sig/current_user.rbs', line 42
def load: () -> self
|
#mfa_devices(options = {}) ⇒ MfaDevice::Collection
59 |
# File 'sig/current_user.rbs', line 59
def mfa_devices: (
|
#password_last_used ⇒ Time
The date and time, in ISO 8601 date-time format, when the user's password was last used to sign in to an Amazon Web Services website. For a list of Amazon Web Services websites that capture a user's last sign-in time, see the Credential reports topic in the IAM User Guide. If a password is used more than once in a five-minute span, only the first use is returned in this field. If the field is null (no value), then it indicates that they never signed in with a password. This can be because:
-
The user never had a password.
-
A password exists but has not been used since IAM started tracking this information on October 20, 2014.
A null value does not mean that the user never had a password. Also, if the user does not currently have a password but had one in the past, then this field contains the date and time the most recent password was used.
This value is returned only in the GetUser and ListUsers operations.
31 |
# File 'sig/current_user.rbs', line 31
def password_last_used: () -> ::Time
|
#path ⇒ String
The path to the user. For more information about paths, see IAM identifiers in the IAM User Guide.
The ARN of the policy used to set the permissions boundary for the user.
16 |
# File 'sig/current_user.rbs', line 16
def path: () -> ::String
|
#permissions_boundary ⇒ Types::AttachedPermissionsBoundary
For more information about permissions boundaries, see Permissions boundaries for IAM identities in the IAM User Guide.
34 |
# File 'sig/current_user.rbs', line 34
def permissions_boundary: () -> Types::AttachedPermissionsBoundary
|
#signing_certificates(options = {}) ⇒ SigningCertificate::Collection
65 |
# File 'sig/current_user.rbs', line 65
def signing_certificates: (
|
#tags ⇒ Array<Types::Tag>
A list of tags that are associated with the user. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
37 |
# File 'sig/current_user.rbs', line 37
def tags: () -> ::Array[Types::Tag]
|
#user_id ⇒ String
The stable and unique string identifying the user. For more information about IDs, see IAM identifiers in the IAM User Guide.
22 |
# File 'sig/current_user.rbs', line 22
def user_id: () -> ::String
|
#user_name ⇒ String
The friendly name identifying the user.
19 |
# File 'sig/current_user.rbs', line 19
def user_name: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/aws-sdk-iam/current_user.rb', line 254 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |