Method: Aws::IAM::Group#update

Defined in:
lib/aws-sdk-iam/group.rb

#update(options = {}) ⇒ Group

Examples:

Request syntax with placeholder values


group = group.update({
  new_path: "pathType",
  new_group_name: "groupNameType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :new_path (String)

    New path for the IAM group. Only include this if changing the group’s path.

    This parameter allows (through its [regex pattern][1]) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (‘\u0021`) through the DEL character (`\u007F`), including most punctuation characters, digits, and upper and lowercased letters.

    [1]: wikipedia.org/wiki/regex

  • :new_group_name (String)

    New name for the IAM group. Only include this if changing the group’s name.

    IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both “MyResource” and “myresource”.

Returns:



455
456
457
458
459
460
461
462
463
464
# File 'lib/aws-sdk-iam/group.rb', line 455

def update(options = {})
  options = options.merge(group_name: @name)
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    @client.update_group(options)
  end
  Group.new(
    name: options[:new_group_name],
    client: @client
  )
end