Class: Aws::IAM::GroupPolicy
- Inherits:
-
Object
- Object
- Aws::IAM::GroupPolicy
- Extended by:
- Deprecations
- Defined in:
- sig/group_policy.rbs,
lib/aws-sdk-iam/group_policy.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #group_name ⇒ String
- #name ⇒ String (also: #policy_name)
-
#policy_document ⇒ String
The policy document.
Actions collapse
Associations collapse
- #group ⇒ Group
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::GetGroupPolicyResponse
Returns the data for this GroupPolicy.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ GroupPolicy
constructor
A new instance of GroupPolicy.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current GroupPolicy.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(group_name, name, options = {}) ⇒ GroupPolicy #initialize(options = {}) ⇒ GroupPolicy
Returns a new instance of GroupPolicy.
13 14 15 |
# File 'sig/group_policy.rbs', line 13
def initialize: (String group_name, String name, Hash[Symbol, untyped] options) -> void
| (group_name: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#data ⇒ Types::GetGroupPolicyResponse
Returns the data for this Aws::IAM::GroupPolicy. Calls
Client#get_group_policy if #data_loaded? is false.
34 |
# File 'sig/group_policy.rbs', line 34
def data: () -> Types::GetGroupPolicyResponse
|
#data_loaded? ⇒ Boolean
37 |
# File 'sig/group_policy.rbs', line 37
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
41 |
# File 'sig/group_policy.rbs', line 41
def delete: (
|
#group_name ⇒ String
18 |
# File 'sig/group_policy.rbs', line 18
def group_name: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
267 268 269 270 271 272 |
# File 'lib/aws-sdk-iam/group_policy.rb', line 267 def identifiers { group_name: @group_name, name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::GroupPolicy.
Returns self making it possible to chain methods.
group_policy.reload.data
30 |
# File 'sig/group_policy.rbs', line 30
def load: () -> self
|
#name ⇒ String Also known as: policy_name
21 |
# File 'sig/group_policy.rbs', line 21
def name: () -> String
|
#policy_document ⇒ String
The policy document.
IAM stores policies in JSON format. However, resources that were created using CloudFormation templates can be formatted in YAML. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.
25 |
# File 'sig/group_policy.rbs', line 25
def policy_document: () -> ::String
|
#put(options = {}) ⇒ EmptyStructure
46 |
# File 'sig/group_policy.rbs', line 46
def put: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/aws-sdk-iam/group_policy.rb', line 177 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |