Class: Aws::IAM::MfaDevice

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/mfa_device.rbs,
lib/aws-sdk-iam/mfa_device.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(user_name, serial_number, options = {}) ⇒ MfaDevice #initialize(options = {}) ⇒ MfaDevice

Returns a new instance of MfaDevice.

Overloads:

  • #initialize(user_name, serial_number, options = {}) ⇒ MfaDevice

    Parameters:

    • user_name (String)
    • serial_number (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ MfaDevice

    Options Hash (options):

    • :user_name (required, String)
    • :serial_number (required, String)
    • :client (Client)


13
14
15
# File 'sig/mfa_device.rbs', line 13

def initialize: (String user_name, String serial_number, Hash[Symbol, untyped] options) -> void
| (user_name: String, serial_number: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#associate(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


mfa_device.associate({
  authentication_code_1: "authenticationCodeType", # required
  authentication_code_2: "authenticationCodeType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :authentication_code_1 (required, String)

    An authentication code emitted by the device.

    The format for this parameter is a string of six digits.

    Submit your request immediately after generating the authentication codes. If you generate the codes and then wait too long to submit the request, the MFA device successfully associates with the user but the MFA device becomes out of sync. This happens because time-based one-time passwords (TOTP) expire after a short period of time. If this happens, you can resync the device.

  • :authentication_code_2 (required, String)

    A subsequent authentication code emitted by the device.

    The format for this parameter is a string of six digits.

    Submit your request immediately after generating the authentication codes. If you generate the codes and then wait too long to submit the request, the MFA device successfully associates with the user but the MFA device becomes out of sync. This happens because time-based one-time passwords (TOTP) expire after a short period of time. If this happens, you can resync the device.

Returns:

  • (EmptyStructure)


37
# File 'sig/mfa_device.rbs', line 37

def associate: (

#clientClient

Returns:



54
# File 'lib/aws-sdk-iam/mfa_device.rb', line 54

def client: () -> Client

#dataTypes::MFADevice

Returns the data for this Aws::IAM::MfaDevice.

Returns:

Raises:



30
# File 'sig/mfa_device.rbs', line 30

def data: () -> Types::MFADevice

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



33
# File 'sig/mfa_device.rbs', line 33

def data_loaded?: () -> bool

#disassociate(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


mfa_device.disassociate()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


44
# File 'sig/mfa_device.rbs', line 44

def disassociate: (

#enable_dateTime

The date when the MFA device was enabled for the user.

Returns:

  • (Time)


24
# File 'sig/mfa_device.rbs', line 24

def enable_date: () -> ::Time

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


286
287
288
289
290
291
# File 'lib/aws-sdk-iam/mfa_device.rb', line 286

def identifiers
  {
    user_name: @user_name,
    serial_number: @serial_number
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


60
61
62
63
# File 'lib/aws-sdk-iam/mfa_device.rb', line 60

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#resync(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


mfa_device.resync({
  authentication_code_1: "authenticationCodeType", # required
  authentication_code_2: "authenticationCodeType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :authentication_code_1 (required, String)

    An authentication code emitted by the device.

    The format for this parameter is a sequence of six digits.

  • :authentication_code_2 (required, String)

    A subsequent authentication code emitted by the device.

    The format for this parameter is a sequence of six digits.

Returns:

  • (EmptyStructure)


49
# File 'sig/mfa_device.rbs', line 49

def resync: (

#serial_numberString

Returns:

  • (String)


21
# File 'sig/mfa_device.rbs', line 21

def serial_number: () -> String

#userUser

Returns:



56
# File 'sig/mfa_device.rbs', line 56

def user: () -> User

#user_nameString

Returns:

  • (String)


18
# File 'sig/mfa_device.rbs', line 18

def user_name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/aws-sdk-iam/mfa_device.rb', line 161

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end