Class: Aws::IAM::RolePolicy

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/role_policy.rbs,
lib/aws-sdk-iam/role_policy.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(role_name, name, options = {}) ⇒ RolePolicy #initialize(options = {}) ⇒ RolePolicy

Returns a new instance of RolePolicy.

Overloads:

  • #initialize(role_name, name, options = {}) ⇒ RolePolicy

    Parameters:

    • role_name (String)
    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ RolePolicy

    Options Hash (options):

    • :role_name (required, String)
    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/role_policy.rbs', line 13

def initialize: (String role_name, String name, Hash[Symbol, untyped] options) -> void
| (role_name: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



60
# File 'lib/aws-sdk-iam/role_policy.rb', line 60

def client: () -> Client

#dataTypes::GetRolePolicyResponse

Returns the data for this Aws::IAM::RolePolicy. Calls Client#get_role_policy if #data_loaded? is false.

Returns:



34
# File 'sig/role_policy.rbs', line 34

def data: () -> Types::GetRolePolicyResponse

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



37
# File 'sig/role_policy.rbs', line 37

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


role_policy.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


41
# File 'sig/role_policy.rbs', line 41

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


267
268
269
270
271
272
# File 'lib/aws-sdk-iam/role_policy.rb', line 267

def identifiers
  {
    role_name: @role_name,
    name: @name
  }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::RolePolicy. Returns self making it possible to chain methods.

role_policy.reload.data

Returns:

  • (self)


30
# File 'sig/role_policy.rbs', line 30

def load: () -> self

#nameString Also known as: policy_name

Returns:

  • (String)


21
# File 'sig/role_policy.rbs', line 21

def name: () -> String

#policy_documentString

The policy document.

IAM stores policies in JSON format. However, resources that were created using CloudFormation templates can be formatted in YAML. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.

Returns:

  • (String)


25
# File 'sig/role_policy.rbs', line 25

def policy_document: () -> ::String

#put(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


role_policy.put({
  policy_document: "policyDocumentType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_document (required, String)

    The policy document.

    You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.

    The regex pattern used to validate this parameter is a string of characters consisting of the following:

    • Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range

    • The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)

    • The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)

Returns:

  • (EmptyStructure)


46
# File 'sig/role_policy.rbs', line 46

def put: (

#roleRole

Returns:



52
# File 'sig/role_policy.rbs', line 52

def role: () -> Role

#role_nameString

Returns:

  • (String)


18
# File 'sig/role_policy.rbs', line 18

def role_name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/aws-sdk-iam/role_policy.rb', line 177

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end