Class: Aws::IAM::SamlProvider

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/saml_provider.rbs,
lib/aws-sdk-iam/saml_provider.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(arn, options = {}) ⇒ SamlProvider #initialize(options = {}) ⇒ SamlProvider

Returns a new instance of SamlProvider.

Overloads:

  • #initialize(arn, options = {}) ⇒ SamlProvider

    Parameters:

    • arn (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ SamlProvider

    Options Hash (options):

    • :arn (required, String)
    • :client (Client)


13
14
15
# File 'sig/saml_provider.rbs', line 13

def initialize: (String arn, Hash[Symbol, untyped] options) -> void
| (arn: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#arnString

Returns:

  • (String)


18
# File 'sig/saml_provider.rbs', line 18

def arn: () -> String

#assertion_encryption_modeString

Specifies the encryption setting for the SAML provider.

Returns:

  • (String)


36
# File 'sig/saml_provider.rbs', line 36

def assertion_encryption_mode: () -> ("Required" | "Allowed")

#clientClient

Returns:



89
# File 'lib/aws-sdk-iam/saml_provider.rb', line 89

def client: () -> Client

#create_dateTime

The date and time when the SAML provider was created.

Returns:

  • (Time)


27
# File 'sig/saml_provider.rbs', line 27

def create_date: () -> ::Time

#dataTypes::GetSAMLProviderResponse

Returns the data for this Aws::IAM::SamlProvider. Calls Client#get_saml_provider if #data_loaded? is false.

Returns:



48
# File 'sig/saml_provider.rbs', line 48

def data: () -> Types::GetSAMLProviderResponse

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



51
# File 'sig/saml_provider.rbs', line 51

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


saml_provider.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


55
# File 'sig/saml_provider.rbs', line 55

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


272
273
274
# File 'lib/aws-sdk-iam/saml_provider.rb', line 272

def identifiers
  { arn: @arn }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::SamlProvider. Returns self making it possible to chain methods.

saml_provider.reload.data

Returns:

  • (self)


44
# File 'sig/saml_provider.rbs', line 44

def load: () -> self

#private_key_listArray<Types::SAMLPrivateKey>

The private key metadata for the SAML provider.

Returns:



39
# File 'sig/saml_provider.rbs', line 39

def private_key_list: () -> ::Array[Types::SAMLPrivateKey]

#saml_metadata_documentString

The XML metadata document that includes information about an identity provider.

Returns:

  • (String)


24
# File 'sig/saml_provider.rbs', line 24

def saml_metadata_document: () -> ::String

#saml_provider_uuidString

The unique identifier assigned to the SAML provider.

Returns:

  • (String)


21
# File 'sig/saml_provider.rbs', line 21

def saml_provider_uuid: () -> ::String

#tagsArray<Types::Tag>

A list of tags that are attached to the specified IAM SAML provider. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



33
# File 'sig/saml_provider.rbs', line 33

def tags: () -> ::Array[Types::Tag]

#update(options = {}) ⇒ Types::UpdateSAMLProviderResponse

Examples:

Request syntax with placeholder values


saml_provider.update({
  saml_metadata_document: "SAMLMetadataDocumentType",
  assertion_encryption_mode: "Required", # accepts Required, Allowed
  add_private_key: "privateKeyType",
  remove_private_key: "privateKeyIdType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :saml_metadata_document (String)

    An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your IdP.

  • :assertion_encryption_mode (String)

    Specifies the encryption setting for the SAML provider.

  • :add_private_key (String)

    Specifies the new private key from your external identity provider. The private key must be a .pem file that uses AES-GCM or AES-CBC encryption algorithm to decrypt SAML assertions.

  • :remove_private_key (String)

    The Key ID of the private key to remove.

Returns:



60
# File 'sig/saml_provider.rbs', line 60

def update: (

#valid_untilTime

The expiration date and time for the SAML provider.

Returns:

  • (Time)


30
# File 'sig/saml_provider.rbs', line 30

def valid_until: () -> ::Time

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/aws-sdk-iam/saml_provider.rb', line 203

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end