Class: Aws::IAM::ServerCertificate

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/server_certificate.rbs,
lib/aws-sdk-iam/server_certificate.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ ServerCertificate #initialize(options = {}) ⇒ ServerCertificate

Returns a new instance of ServerCertificate.

Overloads:

  • #initialize(name, options = {}) ⇒ ServerCertificate

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ ServerCertificate

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/server_certificate.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#certificate_bodyString

The contents of the public key certificate.

Returns:

  • (String)


24
# File 'sig/server_certificate.rbs', line 24

def certificate_body: () -> ::String

#certificate_chainString

The contents of the public key certificate chain.

Returns:

  • (String)


27
# File 'sig/server_certificate.rbs', line 27

def certificate_chain: () -> ::String

#clientClient

Returns:



71
# File 'lib/aws-sdk-iam/server_certificate.rb', line 71

def client: () -> Client

#dataTypes::ServerCertificate

Returns the data for this Aws::IAM::ServerCertificate. Calls Client#get_server_certificate if #data_loaded? is false.

Returns:



39
# File 'sig/server_certificate.rbs', line 39

def data: () -> Types::ServerCertificate

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



42
# File 'sig/server_certificate.rbs', line 42

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


server_certificate.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


46
# File 'sig/server_certificate.rbs', line 46

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


267
268
269
# File 'lib/aws-sdk-iam/server_certificate.rb', line 267

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::ServerCertificate. Returns self making it possible to chain methods.

server_certificate.reload.data

Returns:

  • (self)


35
# File 'sig/server_certificate.rbs', line 35

def load: () -> self

#nameString

Returns:

  • (String)


18
# File 'sig/server_certificate.rbs', line 18

def name: () -> String

#server_certificate_metadataTypes::ServerCertificateMetadata

The meta information of the server certificate, such as its name, path, ID, and ARN.



21
# File 'sig/server_certificate.rbs', line 21

def server_certificate_metadata: () -> Types::ServerCertificateMetadata

#tagsArray<Types::Tag>

A list of tags that are attached to the server certificate. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



30
# File 'sig/server_certificate.rbs', line 30

def tags: () -> ::Array[Types::Tag]

#update(options = {}) ⇒ ServerCertificate

Examples:

Request syntax with placeholder values


servercertificate = server_certificate.update({
  new_path: "pathType",
  new_server_certificate_name: "serverCertificateNameType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :new_path (String)

    The new path for the server certificate. Include this only if you are updating the server certificate's path.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

  • :new_server_certificate_name (String)

    The new name for the server certificate. Include this only if you are updating the server certificate's name. The name of the certificate cannot contain any spaces.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:



51
# File 'sig/server_certificate.rbs', line 51

def update: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/aws-sdk-iam/server_certificate.rb', line 185

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end