Class: Aws::IAM::Types::AccessKey

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about an Amazon Web Services access key.

This data type is used as a response element in the

CreateAccessKey][1

and [ListAccessKeys] operations.

<note markdown=“1”> The SecretAccessKey value is returned only in response to [CreateAccessKey]. You can get a secret access key only when you first create an access key; you cannot recover the secret access key later. If you lose a secret access key, you must create a new access key.

</note>

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_CreateAccessKey.html [2]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListAccessKeys.html

Constant Summary collapse

SENSITIVE =
[:secret_access_key]

Instance Attribute Summary collapse

Instance Attribute Details

#access_key_idString

The ID for this access key.



163
164
165
166
167
168
169
170
171
# File 'lib/aws-sdk-iam/types.rb', line 163

class AccessKey < Struct.new(
  :user_name,
  :access_key_id,
  :status,
  :secret_access_key,
  :create_date)
  SENSITIVE = [:secret_access_key]
  include Aws::Structure
end

#create_dateTime

The date when the access key was created.



163
164
165
166
167
168
169
170
171
# File 'lib/aws-sdk-iam/types.rb', line 163

class AccessKey < Struct.new(
  :user_name,
  :access_key_id,
  :status,
  :secret_access_key,
  :create_date)
  SENSITIVE = [:secret_access_key]
  include Aws::Structure
end

#secret_access_keyString

The secret key used to sign requests.



163
164
165
166
167
168
169
170
171
# File 'lib/aws-sdk-iam/types.rb', line 163

class AccessKey < Struct.new(
  :user_name,
  :access_key_id,
  :status,
  :secret_access_key,
  :create_date)
  SENSITIVE = [:secret_access_key]
  include Aws::Structure
end

#statusString

The status of the access key. Active means that the key is valid for API calls, while Inactive means it is not.



163
164
165
166
167
168
169
170
171
# File 'lib/aws-sdk-iam/types.rb', line 163

class AccessKey < Struct.new(
  :user_name,
  :access_key_id,
  :status,
  :secret_access_key,
  :create_date)
  SENSITIVE = [:secret_access_key]
  include Aws::Structure
end

#user_nameString

The name of the IAM user that the access key is associated with.



163
164
165
166
167
168
169
170
171
# File 'lib/aws-sdk-iam/types.rb', line 163

class AccessKey < Struct.new(
  :user_name,
  :access_key_id,
  :status,
  :secret_access_key,
  :create_date)
  SENSITIVE = [:secret_access_key]
  include Aws::Structure
end