Class: Aws::IAM::Types::AccountNotManagementOrDelegatedAdministratorException

Inherits:
EmptyStructure
  • Object
show all
Defined in:
lib/aws-sdk-iam/types.rb

Overview

The request was rejected because the account making the request is not the management account or delegated administrator account for centralized root access.