Class: Aws::IAM::Types::AcquireRoleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#replacement_valuesHash<String,Types::ReplacementValueEntry>

A map of values to substitute for the parameters that are defined in the role template version. Each key is a parameter name from the template, and each value is a structure that contains the replacement values for that parameter.

Returns:



321
322
323
324
325
326
327
# File 'lib/aws-sdk-iam/types.rb', line 321

class AcquireRoleRequest < Struct.new(
  :template_arn,
  :template_minor_version,
  :replacement_values)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The Amazon Resource Name (ARN) of the role template to create the role from.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


321
322
323
324
325
326
327
# File 'lib/aws-sdk-iam/types.rb', line 321

class AcquireRoleRequest < Struct.new(
  :template_arn,
  :template_minor_version,
  :replacement_values)
  SENSITIVE = []
  include Aws::Structure
end

#template_minor_versionInteger

The minor version of the role template to use. If you do not specify a minor version, the service uses the template's default minor version.

Returns:

  • (Integer)


321
322
323
324
325
326
327
# File 'lib/aws-sdk-iam/types.rb', line 321

class AcquireRoleRequest < Struct.new(
  :template_arn,
  :template_minor_version,
  :replacement_values)
  SENSITIVE = []
  include Aws::Structure
end