Class: Aws::IAM::Types::ContextEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ContextEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about a condition context key. It includes the name of the key and specifies the value (or values, if the context key supports multiple values) to use in the simulation. This information is used when evaluating the ‘Condition` elements of the input policies.
This data type is used as an input parameter to
- SimulateCustomPolicy][1
-
and [SimulatePrincipalPolicy].
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_SimulateCustomPolicy.html [2]: docs.aws.amazon.com/IAM/latest/APIReference/API_SimulatePrincipalPolicy.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_key_name ⇒ String
The full name of a condition context key, including the service prefix.
-
#context_key_type ⇒ String
The data type of the value (or values) specified in the ‘ContextKeyValues` parameter.
-
#context_key_values ⇒ Array<String>
The value (or values, if the condition context key supports multiple values) to provide to the simulation when the key is referenced by a ‘Condition` element in an input policy.
Instance Attribute Details
#context_key_name ⇒ String
The full name of a condition context key, including the service prefix. For example, ‘aws:SourceIp` or `s3:VersionId`.
665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-iam/types.rb', line 665 class ContextEntry < Struct.new( :context_key_name, :context_key_values, :context_key_type) SENSITIVE = [] include Aws::Structure end |
#context_key_type ⇒ String
The data type of the value (or values) specified in the ‘ContextKeyValues` parameter.
665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-iam/types.rb', line 665 class ContextEntry < Struct.new( :context_key_name, :context_key_values, :context_key_type) SENSITIVE = [] include Aws::Structure end |
#context_key_values ⇒ Array<String>
The value (or values, if the condition context key supports multiple values) to provide to the simulation when the key is referenced by a ‘Condition` element in an input policy.
665 666 667 668 669 670 671 |
# File 'lib/aws-sdk-iam/types.rb', line 665 class ContextEntry < Struct.new( :context_key_name, :context_key_values, :context_key_type) SENSITIVE = [] include Aws::Structure end |