Class: Aws::IAM::Types::CreateServiceLinkedRoleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::CreateServiceLinkedRoleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role ⇒ Types::Role
A [Role][1] object that contains details about the newly created role.
Instance Attribute Details
#role ⇒ Types::Role
A Role object that contains details about the newly created role.
1785 1786 1787 1788 1789 |
# File 'lib/aws-sdk-iam/types.rb', line 1785 class CreateServiceLinkedRoleResponse < Struct.new( :role) SENSITIVE = [] include Aws::Structure end |