Class: Aws::IAM::Types::CreateServiceSpecificCredentialRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::CreateServiceSpecificCredentialRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_age_days ⇒ Integer
The number of days until the service specific credential expires.
-
#service_name ⇒ String
The name of the Amazon Web Services service that is to be associated with the credentials.
-
#user_name ⇒ String
The name of the IAM user that is to be associated with the credentials.
Instance Attribute Details
#credential_age_days ⇒ Integer
The number of days until the service specific credential expires. This field is only valid for services that support long-term API keys and must be a positive integer. When not specified, the credential will not expire.
To see which services support long-term API keys, refer to API keys for Amazon Web Services services in the IAM User Guide.
1829 1830 1831 1832 1833 1834 1835 |
# File 'lib/aws-sdk-iam/types.rb', line 1829 class CreateServiceSpecificCredentialRequest < Struct.new( :user_name, :service_name, :credential_age_days) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the Amazon Web Services service that is to be associated with the credentials. The service you specify here is the only service that can be accessed using these credentials.
1829 1830 1831 1832 1833 1834 1835 |
# File 'lib/aws-sdk-iam/types.rb', line 1829 class CreateServiceSpecificCredentialRequest < Struct.new( :user_name, :service_name, :credential_age_days) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the IAM user that is to be associated with the credentials. The new service-specific credentials have the same permissions as the associated user except that they can be used only to access the specified service.
This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
1829 1830 1831 1832 1833 1834 1835 |
# File 'lib/aws-sdk-iam/types.rb', line 1829 class CreateServiceSpecificCredentialRequest < Struct.new( :user_name, :service_name, :credential_age_days) SENSITIVE = [] include Aws::Structure end |