Method: Aws::IAM::Types::CreateUserRequest#permissions_boundary
- Defined in:
- lib/aws-sdk-iam/types.rb
#permissions_boundary ⇒ String
The ARN of the managed policy that is used to set the permissions boundary for the user.
A permissions boundary policy defines the maximum permissions that identity-based policies can grant to an entity, but does not grant permissions. Permissions boundaries do not define the maximum permissions that a resource-based policy can grant to an entity. To learn more, see [Permissions boundaries for IAM entities] in the *IAM User Guide*.
For more information about policy types, see [Policy types ][2] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#access_policy-types
1864 1865 1866 1867 1868 1869 1870 1871 |
# File 'lib/aws-sdk-iam/types.rb', line 1864 class CreateUserRequest < Struct.new( :path, :user_name, :permissions_boundary, :tags) SENSITIVE = [] include Aws::Structure end |