Method: Aws::IAM::Types::CreateUserRequest#user_name
- Defined in:
- lib/aws-sdk-iam/types.rb
#user_name ⇒ String
The name of the user to create.
IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both “MyResource” and “myresource”.
1864 1865 1866 1867 1868 1869 1870 1871 |
# File 'lib/aws-sdk-iam/types.rb', line 1864 class CreateUserRequest < Struct.new( :path, :user_name, :permissions_boundary, :tags) SENSITIVE = [] include Aws::Structure end |