Class: Aws::IAM::Types::CredentialReportExpiredException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

The request was rejected because the most recent credential report has expired. To generate a new credential report, use GenerateCredentialReport. For more information about credential report expiration, see Getting credential reports in the IAM User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2001
2002
2003
2004
2005
# File 'lib/aws-sdk-iam/types.rb', line 2001

class CredentialReportExpiredException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end