Class: Aws::IAM::Types::DeleteGroupPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::DeleteGroupPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group_name ⇒ String
The name (friendly name, not ARN) identifying the group that the policy is embedded in.
-
#policy_name ⇒ String
The name identifying the policy document to delete.
Instance Attribute Details
#group_name ⇒ String
The name (friendly name, not ARN) identifying the group that the policy is embedded in.
This parameter allows (through its [regex pattern][1]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-iam/types.rb', line 2359 class DeleteGroupPolicyRequest < Struct.new( :group_name, :policy_name) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name identifying the policy document to delete.
This parameter allows (through its [regex pattern][1]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-iam/types.rb', line 2359 class DeleteGroupPolicyRequest < Struct.new( :group_name, :policy_name) SENSITIVE = [] include Aws::Structure end |