Class: Aws::IAM::Types::DeleteUserPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_nameString

The name identifying the policy document to delete.

This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


2794
2795
2796
2797
2798
2799
# File 'lib/aws-sdk-iam/types.rb', line 2794

class DeleteUserPolicyRequest < Struct.new(
  :user_name,
  :policy_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name (friendly name, not ARN) identifying the user that the policy is embedded in.

This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


2794
2795
2796
2797
2798
2799
# File 'lib/aws-sdk-iam/types.rb', line 2794

class DeleteUserPolicyRequest < Struct.new(
  :user_name,
  :policy_name)
  SENSITIVE = []
  include Aws::Structure
end