Class: Aws::IAM::Types::DetachUserPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_arnString

The Amazon Resource Name (ARN) of the IAM policy you want to detach.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


3027
3028
3029
3030
3031
3032
# File 'lib/aws-sdk-iam/types.rb', line 3027

class DetachUserPolicyRequest < Struct.new(
  :user_name,
  :policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name (friendly name, not ARN) of the IAM user to detach the policy from.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (String)


3027
3028
3029
3030
3031
3032
# File 'lib/aws-sdk-iam/types.rb', line 3027

class DetachUserPolicyRequest < Struct.new(
  :user_name,
  :policy_arn)
  SENSITIVE = []
  include Aws::Structure
end