Class: Aws::IAM::Types::EnableOutboundWebIdentityFederationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#issuer_identifierString

A unique issuer URL for your Amazon Web Services account that hosts the OpenID Connect (OIDC) discovery endpoints at ‘/.well-known/openid-configuration and /.well-known/jwks.json`. The OpenID Connect (OIDC) discovery endpoints contain verification keys and metadata necessary for token verification.

Returns:

  • (String)


3177
3178
3179
3180
3181
# File 'lib/aws-sdk-iam/types.rb', line 3177

class EnableOutboundWebIdentityFederationResponse < Struct.new(
  :issuer_identifier)
  SENSITIVE = []
  include Aws::Structure
end