Class: Aws::IAM::Types::ErrorDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about the reason that the operation failed.

This data type is used as a response element in the [GetOrganizationsAccessReport][1], [GetServiceLastAccessedDetails][2], and [GetServiceLastAccessedDetailsWithEntities][3] operations.

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetOrganizationsAccessReport.html [2]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetails.html [3]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetailsWithEntities.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code associated with the operation failure.

Returns:

  • (String)


3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-iam/types.rb', line 3328

class ErrorDetails < Struct.new(
  :message,
  :code)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Detailed information about the reason that the operation failed.

Returns:

  • (String)


3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-iam/types.rb', line 3328

class ErrorDetails < Struct.new(
  :message,
  :code)
  SENSITIVE = []
  include Aws::Structure
end