Class: Aws::IAM::Types::GenerateOrganizationsAccessReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entity_pathString

The path of the Organizations entity (root, OU, or account). You can build an entity path using the known structure of your organization. For example, assume that your account ID is 123456789012 and its parent OU ID is ou-rge0-awsabcde. The organization root ID is r-f6g7h8i9j0example and your organization ID is o-a1b2c3d4e5. Your entity path is o-a1b2c3d4e5/r-f6g7h8i9j0example/ou-rge0-awsabcde/123456789012.

Returns:

  • (String)


3516
3517
3518
3519
3520
3521
# File 'lib/aws-sdk-iam/types.rb', line 3516

class GenerateOrganizationsAccessReportRequest < Struct.new(
  :entity_path,
  :organizations_policy_id)
  SENSITIVE = []
  include Aws::Structure
end

#organizations_policy_idString

The identifier of the Organizations service control policy (SCP). This parameter is optional.

This ID is used to generate information about when an account principal that is limited by the SCP attempted to access an Amazon Web Services service.

Returns:

  • (String)


3516
3517
3518
3519
3520
3521
# File 'lib/aws-sdk-iam/types.rb', line 3516

class GenerateOrganizationsAccessReportRequest < Struct.new(
  :entity_path,
  :organizations_policy_id)
  SENSITIVE = []
  include Aws::Structure
end