Class: Aws::IAM::Types::GenerateServiceLastAccessedDetailsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the IAM resource (user, group, role, or managed policy) used to generate information about when the resource was last used in an attempt to access an Amazon Web Services service.

Returns:

  • (String)


3564
3565
3566
3567
3568
3569
# File 'lib/aws-sdk-iam/types.rb', line 3564

class GenerateServiceLastAccessedDetailsRequest < Struct.new(
  :arn,
  :granularity)
  SENSITIVE = []
  include Aws::Structure
end

#granularityString

The level of detail that you want to generate. You can specify whether you want to generate information about the last attempt to access services or actions. If you specify service-level granularity, this operation generates only service data. If you specify action-level granularity, it generates service and action data. If you don’t include this optional parameter, the operation generates service data.

Returns:

  • (String)


3564
3565
3566
3567
3568
3569
# File 'lib/aws-sdk-iam/types.rb', line 3564

class GenerateServiceLastAccessedDetailsRequest < Struct.new(
  :arn,
  :granularity)
  SENSITIVE = []
  include Aws::Structure
end