Class: Aws::IAM::Types::GetDelegationRequestResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetDelegationRequestResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegation_request ⇒ Types::DelegationRequest
The delegation request object containing all details about the request.
-
#permission_check_result ⇒ String
The result of the permission check, indicating whether the caller has sufficient permissions to cover the requested permissions.
-
#permission_check_status ⇒ String
The status of the permission check for the delegation request.
Instance Attribute Details
#delegation_request ⇒ Types::DelegationRequest
The delegation request object containing all details about the request.
3965 3966 3967 3968 3969 3970 3971 |
# File 'lib/aws-sdk-iam/types.rb', line 3965 class GetDelegationRequestResponse < Struct.new( :delegation_request, :permission_check_status, :permission_check_result) SENSITIVE = [] include Aws::Structure end |
#permission_check_result ⇒ String
The result of the permission check, indicating whether the caller has sufficient permissions to cover the requested permissions. This is an approximate result.
-
ALLOWED: The caller has sufficient permissions cover all the requested permissions. -
DENIED: The caller does not have sufficient permissions to cover all the requested permissions. -
UNSURE: It is not possible to determine whether the caller has all the permissions needed. This output is most likely for cases when the caller has permissions with conditions.
3965 3966 3967 3968 3969 3970 3971 |
# File 'lib/aws-sdk-iam/types.rb', line 3965 class GetDelegationRequestResponse < Struct.new( :delegation_request, :permission_check_status, :permission_check_result) SENSITIVE = [] include Aws::Structure end |
#permission_check_status ⇒ String
The status of the permission check for the delegation request.
This value indicates the status of the process to check whether the caller has sufficient permissions to cover the requested actions in the delegation request. Since this is an asynchronous process, there are three potential values:
-
IN_PROGRESS: The permission check process has started. -
COMPLETED: The permission check process has completed. ThePermissionCheckResultwill include the result. -
FAILED: The permission check process has failed.
3965 3966 3967 3968 3969 3970 3971 |
# File 'lib/aws-sdk-iam/types.rb', line 3965 class GetDelegationRequestResponse < Struct.new( :delegation_request, :permission_check_status, :permission_check_result) SENSITIVE = [] include Aws::Structure end |