Class: Aws::IAM::Types::GetHumanReadableSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entity_arnString

Arn of the entity to be summarized. At this time, the only supported entity type is delegation-request

Returns:

  • (String)


4139
4140
4141
4142
4143
4144
# File 'lib/aws-sdk-iam/types.rb', line 4139

class GetHumanReadableSummaryRequest < Struct.new(
  :entity_arn,
  :locale)
  SENSITIVE = []
  include Aws::Structure
end

#localeString

A string representing the locale to use for the summary generation. The supported locale strings are based on the [ Supported languages of the Amazon Web Services Management Console ](/awsconsolehelpdocs/latest/gsg/change-language.html#supported-languages).

Returns:

  • (String)


4139
4140
4141
4142
4143
4144
# File 'lib/aws-sdk-iam/types.rb', line 4139

class GetHumanReadableSummaryRequest < Struct.new(
  :entity_arn,
  :locale)
  SENSITIVE = []
  include Aws::Structure
end