Class: Aws::IAM::Types::GetLoginProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetLoginProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [GetLoginProfile] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetLoginProfile.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#login_profile ⇒ Types::LoginProfile
A structure containing the user name and the profile creation date for the user.
Instance Attribute Details
#login_profile ⇒ Types::LoginProfile
A structure containing the user name and the profile creation date for the user.
4240 4241 4242 4243 4244 |
# File 'lib/aws-sdk-iam/types.rb', line 4240 class GetLoginProfileResponse < Struct.new( :login_profile) SENSITIVE = [] include Aws::Structure end |