Class: Aws::IAM::Types::GetOpenIDConnectProviderResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains the response to a successful GetOpenIDConnectProvider request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_id_listArray<String>

A list of client IDs (also known as audiences) that are associated with the specified IAM OIDC provider resource object. For more information, see CreateOpenIDConnectProvider.

Returns:

  • (Array<String>)


4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-iam/types.rb', line 4521

class GetOpenIDConnectProviderResponse < Struct.new(
  :url,
  :client_id_list,
  :thumbprint_list,
  :create_date,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateTime

The date and time when the IAM OIDC provider resource object was created in the Amazon Web Services account.

Returns:

  • (Time)


4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-iam/types.rb', line 4521

class GetOpenIDConnectProviderResponse < Struct.new(
  :url,
  :client_id_list,
  :thumbprint_list,
  :create_date,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are attached to the specified IAM OIDC provider. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-iam/types.rb', line 4521

class GetOpenIDConnectProviderResponse < Struct.new(
  :url,
  :client_id_list,
  :thumbprint_list,
  :create_date,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#thumbprint_listArray<String>

A list of certificate thumbprints that are associated with the specified IAM OIDC provider resource object. For more information, see CreateOpenIDConnectProvider.

Returns:

  • (Array<String>)


4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-iam/types.rb', line 4521

class GetOpenIDConnectProviderResponse < Struct.new(
  :url,
  :client_id_list,
  :thumbprint_list,
  :create_date,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL that the IAM OIDC provider resource object is associated with. For more information, see CreateOpenIDConnectProvider.

Returns:

  • (String)


4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/aws-sdk-iam/types.rb', line 4521

class GetOpenIDConnectProviderResponse < Struct.new(
  :url,
  :client_id_list,
  :thumbprint_list,
  :create_date,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end