Class: Aws::IAM::Types::GetOrganizationsAccessReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetOrganizationsAccessReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The identifier of the request generated by the [GenerateOrganizationsAccessReport][1] operation.
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#sort_key ⇒ String
The key that is used to sort the results.
Instance Attribute Details
#job_id ⇒ String
The identifier of the request generated by the GenerateOrganizationsAccessReport operation.
4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-iam/types.rb', line 4454 class GetOrganizationsAccessReportRequest < Struct.new( :job_id, :max_items, :marker, :sort_key) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter only when paginating results and only after you
receive a response indicating that the results are truncated. Set it
to the value of the Marker element in the response that you
received to indicate where the next call should start.
4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-iam/types.rb', line 4454 class GetOrganizationsAccessReportRequest < Struct.new( :job_id, :max_items, :marker, :sort_key) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number
of items you want in the response. If additional items exist beyond
the maximum you specify, the IsTruncated response element is
true.
If you do not include this parameter, the number of items defaults
to 100. Note that IAM might return fewer results, even when there
are more results available. In that case, the IsTruncated response
element returns true, and Marker contains a value to include in
the subsequent call that tells the service where to continue from.
4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-iam/types.rb', line 4454 class GetOrganizationsAccessReportRequest < Struct.new( :job_id, :max_items, :marker, :sort_key) SENSITIVE = [] include Aws::Structure end |
#sort_key ⇒ String
The key that is used to sort the results. If you choose the namespace key, the results are returned in alphabetical order. If you choose the time key, the results are sorted numerically by the date and time.
4454 4455 4456 4457 4458 4459 4460 4461 |
# File 'lib/aws-sdk-iam/types.rb', line 4454 class GetOrganizationsAccessReportRequest < Struct.new( :job_id, :max_items, :marker, :sort_key) SENSITIVE = [] include Aws::Structure end |