Class: Aws::IAM::Types::GetOrganizationsAccessReportResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_detailsArray<Types::AccessDetail>

An object that contains details about the most recent attempt to access the service.

Returns:



4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#error_detailsTypes::ErrorDetails

Returns:



4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.

Returns:

  • (Boolean)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#job_completion_dateTime

The date and time, in [ISO 8601 date-time format], when the generated report job was completed or failed.

This field is null if the job is still in progress, as indicated by a job status value of IN_PROGRESS.

[1]: www.iso.org/iso/iso8601

Returns:

  • (Time)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#job_creation_dateTime

The date and time, in [ISO 8601 date-time format], when the report job was created.

[1]: www.iso.org/iso/iso8601

Returns:

  • (Time)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The status of the job.

Returns:

  • (String)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.

Returns:

  • (String)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_services_accessibleInteger

The number of services that the applicable SCPs allow account principals to access.

Returns:

  • (Integer)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_services_not_accessedInteger

The number of services that account principals are allowed but did not attempt to access.

Returns:

  • (Integer)


4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
# File 'lib/aws-sdk-iam/types.rb', line 4513

class GetOrganizationsAccessReportResponse < Struct.new(
  :job_status,
  :job_creation_date,
  :job_completion_date,
  :number_of_services_accessible,
  :number_of_services_not_accessed,
  :access_details,
  :is_truncated,
  :marker,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end