Class: Aws::IAM::Types::GetPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the managed policy that you want information about.
Instance Attribute Details
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the managed policy that you want information about.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
4636 4637 4638 4639 4640 |
# File 'lib/aws-sdk-iam/types.rb', line 4636 class GetPolicyRequest < Struct.new( :policy_arn) SENSITIVE = [] include Aws::Structure end |