Class: Aws::IAM::Types::GetPolicyVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_arnString

The Amazon Resource Name (ARN) of the managed policy that you want information about.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


4754
4755
4756
4757
4758
4759
# File 'lib/aws-sdk-iam/types.rb', line 4754

class GetPolicyVersionRequest < Struct.new(
  :policy_arn,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

Identifies the policy version to retrieve.

This parameter allows (through its regex pattern) a string of characters that consists of the lowercase letter 'v' followed by one or two digits, and optionally followed by a period '.' and a string of letters and digits.

Returns:

  • (String)


4754
4755
4756
4757
4758
4759
# File 'lib/aws-sdk-iam/types.rb', line 4754

class GetPolicyVersionRequest < Struct.new(
  :policy_arn,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end