Class: Aws::IAM::Types::GetRoleTemplateVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#minor_versionInteger

The minor version of the role template to retrieve. If you do not specify a minor version, the service returns the template's default minor version.

Returns:

  • (Integer)


4906
4907
4908
4909
4910
4911
# File 'lib/aws-sdk-iam/types.rb', line 4906

class GetRoleTemplateVersionRequest < Struct.new(
  :template_arn,
  :minor_version)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The Amazon Resource Name (ARN) of the role template whose version you want to retrieve.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


4906
4907
4908
4909
4910
4911
# File 'lib/aws-sdk-iam/types.rb', line 4906

class GetRoleTemplateVersionRequest < Struct.new(
  :template_arn,
  :minor_version)
  SENSITIVE = []
  include Aws::Structure
end