Class: Aws::IAM::Types::GetServiceLastAccessedDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetServiceLastAccessedDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The ID of the request generated by the [GenerateServiceLastAccessedDetails] operation.
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
Instance Attribute Details
#job_id ⇒ String
The ID of the request generated by the
- GenerateServiceLastAccessedDetails][1
-
operation. The
JobId
returned by GenerateServiceLastAccessedDetail must be used by the same role within a session, or by the same user when used to call GetServiceLastAccessedDetail.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateServiceLastAccessedDetails.html
4958 4959 4960 4961 4962 4963 4964 |
# File 'lib/aws-sdk-iam/types.rb', line 4958 class GetServiceLastAccessedDetailsRequest < Struct.new( :job_id, :max_items, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.
4958 4959 4960 4961 4962 4963 4964 |
# File 'lib/aws-sdk-iam/types.rb', line 4958 class GetServiceLastAccessedDetailsRequest < Struct.new( :job_id, :max_items, :marker) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.
If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from.
4958 4959 4960 4961 4962 4963 4964 |
# File 'lib/aws-sdk-iam/types.rb', line 4958 class GetServiceLastAccessedDetailsRequest < Struct.new( :job_id, :max_items, :marker) SENSITIVE = [] include Aws::Structure end |