Class: Aws::IAM::Types::GetServiceLastAccessedDetailsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::ErrorDetails

An object that contains details about the reason the operation failed.

Returns:



5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the ‘Marker` request parameter to retrieve more items. Note that IAM might return fewer than the `MaxItems` number of results even when there are more results available. We recommend that you check `IsTruncated` after every call to ensure that you receive all your results.

Returns:

  • (Boolean)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#job_completion_dateTime

The date and time, in [ISO 8601 date-time format], when the generated report job was completed or failed.

This field is null if the job is still in progress, as indicated by a job status value of ‘IN_PROGRESS`.

[1]: www.iso.org/iso/iso8601

Returns:

  • (Time)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#job_creation_dateTime

The date and time, in [ISO 8601 date-time format], when the report job was created.

[1]: www.iso.org/iso/iso8601

Returns:

  • (Time)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The status of the job.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The type of job. Service jobs return information about when each service was last accessed. Action jobs also include information about when tracked actions within the service were last accessed.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When ‘IsTruncated` is `true`, this element is present and contains the value to use for the `Marker` parameter in a subsequent pagination request.

Returns:

  • (String)


5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#services_last_accessedArray<Types::ServiceLastAccessed>

A ‘ServiceLastAccessed` object that contains details about the most recent attempt to access the service.

Returns:



5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
# File 'lib/aws-sdk-iam/types.rb', line 5041

class GetServiceLastAccessedDetailsResponse < Struct.new(
  :job_status,
  :job_type,
  :job_creation_date,
  :services_last_accessed,
  :job_completion_date,
  :is_truncated,
  :marker,
  :error)
  SENSITIVE = []
  include Aws::Structure
end