Class: Aws::IAM::Types::GetServiceLastAccessedDetailsWithEntitiesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetServiceLastAccessedDetailsWithEntitiesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_details_list ⇒ Array<Types::EntityDetails>
An ‘EntityDetailsList` object that contains details about when an IAM entity (user or role) used group or policy permissions in an attempt to access the specified Amazon Web Services service.
-
#error ⇒ Types::ErrorDetails
An object that contains details about the reason the operation failed.
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#job_completion_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the generated report job was completed or failed.
-
#job_creation_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the report job was created.
-
#job_status ⇒ String
The status of the job.
-
#marker ⇒ String
When ‘IsTruncated` is `true`, this element is present and contains the value to use for the `Marker` parameter in a subsequent pagination request.
Instance Attribute Details
#entity_details_list ⇒ Array<Types::EntityDetails>
An ‘EntityDetailsList` object that contains details about when an IAM entity (user or role) used group or policy permissions in an attempt to access the specified Amazon Web Services service.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::ErrorDetails
An object that contains details about the reason the operation failed.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the ‘Marker` request parameter to retrieve more items. Note that IAM might return fewer than the `MaxItems` number of results even when there are more results available. We recommend that you check `IsTruncated` after every call to ensure that you receive all your results.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#job_completion_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the generated report job was completed or failed.
This field is null if the job is still in progress, as indicated by a job status value of ‘IN_PROGRESS`.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#job_creation_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the report job was created.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The status of the job.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When ‘IsTruncated` is `true`, this element is present and contains the value to use for the `Marker` parameter in a subsequent pagination request.
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 |
# File 'lib/aws-sdk-iam/types.rb', line 5170 class GetServiceLastAccessedDetailsWithEntitiesResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :entity_details_list, :is_truncated, :marker, :error) SENSITIVE = [] include Aws::Structure end |