Class: Aws::IAM::Types::GetUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#user_name ⇒ String
The name of the user to get information about.
Instance Attribute Details
#user_name ⇒ String
The name of the user to get information about.
This parameter is optional. If it is not included, it defaults to the user making the request. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
5350 5351 5352 5353 5354 |
# File 'lib/aws-sdk-iam/types.rb', line 5350 class GetUserRequest < Struct.new( :user_name) SENSITIVE = [] include Aws::Structure end |