Class: Aws::IAM::Types::InlinePolicyIdentifierType
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::InlinePolicyIdentifierType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Identifies one or more inline policies that are embedded in IAM users, groups, or roles, by the name of the policy together with the type and name of the entity that it is attached to. Wildcard characters in the entity name can match multiple entities, so a single identifier can select more than one attached inline policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_name ⇒ String
The name of the IAM user, group, or role that the inline policy is attached to.
-
#attachment_type ⇒ String
The type of IAM entity that the inline policy is attached to.
-
#policy_name ⇒ String
The name of the inline policy.
Instance Attribute Details
#attachment_name ⇒ String
The name of the IAM user, group, or role that the inline policy is
attached to. Wildcard characters are supported to match multiple
entities: use at most one * (matches any sequence of characters,
including none), and any number of ? (each matches exactly one
character).
5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-iam/types.rb', line 5696 class InlinePolicyIdentifierType < Struct.new( :policy_name, :attachment_type, :attachment_name) SENSITIVE = [] include Aws::Structure end |
#attachment_type ⇒ String
The type of IAM entity that the inline policy is attached to.
5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-iam/types.rb', line 5696 class InlinePolicyIdentifierType < Struct.new( :policy_name, :attachment_type, :attachment_name) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name of the inline policy.
5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-iam/types.rb', line 5696 class InlinePolicyIdentifierType < Struct.new( :policy_name, :attachment_type, :attachment_name) SENSITIVE = [] include Aws::Structure end |