Class: Aws::IAM::Types::InstanceProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about an instance profile.

This data type is used as a response element in the following operations:

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) specifying the instance profile. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateTime

The date when the instance profile was created.

Returns:

  • (Time)


5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_idString

The stable and unique string identifying the instance profile. For more information about IDs, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_nameString

The name identifying the instance profile.

Returns:

  • (String)


5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path to the instance profile. For more information about paths, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rolesArray<Types::Role>

The role associated with the instance profile.

Returns:



5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are attached to the instance profile. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/aws-sdk-iam/types.rb', line 5777

class InstanceProfile < Struct.new(
  :path,
  :instance_profile_name,
  :instance_profile_id,
  :arn,
  :create_date,
  :roles,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end