Class: Aws::IAM::Types::ListGroupPoliciesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains the response to a successful ListGroupPolicies request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.

Returns:

  • (Boolean)


6599
6600
6601
6602
6603
6604
6605
# File 'lib/aws-sdk-iam/types.rb', line 6599

class ListGroupPoliciesResponse < Struct.new(
  :policy_names,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.

Returns:

  • (String)


6599
6600
6601
6602
6603
6604
6605
# File 'lib/aws-sdk-iam/types.rb', line 6599

class ListGroupPoliciesResponse < Struct.new(
  :policy_names,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#policy_namesArray<String>

A list of policy names.

This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (Array<String>)


6599
6600
6601
6602
6603
6604
6605
# File 'lib/aws-sdk-iam/types.rb', line 6599

class ListGroupPoliciesResponse < Struct.new(
  :policy_names,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end