Class: Aws::IAM::Types::ListInstanceProfileTagsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListInstanceProfileTagsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_profile_name ⇒ String
The name of the IAM instance profile whose tags you want to see.
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
Instance Attribute Details
#instance_profile_name ⇒ String
The name of the IAM instance profile whose tags you want to see.
This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
6576 6577 6578 6579 6580 6581 6582 |
# File 'lib/aws-sdk-iam/types.rb', line 6576 class ListInstanceProfileTagsRequest < Struct.new( :instance_profile_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.
6576 6577 6578 6579 6580 6581 6582 |
# File 'lib/aws-sdk-iam/types.rb', line 6576 class ListInstanceProfileTagsRequest < Struct.new( :instance_profile_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.
If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from.
6576 6577 6578 6579 6580 6581 6582 |
# File 'lib/aws-sdk-iam/types.rb', line 6576 class ListInstanceProfileTagsRequest < Struct.new( :instance_profile_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |