Class: Aws::IAM::Types::ListInstanceProfilesForRoleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListInstanceProfilesForRoleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [ListInstanceProfilesForRole] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfilesForRole.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_profiles ⇒ Array<Types::InstanceProfile>
A list of instance profiles.
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request.
Instance Attribute Details
#instance_profiles ⇒ Array<Types::InstanceProfile>
A list of instance profiles.
6689 6690 6691 6692 6693 6694 6695 |
# File 'lib/aws-sdk-iam/types.rb', line 6689 class ListInstanceProfilesForRoleResponse < Struct.new( :instance_profiles, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
6689 6690 6691 6692 6693 6694 6695 |
# File 'lib/aws-sdk-iam/types.rb', line 6689 class ListInstanceProfilesForRoleResponse < Struct.new( :instance_profiles, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
6689 6690 6691 6692 6693 6694 6695 |
# File 'lib/aws-sdk-iam/types.rb', line 6689 class ListInstanceProfilesForRoleResponse < Struct.new( :instance_profiles, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |