Class: Aws::IAM::Types::ListInstanceProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListInstanceProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#path_prefix ⇒ String
The path prefix for filtering the results.
Instance Attribute Details
#marker ⇒ String
Use this parameter only when paginating results and only after you
receive a response indicating that the results are truncated. Set it
to the value of the Marker element in the response that you
received to indicate where the next call should start.
6968 6969 6970 6971 6972 6973 6974 |
# File 'lib/aws-sdk-iam/types.rb', line 6968 class ListInstanceProfilesRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number
of items you want in the response. If additional items exist beyond
the maximum you specify, the IsTruncated response element is
true.
If you do not include this parameter, the number of items defaults
to 100. Note that IAM might return fewer results, even when there
are more results available. In that case, the IsTruncated response
element returns true, and Marker contains a value to include in
the subsequent call that tells the service where to continue from.
6968 6969 6970 6971 6972 6973 6974 |
# File 'lib/aws-sdk-iam/types.rb', line 6968 class ListInstanceProfilesRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#path_prefix ⇒ String
The path prefix for filtering the results. For example, the prefix
/application_abc/component_xyz/ gets all instance profiles whose
path starts with /application_abc/component_xyz/.
This parameter is optional. If it is not included, it defaults to a
slash (/), listing all instance profiles. This parameter allows
(through its regex pattern) a string of characters consisting
of either a forward slash (/) by itself or a string that must begin
and end with forward slashes. In addition, it can contain any ASCII
character from the ! (\u0021) through the DEL character
(\u007F), including most punctuation characters, digits, and upper
and lowercased letters.
6968 6969 6970 6971 6972 6973 6974 |
# File 'lib/aws-sdk-iam/types.rb', line 6968 class ListInstanceProfilesRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |