Class: Aws::IAM::Types::ListInstanceProfilesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains the response to a successful ListInstanceProfiles request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_profilesArray<Types::InstanceProfile>

A list of instance profiles.



7005
7006
7007
7008
7009
7010
7011
# File 'lib/aws-sdk-iam/types.rb', line 7005

class ListInstanceProfilesResponse < Struct.new(
  :instance_profiles,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.



7005
7006
7007
7008
7009
7010
7011
# File 'lib/aws-sdk-iam/types.rb', line 7005

class ListInstanceProfilesResponse < Struct.new(
  :instance_profiles,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.



7005
7006
7007
7008
7009
7010
7011
# File 'lib/aws-sdk-iam/types.rb', line 7005

class ListInstanceProfilesResponse < Struct.new(
  :instance_profiles,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end