Class: Aws::IAM::Types::ListMFADevicesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListMFADevicesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [ListMFADevices][1] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListMFADevices.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#mfa_devices ⇒ Array<Types::MFADevice>
A list of MFA devices.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
6942 6943 6944 6945 6946 6947 6948 |
# File 'lib/aws-sdk-iam/types.rb', line 6942 class ListMFADevicesResponse < Struct.new( :mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
6942 6943 6944 6945 6946 6947 6948 |
# File 'lib/aws-sdk-iam/types.rb', line 6942 class ListMFADevicesResponse < Struct.new( :mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#mfa_devices ⇒ Array<Types::MFADevice>
A list of MFA devices.
6942 6943 6944 6945 6946 6947 6948 |
# File 'lib/aws-sdk-iam/types.rb', line 6942 class ListMFADevicesResponse < Struct.new( :mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |