Class: Aws::IAM::Types::ListPoliciesGrantingServiceAccessEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListPoliciesGrantingServiceAccessEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains details about the permissions policies that are attached to the specified identity (user, group, or role).
This data type is used as a response element in the
- ListPoliciesGrantingServiceAccess][1
-
operation.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListPoliciesGrantingServiceAccess.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policies ⇒ Array<Types::PolicyGrantingServiceAccess>
The
PoliciesGrantingServiceAccessobject that contains details about the policy. -
#service_namespace ⇒ String
The namespace of the service that was accessed.
Instance Attribute Details
#policies ⇒ Array<Types::PolicyGrantingServiceAccess>
The PoliciesGrantingServiceAccess object that contains details about the policy.
7102 7103 7104 7105 7106 7107 |
# File 'lib/aws-sdk-iam/types.rb', line 7102 class ListPoliciesGrantingServiceAccessEntry < Struct.new( :service_namespace, :policies) SENSITIVE = [] include Aws::Structure end |
#service_namespace ⇒ String
The namespace of the service that was accessed.
To learn the service namespace of a service, see [Actions, resources, and condition keys for Amazon Web Services services] in the *Service Authorization Reference*. Choose the name of the service to view details for that service. In the first paragraph, find the service prefix. For example, ‘(service prefix: a4b)`. For more information about service namespaces, see [Amazon Web Services service namespaces] in the *Amazon Web Services General Reference*.
[1]: docs.aws.amazon.com/service-authorization/latest/reference/reference_policies_actions-resources-contextkeys.html [2]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#genref-aws-service-namespaces
7102 7103 7104 7105 7106 7107 |
# File 'lib/aws-sdk-iam/types.rb', line 7102 class ListPoliciesGrantingServiceAccessEntry < Struct.new( :service_namespace, :policies) SENSITIVE = [] include Aws::Structure end |