Class: Aws::IAM::Types::ListPoliciesGrantingServiceAccessRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the IAM identity (user, group, or role) whose policies you want to list.

Returns:



7371
7372
7373
7374
7375
7376
7377
# File 'lib/aws-sdk-iam/types.rb', line 7371

class ListPoliciesGrantingServiceAccessRequest < Struct.new(
  :marker,
  :arn,
  :service_namespaces)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.

Returns:



7371
7372
7373
7374
7375
7376
7377
# File 'lib/aws-sdk-iam/types.rb', line 7371

class ListPoliciesGrantingServiceAccessRequest < Struct.new(
  :marker,
  :arn,
  :service_namespaces)
  SENSITIVE = []
  include Aws::Structure
end

#service_namespacesArray<String>

The service namespace for the Amazon Web Services services whose policies you want to list.

To learn the service namespace for a service, see Actions, resources, and condition keys for Amazon Web Services services in the IAM User Guide. Choose the name of the service to view details for that service. In the first paragraph, find the service prefix. For example, (service prefix: a4b). For more information about service namespaces, see Amazon Web Services service namespaces in the Amazon Web Services General Reference.

Returns:



7371
7372
7373
7374
7375
7376
7377
# File 'lib/aws-sdk-iam/types.rb', line 7371

class ListPoliciesGrantingServiceAccessRequest < Struct.new(
  :marker,
  :arn,
  :service_namespaces)
  SENSITIVE = []
  include Aws::Structure
end