Class: Aws::IAM::Types::ListPoliciesGrantingServiceAccessResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. We recommend that you check IsTruncated after every call to ensure that you receive all your results.



7401
7402
7403
7404
7405
7406
7407
# File 'lib/aws-sdk-iam/types.rb', line 7401

class ListPoliciesGrantingServiceAccessResponse < Struct.new(
  :policies_granting_service_access,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.



7401
7402
7403
7404
7405
7406
7407
# File 'lib/aws-sdk-iam/types.rb', line 7401

class ListPoliciesGrantingServiceAccessResponse < Struct.new(
  :policies_granting_service_access,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#policies_granting_service_accessArray<Types::ListPoliciesGrantingServiceAccessEntry>

A ListPoliciesGrantingServiceAccess object that contains details about the permissions policies attached to the specified identity (user, group, or role).



7401
7402
7403
7404
7405
7406
7407
# File 'lib/aws-sdk-iam/types.rb', line 7401

class ListPoliciesGrantingServiceAccessResponse < Struct.new(
  :policies_granting_service_access,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end