Class: Aws::IAM::Types::ListPolicyVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.

Returns:



7635
7636
7637
7638
7639
7640
7641
# File 'lib/aws-sdk-iam/types.rb', line 7635

class ListPolicyVersionsRequest < Struct.new(
  :policy_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.

If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from.

Returns:



7635
7636
7637
7638
7639
7640
7641
# File 'lib/aws-sdk-iam/types.rb', line 7635

class ListPolicyVersionsRequest < Struct.new(
  :policy_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#policy_arnString

The Amazon Resource Name (ARN) of the IAM policy for which you want the versions.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:



7635
7636
7637
7638
7639
7640
7641
# File 'lib/aws-sdk-iam/types.rb', line 7635

class ListPolicyVersionsRequest < Struct.new(
  :policy_arn,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end