Class: Aws::IAM::Types::ListPolicyVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListPolicyVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [ListPolicyVersions] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicyVersions.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#versions ⇒ Array<Types::PolicyVersion>
A list of policy versions.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
7448 7449 7450 7451 7452 7453 7454 |
# File 'lib/aws-sdk-iam/types.rb', line 7448 class ListPolicyVersionsResponse < Struct.new( :versions, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
7448 7449 7450 7451 7452 7453 7454 |
# File 'lib/aws-sdk-iam/types.rb', line 7448 class ListPolicyVersionsResponse < Struct.new( :versions, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#versions ⇒ Array<Types::PolicyVersion>
A list of policy versions.
For more information about managed policy versions, see [Versioning for managed policies] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-versions.html
7448 7449 7450 7451 7452 7453 7454 |
# File 'lib/aws-sdk-iam/types.rb', line 7448 class ListPolicyVersionsResponse < Struct.new( :versions, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |