Class: Aws::IAM::Types::ListSSHPublicKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListSSHPublicKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#user_name ⇒ String
The name of the IAM user to list SSH public keys for.
Instance Attribute Details
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start.
7846 7847 7848 7849 7850 7851 7852 |
# File 'lib/aws-sdk-iam/types.rb', line 7846 class ListSSHPublicKeysRequest < Struct.new( :user_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.
If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from.
7846 7847 7848 7849 7850 7851 7852 |
# File 'lib/aws-sdk-iam/types.rb', line 7846 class ListSSHPublicKeysRequest < Struct.new( :user_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the IAM user to list SSH public keys for. If none is specified, the UserName field is determined implicitly based on the Amazon Web Services access key used to sign the request.
This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
7846 7847 7848 7849 7850 7851 7852 |
# File 'lib/aws-sdk-iam/types.rb', line 7846 class ListSSHPublicKeysRequest < Struct.new( :user_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |