Class: Aws::IAM::Types::ListSSHPublicKeysResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListSSHPublicKeysResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful ListSSHPublicKeys request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#ssh_public_keys ⇒ Array<Types::SSHPublicKeyMetadata>
A list of the SSH public keys assigned to IAM user.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If
your results were truncated, you can make a subsequent pagination
request using the Marker request parameter to retrieve more items.
Note that IAM might return fewer than the MaxItems number of
results even when there are more results available. We recommend
that you check IsTruncated after every call to ensure that you
receive all your results.
8102 8103 8104 8105 8106 8107 8108 |
# File 'lib/aws-sdk-iam/types.rb', line 8102 class ListSSHPublicKeysResponse < Struct.new( :ssh_public_keys, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains
the value to use for the Marker parameter in a subsequent
pagination request.
8102 8103 8104 8105 8106 8107 8108 |
# File 'lib/aws-sdk-iam/types.rb', line 8102 class ListSSHPublicKeysResponse < Struct.new( :ssh_public_keys, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#ssh_public_keys ⇒ Array<Types::SSHPublicKeyMetadata>
A list of the SSH public keys assigned to IAM user.
8102 8103 8104 8105 8106 8107 8108 |
# File 'lib/aws-sdk-iam/types.rb', line 8102 class ListSSHPublicKeysResponse < Struct.new( :ssh_public_keys, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |