Class: Aws::IAM::Types::ListServerCertificatesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListServerCertificatesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful ListServerCertificates request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#server_certificate_metadata_list ⇒ Array<Types::ServerCertificateMetadata>
A list of server certificates.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If
your results were truncated, you can make a subsequent pagination
request using the Marker request parameter to retrieve more items.
Note that IAM might return fewer than the MaxItems number of
results even when there are more results available. We recommend
that you check IsTruncated after every call to ensure that you
receive all your results.
8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-iam/types.rb', line 8264 class ListServerCertificatesResponse < Struct.new( :server_certificate_metadata_list, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains
the value to use for the Marker parameter in a subsequent
pagination request.
8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-iam/types.rb', line 8264 class ListServerCertificatesResponse < Struct.new( :server_certificate_metadata_list, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#server_certificate_metadata_list ⇒ Array<Types::ServerCertificateMetadata>
A list of server certificates.
8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-iam/types.rb', line 8264 class ListServerCertificatesResponse < Struct.new( :server_certificate_metadata_list, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |