Class: Aws::IAM::Types::ListServiceSpecificCredentialsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_usersBoolean

A flag indicating whether to list service specific credentials for all users. This parameter cannot be specified together with UserName. When true, returns all credentials associated with the specified service.

Returns:



8096
8097
8098
8099
8100
8101
8102
8103
8104
# File 'lib/aws-sdk-iam/types.rb', line 8096

class ListServiceSpecificCredentialsRequest < Struct.new(
  :user_name,
  :service_name,
  :all_users,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker from the response that you received to indicate where the next call should start.

Returns:



8096
8097
8098
8099
8100
8101
8102
8103
8104
# File 'lib/aws-sdk-iam/types.rb', line 8096

class ListServiceSpecificCredentialsRequest < Struct.new(
  :user_name,
  :service_name,
  :all_users,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.

Returns:



8096
8097
8098
8099
8100
8101
8102
8103
8104
# File 'lib/aws-sdk-iam/types.rb', line 8096

class ListServiceSpecificCredentialsRequest < Struct.new(
  :user_name,
  :service_name,
  :all_users,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

Filters the returned results to only those for the specified Amazon Web Services service. If not specified, then Amazon Web Services returns service-specific credentials for all services.

Returns:



8096
8097
8098
8099
8100
8101
8102
8103
8104
# File 'lib/aws-sdk-iam/types.rb', line 8096

class ListServiceSpecificCredentialsRequest < Struct.new(
  :user_name,
  :service_name,
  :all_users,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the user whose service-specific credentials you want information about. If this value is not specified, then the operation assumes the user whose credentials are used to call the operation.

This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

[1]: wikipedia.org/wiki/regex

Returns:



8096
8097
8098
8099
8100
8101
8102
8103
8104
# File 'lib/aws-sdk-iam/types.rb', line 8096

class ListServiceSpecificCredentialsRequest < Struct.new(
  :user_name,
  :service_name,
  :all_users,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end