Class: Aws::IAM::Types::ListUsersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListUsersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#path_prefix ⇒ String
The path prefix for filtering the results.
Instance Attribute Details
#marker ⇒ String
Use this parameter only when paginating results and only after you
receive a response indicating that the results are truncated. Set it
to the value of the Marker element in the response that you
received to indicate where the next call should start.
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-iam/types.rb', line 8630 class ListUsersRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number
of items you want in the response. If additional items exist beyond
the maximum you specify, the IsTruncated response element is
true.
If you do not include this parameter, the number of items defaults
to 100. Note that IAM might return fewer results, even when there
are more results available. In that case, the IsTruncated response
element returns true, and Marker contains a value to include in
the subsequent call that tells the service where to continue from.
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-iam/types.rb', line 8630 class ListUsersRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#path_prefix ⇒ String
The path prefix for filtering the results. For example:
/division_abc/subdivision_xyz/, which would get all user names
whose path starts with /division_abc/subdivision_xyz/.
This parameter is optional. If it is not included, it defaults to a
slash (/), listing all user names. This parameter allows (through
its regex pattern) a string of characters consisting of either
a forward slash (/) by itself or a string that must begin and end
with forward slashes. In addition, it can contain any ASCII
character from the ! (\u0021) through the DEL character
(\u007F), including most punctuation characters, digits, and upper
and lowercased letters.
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-iam/types.rb', line 8630 class ListUsersRequest < Struct.new( :path_prefix, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |