Class: Aws::IAM::Types::ListVirtualMFADevicesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.

Returns:

  • (Boolean)


8521
8522
8523
8524
8525
8526
8527
# File 'lib/aws-sdk-iam/types.rb', line 8521

class ListVirtualMFADevicesResponse < Struct.new(
  :virtual_mfa_devices,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.

Returns:

  • (String)


8521
8522
8523
8524
8525
8526
8527
# File 'lib/aws-sdk-iam/types.rb', line 8521

class ListVirtualMFADevicesResponse < Struct.new(
  :virtual_mfa_devices,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_mfa_devicesArray<Types::VirtualMFADevice>

The list of virtual MFA devices in the current account that match the AssignmentStatus value that was passed in the request.

Returns:



8521
8522
8523
8524
8525
8526
8527
# File 'lib/aws-sdk-iam/types.rb', line 8521

class ListVirtualMFADevicesResponse < Struct.new(
  :virtual_mfa_devices,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end