Class: Aws::IAM::Types::PasswordPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about the account password policy.

This data type is used as a response element in the

GetAccountPasswordPolicy][1

operation.

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountPasswordPolicy.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_users_to_change_passwordBoolean

Specifies whether IAM users are allowed to change their own password. Gives IAM users permissions to iam:ChangePassword for only their user and to the iam:GetAccountPasswordPolicy action. This option does not attach a permissions policy to each user, rather the permissions are applied at the account-level for all users by IAM.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#expire_passwordsBoolean

Indicates whether passwords in the account expire. Returns true if MaxPasswordAge contains a value greater than 0. Returns false if MaxPasswordAge is 0 or not present.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#hard_expiryBoolean

Specifies whether IAM users are prevented from setting a new password via the Amazon Web Services Management Console after their password has expired. The IAM user cannot access the console until an administrator resets the password. IAM users with iam:ChangePassword permission and active access keys can reset their own expired console password using the CLI or API.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#max_password_ageInteger

The number of days that an IAM user password is valid.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_password_lengthInteger

Minimum length to require for IAM user passwords.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#password_reuse_preventionInteger

Specifies the number of previous passwords that IAM users are prevented from reusing.

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_lowercase_charactersBoolean

Specifies whether IAM user passwords must contain at least one lowercase character (a to z).

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_numbersBoolean

Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_symbolsBoolean

Specifies whether IAM user passwords must contain at least one of the following symbols:

! @ # $ % ^ &amp; * ( ) _ + - = [ ] { } \| ‘

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_uppercase_charactersBoolean

Specifies whether IAM user passwords must contain at least one uppercase character (A to Z).

Returns:



8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/aws-sdk-iam/types.rb', line 8917

class PasswordPolicy < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :expire_passwords,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end