Class: Aws::IAM::Types::Position
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::Position
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the row and column of a location of a Statement element in a policy document.
This data type is used as a member of the ‘ Statement ` type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column ⇒ Integer
The column in the line containing the specified position in the document.
-
#line ⇒ Integer
The line containing the specified position in the document.
Instance Attribute Details
#column ⇒ Integer
The column in the line containing the specified position in the document.
9470 9471 9472 9473 9474 9475 |
# File 'lib/aws-sdk-iam/types.rb', line 9470 class Position < Struct.new( :line, :column) SENSITIVE = [] include Aws::Structure end |
#line ⇒ Integer
The line containing the specified position in the document.
9470 9471 9472 9473 9474 9475 |
# File 'lib/aws-sdk-iam/types.rb', line 9470 class Position < Struct.new( :line, :column) SENSITIVE = [] include Aws::Structure end |