Class: Aws::IAM::Types::PutAccountPropertiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#propertiesHash<String,String>

A map of property key-value pairs to set. All keys must belong to the same namespace.

Each key uses the format Namespace/PropertyName. The key must contain exactly one / separating the namespace from the property name, and cannot start or end with /.

The service validates each value based on the property key's expected type. For example, boolean properties expect true or false.

Returns:

  • (Hash<String,String>)


9858
9859
9860
9861
9862
# File 'lib/aws-sdk-iam/types.rb', line 9858

class PutAccountPropertiesRequest < Struct.new(
  :properties)
  SENSITIVE = []
  include Aws::Structure
end