Class: Aws::IAM::Types::PutRolePermissionsBoundaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#permissions_boundaryString

The ARN of the managed policy that is used to set the permissions boundary for the role.

A permissions boundary policy defines the maximum permissions that identity-based policies can grant to an entity, but does not grant permissions. Permissions boundaries do not define the maximum permissions that a resource-based policy can grant to an entity. To learn more, see Permissions boundaries for IAM entities in the IAM User Guide.

For more information about policy types, see Policy types in the IAM User Guide.

Returns:

  • (String)


9736
9737
9738
9739
9740
9741
# File 'lib/aws-sdk-iam/types.rb', line 9736

class PutRolePermissionsBoundaryRequest < Struct.new(
  :role_name,
  :permissions_boundary)
  SENSITIVE = []
  include Aws::Structure
end

#role_nameString

The name (friendly name, not ARN) of the IAM role for which you want to set the permissions boundary.

Returns:

  • (String)


9736
9737
9738
9739
9740
9741
# File 'lib/aws-sdk-iam/types.rb', line 9736

class PutRolePermissionsBoundaryRequest < Struct.new(
  :role_name,
  :permissions_boundary)
  SENSITIVE = []
  include Aws::Structure
end