Class: Aws::IAM::Types::RejectDelegationRequestRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delegation_request_idString

The unique identifier of the delegation request to reject.

Returns:

  • (String)


9752
9753
9754
9755
9756
9757
# File 'lib/aws-sdk-iam/types.rb', line 9752

class RejectDelegationRequestRequest < Struct.new(
  :delegation_request_id,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end

#notesString

Optional notes explaining the reason for rejecting the delegation request.

Returns:

  • (String)


9752
9753
9754
9755
9756
9757
# File 'lib/aws-sdk-iam/types.rb', line 9752

class RejectDelegationRequestRequest < Struct.new(
  :delegation_request_id,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end