Class: Aws::IAM::Types::RoleModifiedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::RoleModifiedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
The request was rejected because someone modified the role template while the service was creating the role. Wait a few minutes and try the request again.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
10749 10750 10751 10752 10753 |
# File 'lib/aws-sdk-iam/types.rb', line 10749 class RoleModifiedException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |