Class: Aws::IAM::Types::RoleTemplateVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about a version of an IAM role template, including the configuration that is used to create roles with AcquireRole. This structure is returned as a response element by the GetRoleTemplateVersion operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assume_role_policy_document_templateString

The trust policy template that grants an entity permission to assume roles that you create from this template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#create_timestampTime

The date and time, in ISO 8601 date-time format, when the role template version was created.

Returns:

  • (Time)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#default_minor_versionInteger

The minor version that the service uses by default when you create a role from this template without specifying a minor version.

Returns:

  • (Integer)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the role template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether the role template is enabled. When a template is disabled, you cannot create roles from it.

Returns:

  • (Boolean)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#inline_policy_templatesArray<Types::InlinePolicy>

A list of inline policy templates that the service embeds in roles that you create from this template.

Returns:



10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#major_versionInteger

The major version number of the role template.

Returns:

  • (Integer)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#managed_by_typeString

Indicates that the role template is managed by an Amazon Web Services service.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#managed_by_valueString

The identifier of the Amazon Web Services service that manages the role template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#managed_policy_arnsArray<String>

A list of the ARNs of the managed policies that the service attaches to roles that you create from this template.

Returns:

  • (Array<String>)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#max_session_durationInteger

The maximum session duration (in seconds) for roles that are created from this template.

Returns:

  • (Integer)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#minor_versionInteger

The minor version number of this role template version.

Returns:

  • (Integer)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#parameters_definitionArray<Types::ParameterDefinition>

A list of the parameters that are defined for this role template version. You supply values for these parameters when you create a role with AcquireRole.

Returns:



10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#permission_boundary_arnString

The ARN of the policy that sets the permissions boundary for roles that you create from this template.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#role_description_patternString

The pattern that is used to generate the description of a role that is created from this template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#role_name_patternString

The pattern that is used to generate the name of a role that is created from this template. The pattern can include @{parameter} placeholders that are replaced with the values you supply in the ReplacementValues parameter of AcquireRole.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#role_path_patternString

The pattern that is used to generate the path of a role that is created from this template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#role_tags_templateArray<Types::TagTemplate>

A list of tag templates that are applied to roles that are created from this template.

Returns:



10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The Amazon Resource Name (ARN) that identifies the role template.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The friendly name that identifies the role template.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#template_version_idString

The identifier of the role template version.

Returns:

  • (String)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#update_timestampTime

The date and time, in ISO 8601 date-time format, when the role template version was last updated.

Returns:

  • (Time)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#version_enabledBoolean

Specifies whether this specific minor version of the role template is enabled.

Returns:

  • (Boolean)


10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
# File 'lib/aws-sdk-iam/types.rb', line 10925

class RoleTemplateVersion < Struct.new(
  :template_arn,
  :template_name,
  :template_version_id,
  :description,
  :major_version,
  :default_minor_version,
  :managed_by_type,
  :managed_by_value,
  :enabled,
  :minor_version,
  :role_name_pattern,
  :role_path_pattern,
  :role_description_pattern,
  :assume_role_policy_document_template,
  :inline_policy_templates,
  :managed_policy_arns,
  :permission_boundary_arn,
  :parameters_definition,
  :role_tags_template,
  :max_session_duration,
  :version_enabled,
  :create_timestamp,
  :update_timestamp)
  SENSITIVE = []
  include Aws::Structure
end