Class: Aws::IAM::Types::RoleUsageType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

An object that contains details about how a service-linked role is used, if that information is returned by the service.

This data type is used as a response element in the

GetServiceLinkedRoleDeletionStatus][1

operation.

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLinkedRoleDeletionStatus.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#regionString

The name of the Region where the service-linked role is being used.

Returns:

  • (String)


10349
10350
10351
10352
10353
10354
# File 'lib/aws-sdk-iam/types.rb', line 10349

class RoleUsageType < Struct.new(
  :region,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<String>

The name of the resource that is using the service-linked role.

Returns:

  • (Array<String>)


10349
10350
10351
10352
10353
10354
# File 'lib/aws-sdk-iam/types.rb', line 10349

class RoleUsageType < Struct.new(
  :region,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end