Class: Aws::IAM::Types::SSHPublicKey

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about an SSH public key.

This data type is used as a response element in the GetSSHPublicKey and UploadSSHPublicKey operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fingerprintString

The MD5 message digest of the SSH public key.

Returns:

  • (String)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#ssh_public_key_bodyString

The SSH public key.

Returns:

  • (String)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#ssh_public_key_idString

The unique identifier for the SSH public key.

Returns:

  • (String)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SSH public key. Active means that the key can be used for authentication with an CodeCommit repository. Inactive means that the key cannot be used.

Returns:

  • (String)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#upload_dateTime

The date and time, in ISO 8601 date-time format, when the SSH public key was uploaded.

Returns:

  • (Time)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the IAM user associated with the SSH public key.

Returns:

  • (String)


10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
# File 'lib/aws-sdk-iam/types.rb', line 10619

class SSHPublicKey < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :fingerprint,
  :ssh_public_key_body,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end