Class: Aws::IAM::Types::SSHPublicKeyMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about an SSH public key, without the key’s body or fingerprint.

This data type is used as a response element in the

ListSSHPublicKeys][1

operation.

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListSSHPublicKeys.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ssh_public_key_idString

The unique identifier for the SSH public key.

Returns:

  • (String)


10494
10495
10496
10497
10498
10499
10500
10501
# File 'lib/aws-sdk-iam/types.rb', line 10494

class SSHPublicKeyMetadata < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SSH public key. Active means that the key can be used for authentication with an CodeCommit repository. Inactive means that the key cannot be used.

Returns:

  • (String)


10494
10495
10496
10497
10498
10499
10500
10501
# File 'lib/aws-sdk-iam/types.rb', line 10494

class SSHPublicKeyMetadata < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#upload_dateTime

The date and time, in [ISO 8601 date-time format], when the SSH public key was uploaded.

[1]: www.iso.org/iso/iso8601

Returns:

  • (Time)


10494
10495
10496
10497
10498
10499
10500
10501
# File 'lib/aws-sdk-iam/types.rb', line 10494

class SSHPublicKeyMetadata < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the IAM user associated with the SSH public key.

Returns:

  • (String)


10494
10495
10496
10497
10498
10499
10500
10501
# File 'lib/aws-sdk-iam/types.rb', line 10494

class SSHPublicKeyMetadata < Struct.new(
  :user_name,
  :ssh_public_key_id,
  :status,
  :upload_date)
  SENSITIVE = []
  include Aws::Structure
end