Class: Aws::IAM::Types::SendDelegationTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::SendDelegationTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegation_request_id ⇒ String
The unique identifier of the delegation request for which to send the token.
Instance Attribute Details
#delegation_request_id ⇒ String
The unique identifier of the delegation request for which to send the token.
11140 11141 11142 11143 11144 |
# File 'lib/aws-sdk-iam/types.rb', line 11140 class SendDelegationTokenRequest < Struct.new( :delegation_request_id) SENSITIVE = [] include Aws::Structure end |