Class: Aws::IAM::Types::SetDefaultPolicyVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_arnString

The Amazon Resource Name (ARN) of the IAM policy whose default version you want to set.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


11567
11568
11569
11570
11571
11572
# File 'lib/aws-sdk-iam/types.rb', line 11567

class SetDefaultPolicyVersionRequest < Struct.new(
  :policy_arn,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version of the policy to set as the default (operative) version.

For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.

Returns:

  • (String)


11567
11568
11569
11570
11571
11572
# File 'lib/aws-sdk-iam/types.rb', line 11567

class SetDefaultPolicyVersionRequest < Struct.new(
  :policy_arn,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end