Class: Aws::IAM::Types::SigningCertificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::SigningCertificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about an X.509 signing certificate.
This data type is used as a response element in the
- UploadSigningCertificate][1
operations.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_UploadSigningCertificate.html [2]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListSigningCertificates.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_body ⇒ String
The contents of the signing certificate.
-
#certificate_id ⇒ String
The ID for the signing certificate.
-
#status ⇒ String
The status of the signing certificate.
-
#upload_date ⇒ Time
The date when the signing certificate was uploaded.
-
#user_name ⇒ String
The name of the user the signing certificate is associated with.
Instance Attribute Details
#certificate_body ⇒ String
The contents of the signing certificate.
11002 11003 11004 11005 11006 11007 11008 11009 11010 |
# File 'lib/aws-sdk-iam/types.rb', line 11002 class SigningCertificate < Struct.new( :user_name, :certificate_id, :certificate_body, :status, :upload_date) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The ID for the signing certificate.
11002 11003 11004 11005 11006 11007 11008 11009 11010 |
# File 'lib/aws-sdk-iam/types.rb', line 11002 class SigningCertificate < Struct.new( :user_name, :certificate_id, :certificate_body, :status, :upload_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the signing certificate. Active means that the key is valid for API calls, while Inactive means it is not.
11002 11003 11004 11005 11006 11007 11008 11009 11010 |
# File 'lib/aws-sdk-iam/types.rb', line 11002 class SigningCertificate < Struct.new( :user_name, :certificate_id, :certificate_body, :status, :upload_date) SENSITIVE = [] include Aws::Structure end |
#upload_date ⇒ Time
The date when the signing certificate was uploaded.
11002 11003 11004 11005 11006 11007 11008 11009 11010 |
# File 'lib/aws-sdk-iam/types.rb', line 11002 class SigningCertificate < Struct.new( :user_name, :certificate_id, :certificate_body, :status, :upload_date) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the user the signing certificate is associated with.
11002 11003 11004 11005 11006 11007 11008 11009 11010 |
# File 'lib/aws-sdk-iam/types.rb', line 11002 class SigningCertificate < Struct.new( :user_name, :certificate_id, :certificate_body, :status, :upload_date) SENSITIVE = [] include Aws::Structure end |