Class: Aws::IAM::Types::SimulatePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::SimulatePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [SimulatePrincipalPolicy] or
- SimulateCustomPolicy][2
-
request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_SimulatePrincipalPolicy.html [2]: docs.aws.amazon.com/IAM/latest/APIReference/API_SimulateCustomPolicy.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_results ⇒ Array<Types::EvaluationResult>
The results of the simulation.
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request.
Instance Attribute Details
#evaluation_results ⇒ Array<Types::EvaluationResult>
The results of the simulation.
11298 11299 11300 11301 11302 11303 11304 |
# File 'lib/aws-sdk-iam/types.rb', line 11298 class SimulatePolicyResponse < Struct.new( :evaluation_results, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
11298 11299 11300 11301 11302 11303 11304 |
# File 'lib/aws-sdk-iam/types.rb', line 11298 class SimulatePolicyResponse < Struct.new( :evaluation_results, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
11298 11299 11300 11301 11302 11303 11304 |
# File 'lib/aws-sdk-iam/types.rb', line 11298 class SimulatePolicyResponse < Struct.new( :evaluation_results, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |