Class: Aws::IAM::Types::SourceRoleTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about the role template that a role was created from.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#template_arnString

The Amazon Resource Name (ARN) of the role template that the role was created from.

Returns:

  • (String)


12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-iam/types.rb', line 12271

class SourceRoleTemplate < Struct.new(
  :template_arn,
  :template_minor_version)
  SENSITIVE = []
  include Aws::Structure
end

#template_minor_versionInteger

The minor version of the role template that was used to create the role.

Returns:

  • (Integer)


12271
12272
12273
12274
12275
12276
# File 'lib/aws-sdk-iam/types.rb', line 12271

class SourceRoleTemplate < Struct.new(
  :template_arn,
  :template_minor_version)
  SENSITIVE = []
  include Aws::Structure
end