Class: Aws::IAM::Types::UntagMFADeviceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#serial_numberString

The unique identifier for the IAM virtual MFA device from which you want to remove tags. For virtual MFA devices, the serial number is the same as the ARN.

This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


12000
12001
12002
12003
12004
12005
# File 'lib/aws-sdk-iam/types.rb', line 12000

class UntagMFADeviceRequest < Struct.new(
  :serial_number,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

A list of key names as a simple array of strings. The tags with matching keys are removed from the specified instance profile.

Returns:

  • (Array<String>)


12000
12001
12002
12003
12004
12005
# File 'lib/aws-sdk-iam/types.rb', line 12000

class UntagMFADeviceRequest < Struct.new(
  :serial_number,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end