Class: Aws::IAM::Types::UpdateAccountPasswordPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_users_to_change_passwordBoolean

Allows all IAM users in your account to use the Amazon Web Services Management Console to change their own passwords. For more information, see [Permitting IAM users to change their own passwords] in the *IAM User Guide*.

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users in the account do not automatically have permissions to change their own password.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_passwords_enable-user-change.html

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#hard_expiryBoolean

Prevents IAM users who are accessing the account via the Amazon Web Services Management Console from setting a new console password after their password has expired. The IAM user cannot access the console until an administrator resets the password.

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that IAM users can change their passwords after they expire and continue to sign in as the user.

<note markdown=“1”> In the Amazon Web Services Management Console, the custom password policy option **Allow users to change their own password** gives IAM users permissions to iam:ChangePassword for only their user and to the iam:GetAccountPasswordPolicy action. This option does not attach a permissions policy to each user, rather the permissions are applied at the account-level for all users by IAM. IAM users with iam:ChangePassword permission and active access keys can reset their own expired console password using the CLI or API.

</note>

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#max_password_ageInteger

The number of days that an IAM user password is valid.

If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM user passwords never expire.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_password_lengthInteger

The minimum number of characters allowed in an IAM user password.

If you do not specify a value for this parameter, then the operation uses the default value of 6.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#password_reuse_preventionInteger

Specifies the number of previous passwords that IAM users are prevented from reusing.

If you do not specify a value for this parameter, then the operation uses the default value of 0. The result is that IAM users are not prevented from reusing previous passwords.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_lowercase_charactersBoolean

Specifies whether IAM user passwords must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one lowercase character.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_numbersBoolean

Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one numeric character.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_symbolsBoolean

Specifies whether IAM user passwords must contain at least one of the following non-alphanumeric characters:

! @ # $ % ^ &amp; * ( ) _ + - = [ ] { } | ‘

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one symbol character.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end

#require_uppercase_charactersBoolean

Specifies whether IAM user passwords must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).

If you do not specify a value for this parameter, then the operation uses the default value of false. The result is that passwords do not require at least one uppercase character.

Returns:



12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
# File 'lib/aws-sdk-iam/types.rb', line 12337

class UpdateAccountPasswordPolicyRequest < Struct.new(
  :minimum_password_length,
  :require_symbols,
  :require_numbers,
  :require_uppercase_characters,
  :require_lowercase_characters,
  :allow_users_to_change_password,
  :max_password_age,
  :password_reuse_prevention,
  :hard_expiry)
  SENSITIVE = []
  include Aws::Structure
end