Class: Aws::IAM::Types::UpdateRoleDescriptionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::UpdateRoleDescriptionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role ⇒ Types::Role
A structure that contains details about the modified role.
Instance Attribute Details
#role ⇒ Types::Role
A structure that contains details about the modified role.
13294 13295 13296 13297 13298 |
# File 'lib/aws-sdk-iam/types.rb', line 13294 class UpdateRoleDescriptionResponse < Struct.new( :role) SENSITIVE = [] include Aws::Structure end |