Class: Aws::IAM::Types::UpdateSSHPublicKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::UpdateSSHPublicKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ssh_public_key_id ⇒ String
The unique identifier for the SSH public key.
-
#status ⇒ String
The status to assign to the SSH public key.
-
#user_name ⇒ String
The name of the IAM user associated with the SSH public key.
Instance Attribute Details
#ssh_public_key_id ⇒ String
The unique identifier for the SSH public key.
This parameter allows (through its [regex pattern]) a string of characters that can consist of any upper or lowercased letter or digit.
12730 12731 12732 12733 12734 12735 12736 |
# File 'lib/aws-sdk-iam/types.rb', line 12730 class UpdateSSHPublicKeyRequest < Struct.new( :user_name, :ssh_public_key_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status to assign to the SSH public key. Active means that the key can be used for authentication with an CodeCommit repository. Inactive means that the key cannot be used.
12730 12731 12732 12733 12734 12735 12736 |
# File 'lib/aws-sdk-iam/types.rb', line 12730 class UpdateSSHPublicKeyRequest < Struct.new( :user_name, :ssh_public_key_id, :status) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the IAM user associated with the SSH public key.
This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
12730 12731 12732 12733 12734 12735 12736 |
# File 'lib/aws-sdk-iam/types.rb', line 12730 class UpdateSSHPublicKeyRequest < Struct.new( :user_name, :ssh_public_key_id, :status) SENSITIVE = [] include Aws::Structure end |