Class: Aws::IAM::Types::UploadServerCertificateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::UploadServerCertificateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:private_key]
Instance Attribute Summary collapse
-
#certificate_body ⇒ String
The contents of the public key certificate in PEM-encoded format.
-
#certificate_chain ⇒ String
The contents of the certificate chain.
-
#path ⇒ String
The path for the server certificate.
-
#private_key ⇒ String
The contents of the private key in PEM-encoded format.
-
#server_certificate_name ⇒ String
The name for the server certificate.
-
#tags ⇒ Array<Types::Tag>
A list of tags that you want to attach to the new IAM server certificate resource.
Instance Attribute Details
#certificate_body ⇒ String
The contents of the public key certificate in PEM-encoded format.
The [regex pattern] used to validate this parameter is a string of characters consisting of the following:
-
Any printable ASCII character ranging from the space character (
\u0020) through the end of the ASCII character range -
The printable characters in the Basic Latin and Latin-1 Supplement character set (through
\u00FF) -
The special characters tab (
\u0009), line feed (\u000A), and carriage return (\u000D)
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |
#certificate_chain ⇒ String
The contents of the certificate chain. This is typically a concatenation of the PEM-encoded public key certificates of the chain.
The [regex pattern] used to validate this parameter is a string of characters consisting of the following:
-
Any printable ASCII character ranging from the space character (
\u0020) through the end of the ASCII character range -
The printable characters in the Basic Latin and Latin-1 Supplement character set (through
\u00FF) -
The special characters tab (
\u0009), line feed (\u000A), and carriage return (\u000D)
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |
#path ⇒ String
The path for the server certificate. For more information about paths, see [IAM identifiers] in the *IAM User Guide*.
This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its [regex pattern]) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.
<note markdown=“1”> If you are uploading a server certificate specifically for use with Amazon CloudFront distributions, you must specify a path using the path parameter. The path must begin with /cloudfront and must include a trailing slash (for example, /cloudfront/test/).
</note>
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html [2]: wikipedia.org/wiki/regex
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |
#private_key ⇒ String
The contents of the private key in PEM-encoded format.
The [regex pattern] used to validate this parameter is a string of characters consisting of the following:
-
Any printable ASCII character ranging from the space character (
\u0020) through the end of the ASCII character range -
The printable characters in the Basic Latin and Latin-1 Supplement character set (through
\u00FF) -
The special characters tab (
\u0009), line feed (\u000A), and carriage return (\u000D)
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |
#server_certificate_name ⇒ String
The name for the server certificate. Do not include the path in this value. The name of the certificate cannot contain any spaces.
This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that you want to attach to the new IAM server certificate resource. Each tag consists of a key name and an associated value. For more information about tagging, see [Tagging IAM resources] in the *IAM User Guide*.
<note markdown=“1”> If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created.
</note>
13096 13097 13098 13099 13100 13101 13102 13103 13104 13105 |
# File 'lib/aws-sdk-iam/types.rb', line 13096 class UploadServerCertificateRequest < Struct.new( :path, :server_certificate_name, :certificate_body, :private_key, :certificate_chain, :tags) SENSITIVE = [:private_key] include Aws::Structure end |