Class: Aws::IAM::Types::UploadServerCertificateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains the response to a successful UploadServerCertificate request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#server_certificate_metadataTypes::ServerCertificateMetadata

The meta information of the uploaded server certificate without its certificate body, certificate chain, and private key.



13861
13862
13863
13864
13865
13866
# File 'lib/aws-sdk-iam/types.rb', line 13861

class UploadServerCertificateResponse < Struct.new(
  :server_certificate_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are attached to the new IAM server certificate. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



13861
13862
13863
13864
13865
13866
# File 'lib/aws-sdk-iam/types.rb', line 13861

class UploadServerCertificateResponse < Struct.new(
  :server_certificate_metadata,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end