Class: Aws::IAM::Types::UserDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about an IAM user, including all the user's policies and all the IAM groups the user is in.

This data type is used as a response element in the GetAccountAuthorizationDetails operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN). ARNs are unique identifiers for Amazon Web Services resources.

For more information about ARNs, go to Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#attached_managed_policiesArray<Types::AttachedPolicy>

A list of the managed policies attached to the user.

Returns:



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#create_dateTime

The date and time, in ISO 8601 date-time format, when the user was created.

Returns:

  • (Time)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#group_listArray<String>

A list of IAM groups that the user is in.

Returns:

  • (Array<String>)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The path to the user. For more information about paths, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#permissions_boundaryTypes::AttachedPermissionsBoundary

The ARN of the policy used to set the permissions boundary for the user.

For more information about permissions boundaries, see Permissions boundaries for IAM identities in the IAM User Guide.



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are associated with the user. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The stable and unique string identifying the user. For more information about IDs, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The friendly name identifying the user.

Returns:

  • (String)


13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_policy_listArray<Types::PolicyDetail>

A list of the inline policies embedded in the user.

Returns:



13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
# File 'lib/aws-sdk-iam/types.rb', line 13643

class UserDetail < Struct.new(
  :path,
  :user_name,
  :user_id,
  :arn,
  :create_date,
  :user_policy_list,
  :group_list,
  :attached_managed_policies,
  :permissions_boundary,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end