Class: Aws::IAM::Types::VirtualMFADevice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about a virtual MFA device.

Constant Summary collapse

SENSITIVE =
[:base_32_string_seed, :qr_code_png]

Instance Attribute Summary collapse

Instance Attribute Details

#base_32_string_seedString

The base32 seed defined as specified in [RFC3548][1]. The Base32StringSeed is base32-encoded.

[1]: tools.ietf.org/html/rfc3548.txt



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#enable_dateTime

The date and time on which the virtual MFA device was enabled.



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#qr_code_pngString

A QR code PNG image that encodes ‘otpauth://totp/$virtualMFADeviceName@$AccountName?secret=$Base32String` where `$virtualMFADeviceName` is one of the create call arguments. AccountName is the user name if set (otherwise, the account ID otherwise), and Base32String is the seed in base32 format. The Base32String value is base64-encoded.



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#serial_numberString

The serial number associated with VirtualMFADevice.



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are attached to the virtual MFA device. For more information about tagging, see [Tagging IAM resources][1] in the *IAM User Guide*.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#userTypes::User

The IAM user associated with this virtual MFA device.



13487
13488
13489
13490
13491
13492
13493
13494
13495
13496
# File 'lib/aws-sdk-iam/types.rb', line 13487

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end