Class: Aws::IAM::User

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/user.rbs,
lib/aws-sdk-iam/user.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ User #initialize(options = {}) ⇒ User

Returns a new instance of User.

Overloads:

  • #initialize(name, options = {}) ⇒ User

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ User

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/user.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#access_key(id) ⇒ AccessKey

Parameters:

  • id (String)

Returns:



139
# File 'sig/user.rbs', line 139

def access_key: (String id) -> AccessKey

#access_keys(options = {}) ⇒ AccessKey::Collection

Examples:

Request syntax with placeholder values


user.access_keys()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



142
# File 'sig/user.rbs', line 142

def access_keys: (

#add_group(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


user.add_group({
  group_name: "groupNameType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :group_name (required, String)

    The name of the group to update.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (EmptyStructure)


63
# File 'sig/user.rbs', line 63

def add_group: (

#arnString

The Amazon Resource Name (ARN) that identifies the user. For more information about ARNs and how to use ARNs in policies, see IAM Identifiers in the IAM User Guide.

Returns:

  • (String)


28
# File 'sig/user.rbs', line 28

def arn: () -> ::String

#attach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


user.attach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to attach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


69
# File 'sig/user.rbs', line 69

def attach_policy: (

#attached_policies(options = {}) ⇒ Policy::Collection

Examples:

Request syntax with placeholder values


attached_policies = user.attached_policies({
  path_prefix: "policyPathType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :path_prefix (String)

    The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all policies.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

Returns:



147
# File 'sig/user.rbs', line 147

def attached_policies: (

#clientClient

Returns:



145
# File 'lib/aws-sdk-iam/user.rb', line 145

def client: () -> Client

#create(options = {}) ⇒ User

Examples:

Request syntax with placeholder values


user = user.create({
  path: "pathType",
  permissions_boundary: "arnType",
  tags: [
    {
      key: "tagKeyType", # required
      value: "tagValueType", # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :path (String)

    The path for the user name. For more information about paths, see IAM identifiers in the IAM User Guide.

    This parameter is optional. If it is not included, it defaults to a slash (/).

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

  • :permissions_boundary (String)

    The ARN of the managed policy that is used to set the permissions boundary for the user.

    A permissions boundary policy defines the maximum permissions that identity-based policies can grant to an entity, but does not grant permissions. Permissions boundaries do not define the maximum permissions that a resource-based policy can grant to an entity. To learn more, see Permissions boundaries for IAM entities in the IAM User Guide.

    For more information about policy types, see Policy types in the IAM User Guide.

  • :tags (Array<Types::Tag>)

    A list of tags that you want to attach to the new user. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created.

Returns:



75
# File 'sig/user.rbs', line 75

def create: (

#create_access_key_pair(options = {}) ⇒ AccessKeyPair

Examples:

Request syntax with placeholder values


user.create_access_key_pair()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



88
# File 'sig/user.rbs', line 88

def create_access_key_pair: (

#create_dateTime

The date and time, in ISO 8601 date-time format, when the user was created.

Returns:

  • (Time)


31
# File 'sig/user.rbs', line 31

def create_date: () -> ::Time

#create_login_profile(options = {}) ⇒ LoginProfile

Examples:

Request syntax with placeholder values


loginprofile = user.({
  password: "passwordType",
  password_reset_required: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :password (String)

    The new password for the user.

    This parameter must be omitted when you make the request with an AssumeRoot session. It is required in all other cases.

    The regex pattern that is used to validate this parameter is a string of characters. That string can include almost any printable ASCII character from the space (\u0020) through the end of the ASCII character range (\u00FF). You can also include the tab (\u0009), line feed (\u000A), and carriage return (\u000D) characters. Any of these characters are valid in a password. However, many tools, such as the Amazon Web Services Management Console, might restrict the ability to type certain characters because they have special meaning within that tool.

  • :password_reset_required (Boolean)

    Specifies whether the user is required to set a new password on next sign-in.

Returns:



93
# File 'sig/user.rbs', line 93

def create_login_profile: (

#create_policy(options = {}) ⇒ UserPolicy

Examples:

Request syntax with placeholder values


userpolicy = user.create_policy({
  policy_name: "policyNameType", # required
  policy_document: "policyDocumentType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_name (required, String)

    The name of the policy document.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

  • :policy_document (required, String)

    The policy document.

    You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.

    The regex pattern used to validate this parameter is a string of characters consisting of the following:

    • Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range

    • The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)

    • The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)

Returns:



100
# File 'sig/user.rbs', line 100

def create_policy: (

#dataTypes::User

Returns the data for this Aws::IAM::User. Calls Client#get_user if #data_loaded? is false.

Returns:



49
# File 'sig/user.rbs', line 49

def data: () -> Types::User

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



52
# File 'sig/user.rbs', line 52

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


user.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


107
# File 'sig/user.rbs', line 107

def delete: (

#detach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


user.detach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to detach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


112
# File 'sig/user.rbs', line 112

def detach_policy: (

#enable_mfa(options = {}) ⇒ MfaDevice

Examples:

Request syntax with placeholder values


mfadevice = user.enable_mfa({
  serial_number: "serialNumberType", # required
  authentication_code_1: "authenticationCodeType", # required
  authentication_code_2: "authenticationCodeType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :serial_number (required, String)

    The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the device ARN.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: =,.@:/-

  • :authentication_code_1 (required, String)

    An authentication code emitted by the device.

    The format for this parameter is a string of six digits.

    Submit your request immediately after generating the authentication codes. If you generate the codes and then wait too long to submit the request, the MFA device successfully associates with the user but the MFA device becomes out of sync. This happens because time-based one-time passwords (TOTP) expire after a short period of time. If this happens, you can resync the device.

  • :authentication_code_2 (required, String)

    A subsequent authentication code emitted by the device.

    The format for this parameter is a string of six digits.

    Submit your request immediately after generating the authentication codes. If you generate the codes and then wait too long to submit the request, the MFA device successfully associates with the user but the MFA device becomes out of sync. This happens because time-based one-time passwords (TOTP) expire after a short period of time. If this happens, you can resync the device.

Returns:



118
# File 'sig/user.rbs', line 118

def enable_mfa: (

#exists?(options = {}) ⇒ Boolean

Returns true if the User exists.

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (Boolean)

    Returns true if the User exists.



55
56
# File 'sig/user.rbs', line 55

def exists?: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) -> bool
| (?Hash[Symbol, untyped]) -> bool

#groups(options = {}) ⇒ Group::Collection

Examples:

Request syntax with placeholder values


user.groups()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



153
# File 'sig/user.rbs', line 153

def groups: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


948
949
950
# File 'lib/aws-sdk-iam/user.rb', line 948

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::User. Returns self making it possible to chain methods.

user.reload.data

Returns:

  • (self)


45
# File 'sig/user.rbs', line 45

def load: () -> self

#login_profileLoginProfile

Returns:



158
# File 'sig/user.rbs', line 158

def login_profile: () -> LoginProfile

#mfa_device(serial_number) ⇒ MfaDevice

Parameters:

  • serial_number (String)

Returns:



161
# File 'sig/user.rbs', line 161

def mfa_device: (String serial_number) -> MfaDevice

#mfa_devices(options = {}) ⇒ MfaDevice::Collection

Examples:

Request syntax with placeholder values


user.mfa_devices()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



164
# File 'sig/user.rbs', line 164

def mfa_devices: (

#nameString Also known as: user_name

Returns:

  • (String)


18
# File 'sig/user.rbs', line 18

def name: () -> String

#password_last_usedTime

The date and time, in ISO 8601 date-time format, when the user's password was last used to sign in to an Amazon Web Services website. For a list of Amazon Web Services websites that capture a user's last sign-in time, see the Credential reports topic in the IAM User Guide. If a password is used more than once in a five-minute span, only the first use is returned in this field. If the field is null (no value), then it indicates that they never signed in with a password. This can be because:

  • The user never had a password.

  • A password exists but has not been used since IAM started tracking this information on October 20, 2014.

A null value does not mean that the user never had a password. Also, if the user does not currently have a password but had one in the past, then this field contains the date and time the most recent password was used.

This value is returned only in the GetUser and ListUsers operations.

Returns:

  • (Time)


34
# File 'sig/user.rbs', line 34

def password_last_used: () -> ::Time

#pathString

The path to the user. For more information about paths, see IAM identifiers in the IAM User Guide.

The ARN of the policy used to set the permissions boundary for the user.

Returns:

  • (String)


22
# File 'sig/user.rbs', line 22

def path: () -> ::String

#permissions_boundaryTypes::AttachedPermissionsBoundary

For more information about permissions boundaries, see Permissions boundaries for IAM identities in the IAM User Guide.



37
# File 'sig/user.rbs', line 37

def permissions_boundary: () -> Types::AttachedPermissionsBoundary

#policies(options = {}) ⇒ UserPolicy::Collection

Examples:

Request syntax with placeholder values


user.policies()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



169
# File 'sig/user.rbs', line 169

def policies: (

#policy(name) ⇒ UserPolicy

Parameters:

  • name (String)

Returns:



174
# File 'sig/user.rbs', line 174

def policy: (String name) -> UserPolicy

#remove_group(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


user.remove_group({
  group_name: "groupNameType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :group_name (required, String)

    The name of the group to update.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (EmptyStructure)


126
# File 'sig/user.rbs', line 126

def remove_group: (

#signing_certificate(id) ⇒ SigningCertificate

Parameters:

  • id (String)

Returns:



177
# File 'sig/user.rbs', line 177

def signing_certificate: (String id) -> SigningCertificate

#signing_certificates(options = {}) ⇒ SigningCertificate::Collection

Examples:

Request syntax with placeholder values


user.signing_certificates()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



180
# File 'sig/user.rbs', line 180

def signing_certificates: (

#tagsArray<Types::Tag>

A list of tags that are associated with the user. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



40
# File 'sig/user.rbs', line 40

def tags: () -> ::Array[Types::Tag]

#update(options = {}) ⇒ User

Examples:

Request syntax with placeholder values


user = user.update({
  new_path: "pathType",
  new_user_name: "userNameType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :new_path (String)

    New path for the IAM user. Include this parameter only if you're changing the user's path.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

  • :new_user_name (String)

    New name for the user. Include this parameter only if you're changing the user's name.

    IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".

Returns:



132
# File 'sig/user.rbs', line 132

def update: (

#user_idString

The stable and unique string identifying the user. For more information about IDs, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


25
# File 'sig/user.rbs', line 25

def user_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/aws-sdk-iam/user.rb', line 292

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end

#wait_until_exists(options = {}, &block) ⇒ User

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :max_attempts (Integer) — default: 20
  • :delay (Float) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)

Returns:



59
60
# File 'sig/user.rbs', line 59

def wait_until_exists: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> User
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> User