Class: Aws::IAM::VirtualMfaDevice
- Inherits:
-
Object
- Object
- Aws::IAM::VirtualMfaDevice
- Extended by:
- Deprecations
- Defined in:
- sig/virtual_mfa_device.rbs,
lib/aws-sdk-iam/virtual_mfa_device.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#base_32_string_seed ⇒ String
The base32 seed defined as specified in [RFC3548][1].
-
#enable_date ⇒ Time
The date and time on which the virtual MFA device was enabled.
-
#qr_code_png ⇒ String
A QR code PNG image that encodes
otpauth://totp/$virtualMFADeviceName@$AccountName?secret=$Base32Stringwhere$virtualMFADeviceNameis one of the create call arguments. - #serial_number ⇒ String
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the virtual MFA device.
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #user ⇒ User?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::VirtualMFADevice
Returns the data for this VirtualMfaDevice.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ VirtualMfaDevice
constructor
A new instance of VirtualMfaDevice.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(serial_number, options = {}) ⇒ VirtualMfaDevice #initialize(options = {}) ⇒ VirtualMfaDevice
Returns a new instance of VirtualMfaDevice.
13 14 15 |
# File 'sig/virtual_mfa_device.rbs', line 13
def initialize: (String serial_number, Hash[Symbol, untyped] options) -> void
| (serial_number: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#base_32_string_seed ⇒ String
The base32 seed defined as specified in RFC3548. The
Base32StringSeed is base32-encoded.
21 |
# File 'sig/virtual_mfa_device.rbs', line 21
def base_32_string_seed: () -> ::String
|
#client ⇒ Client
80 |
# File 'lib/aws-sdk-iam/virtual_mfa_device.rb', line 80
def client: () -> Client
|
#data ⇒ Types::VirtualMFADevice
Returns the data for this Aws::IAM::VirtualMfaDevice.
36 |
# File 'sig/virtual_mfa_device.rbs', line 36
def data: () -> Types::VirtualMFADevice
|
#data_loaded? ⇒ Boolean
39 |
# File 'sig/virtual_mfa_device.rbs', line 39
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
43 |
# File 'sig/virtual_mfa_device.rbs', line 43
def delete: (
|
#enable_date ⇒ Time
The date and time on which the virtual MFA device was enabled.
27 |
# File 'sig/virtual_mfa_device.rbs', line 27
def enable_date: () -> ::Time
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
237 238 239 |
# File 'lib/aws-sdk-iam/virtual_mfa_device.rb', line 237 def identifiers { serial_number: @serial_number } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
86 87 88 89 |
# File 'lib/aws-sdk-iam/virtual_mfa_device.rb', line 86 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#qr_code_png ⇒ String
A QR code PNG image that encodes
otpauth://totp/$virtualMFADeviceName@$AccountName?secret=$Base32String
where $virtualMFADeviceName is one of the create call arguments.
AccountName is the user name if set (otherwise, the account ID
otherwise), and Base32String is the seed in base32 format. The
Base32String value is base64-encoded.
24 |
# File 'sig/virtual_mfa_device.rbs', line 24
def qr_code_png: () -> ::String
|
#serial_number ⇒ String
18 |
# File 'sig/virtual_mfa_device.rbs', line 18
def serial_number: () -> String
|
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the virtual MFA device. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
30 |
# File 'sig/virtual_mfa_device.rbs', line 30
def tags: () -> ::Array[Types::Tag]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/aws-sdk-iam/virtual_mfa_device.rb', line 187 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |