Class: Aws::IAM::Waiters::InstanceProfileExists
- Inherits:
-
Object
- Object
- Aws::IAM::Waiters::InstanceProfileExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-iam/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InstanceProfileExists
constructor
A new instance of InstanceProfileExists.
-
#wait(params = {}) ⇒ Types::GetInstanceProfileResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InstanceProfileExists
Returns a new instance of InstanceProfileExists.
87 88 |
# File 'lib/aws-sdk-iam/waiters.rb', line 87
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
117 118 119 |
# File 'lib/aws-sdk-iam/waiters.rb', line 117 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetInstanceProfileResponse
Returns a response object which responds to the following methods:
- #instance_profile => Types::InstanceProfile
112 |
# File 'lib/aws-sdk-iam/waiters.rb', line 112
def wait: (
|