Class: Aws::IAM::Waiters::PolicyExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-iam/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ PolicyExists

Returns a new instance of PolicyExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 20
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


129
130
# File 'lib/aws-sdk-iam/waiters.rb', line 129

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



159
160
161
# File 'lib/aws-sdk-iam/waiters.rb', line 159

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetPolicyResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the managed policy that you want information about.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:



154
# File 'lib/aws-sdk-iam/waiters.rb', line 154

def wait: (