Class: Aws::IAM::Waiters::RoleExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-iam/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ RoleExists

Returns a new instance of RoleExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 20
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


171
172
# File 'lib/aws-sdk-iam/waiters.rb', line 171

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



201
202
203
# File 'lib/aws-sdk-iam/waiters.rb', line 201

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRoleResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :role_name (required, String)

    The name of the IAM role to get information about.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:



196
# File 'lib/aws-sdk-iam/waiters.rb', line 196

def wait: (