Class: Aws::IAM::Waiters::UserExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-iam/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ UserExists

Returns a new instance of UserExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 20
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


213
214
# File 'lib/aws-sdk-iam/waiters.rb', line 213

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



243
244
245
# File 'lib/aws-sdk-iam/waiters.rb', line 243

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetUserResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :user_name (String)

    The name of the user to get information about.

    This parameter is optional. If it is not included, it defaults to the user making the request. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:



238
# File 'lib/aws-sdk-iam/waiters.rb', line 238

def wait: (