Class: Aws::IAM::Group

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/group.rbs,
lib/aws-sdk-iam/group.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ Group #initialize(options = {}) ⇒ Group

Returns a new instance of Group.

Overloads:

  • #initialize(name, options = {}) ⇒ Group

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Group

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/group.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#add_user(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


group.add_user({
  user_name: "existingUserNameType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :user_name (required, String)

    The name of the user to add.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (EmptyStructure)


47
# File 'sig/group.rbs', line 47

def add_user: (

#arnString

The Amazon Resource Name (ARN) specifying the group. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


28
# File 'sig/group.rbs', line 28

def arn: () -> ::String

#attach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


group.attach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to attach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


53
# File 'sig/group.rbs', line 53

def attach_policy: (

#attached_policies(options = {}) ⇒ Policy::Collection

Examples:

Request syntax with placeholder values


attached_policies = group.attached_policies({
  path_prefix: "policyPathType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :path_prefix (String)

    The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all policies.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

Returns:



96
# File 'sig/group.rbs', line 96

def attached_policies: (

#clientClient

Returns:



87
# File 'lib/aws-sdk-iam/group.rb', line 87

def client: () -> Client

#create(options = {}) ⇒ Group

Examples:

Request syntax with placeholder values


group = group.create({
  path: "pathType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :path (String)

    The path to the group. For more information about paths, see IAM identifiers in the IAM User Guide.

    This parameter is optional. If it is not included, it defaults to a slash (/).

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

Returns:



59
# File 'sig/group.rbs', line 59

def create: (

#create_dateTime

The date and time, in ISO 8601 date-time format, when the group was created.

Returns:

  • (Time)


31
# File 'sig/group.rbs', line 31

def create_date: () -> ::Time

#create_policy(options = {}) ⇒ GroupPolicy

Examples:

Request syntax with placeholder values


grouppolicy = group.create_policy({
  policy_name: "policyNameType", # required
  policy_document: "policyDocumentType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_name (required, String)

    The name of the policy document.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

  • :policy_document (required, String)

    The policy document.

    You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM.

    The regex pattern used to validate this parameter is a string of characters consisting of the following:

    • Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range

    • The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)

    • The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)

Returns:



65
# File 'sig/group.rbs', line 65

def create_policy: (

#dataTypes::Group

Returns the data for this Aws::IAM::Group. Calls Client#get_group if #data_loaded? is false.

Returns:



40
# File 'sig/group.rbs', line 40

def data: () -> Types::Group

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



43
# File 'sig/group.rbs', line 43

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


group.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


72
# File 'sig/group.rbs', line 72

def delete: (

#detach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


group.detach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to detach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


77
# File 'sig/group.rbs', line 77

def detach_policy: (

#group_idString

The stable and unique string identifying the group. For more information about IDs, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


25
# File 'sig/group.rbs', line 25

def group_id: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


574
575
576
# File 'lib/aws-sdk-iam/group.rb', line 574

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::Group. Returns self making it possible to chain methods.

group.reload.data

Returns:

  • (self)


36
# File 'sig/group.rbs', line 36

def load: () -> self

#nameString Also known as: group_name

Returns:

  • (String)


18
# File 'sig/group.rbs', line 18

def name: () -> String

#pathString

The path to the group. For more information about paths, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


22
# File 'sig/group.rbs', line 22

def path: () -> ::String

#policies(options = {}) ⇒ GroupPolicy::Collection

Examples:

Request syntax with placeholder values


group.policies()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



102
# File 'sig/group.rbs', line 102

def policies: (

#policy(name) ⇒ GroupPolicy

Parameters:

  • name (String)

Returns:



107
# File 'sig/group.rbs', line 107

def policy: (String name) -> GroupPolicy

#remove_user(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


group.remove_user({
  user_name: "existingUserNameType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :user_name (required, String)

    The name of the user to remove.

    This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

Returns:

  • (EmptyStructure)


83
# File 'sig/group.rbs', line 83

def remove_user: (

#update(options = {}) ⇒ Group

Examples:

Request syntax with placeholder values


group = group.update({
  new_path: "pathType",
  new_group_name: "groupNameType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :new_path (String)

    New path for the IAM group. Only include this if changing the group's path.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

  • :new_group_name (String)

    New name for the IAM group. Only include this if changing the group's name.

    IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".

Returns:



89
# File 'sig/group.rbs', line 89

def update: (

#users(options = {}) ⇒ User::Collection

Examples:

Request syntax with placeholder values


group.users()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



110
# File 'sig/group.rbs', line 110

def users: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/aws-sdk-iam/group.rb', line 201

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end