Class: Aws::IAM::Group
- Inherits:
-
Object
- Object
- Aws::IAM::Group
- Extended by:
- Deprecations
- Defined in:
- sig/group.rbs,
lib/aws-sdk-iam/group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the group.
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the group was created.
-
#group_id ⇒ String
The stable and unique string identifying the group.
- #name ⇒ String (also: #group_name)
-
#path ⇒ String
The path to the group.
Actions collapse
- #add_user(options = {}) ⇒ EmptyStructure
- #attach_policy(options = {}) ⇒ EmptyStructure
- #create(options = {}) ⇒ Group
- #create_policy(options = {}) ⇒ GroupPolicy
- #delete(options = {}) ⇒ EmptyStructure
- #detach_policy(options = {}) ⇒ EmptyStructure
- #remove_user(options = {}) ⇒ EmptyStructure
- #update(options = {}) ⇒ Group
Associations collapse
- #attached_policies(options = {}) ⇒ Policy::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #policies(options = {}) ⇒ GroupPolicy::Collection
- #policy(name) ⇒ GroupPolicy
- #users(options = {}) ⇒ User::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Group
Returns the data for this Group.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Group
constructor
A new instance of Group.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
Instance Method Details
#add_user(options = {}) ⇒ EmptyStructure
47 |
# File 'sig/group.rbs', line 47
def add_user: (
|
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the group. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide.
28 |
# File 'sig/group.rbs', line 28
def arn: () -> ::String
|
#attach_policy(options = {}) ⇒ EmptyStructure
53 |
# File 'sig/group.rbs', line 53
def attach_policy: (
|
#attached_policies(options = {}) ⇒ Policy::Collection
96 |
# File 'sig/group.rbs', line 96
def attached_policies: (
|
#create_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the group was created.
31 |
# File 'sig/group.rbs', line 31
def create_date: () -> ::Time
|
#data ⇒ Types::Group
Returns the data for this Aws::IAM::Group. Calls
Client#get_group if #data_loaded? is false.
40 |
# File 'sig/group.rbs', line 40
def data: () -> Types::Group
|
#data_loaded? ⇒ Boolean
43 |
# File 'sig/group.rbs', line 43
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
72 |
# File 'sig/group.rbs', line 72
def delete: (
|
#detach_policy(options = {}) ⇒ EmptyStructure
77 |
# File 'sig/group.rbs', line 77
def detach_policy: (
|
#group_id ⇒ String
The stable and unique string identifying the group. For more information about IDs, see IAM identifiers in the IAM User Guide.
25 |
# File 'sig/group.rbs', line 25
def group_id: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
574 575 576 |
# File 'lib/aws-sdk-iam/group.rb', line 574 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::Group.
Returns self making it possible to chain methods.
group.reload.data
36 |
# File 'sig/group.rbs', line 36
def load: () -> self
|
#name ⇒ String Also known as: group_name
18 |
# File 'sig/group.rbs', line 18
def name: () -> String
|
#path ⇒ String
The path to the group. For more information about paths, see IAM identifiers in the IAM User Guide.
22 |
# File 'sig/group.rbs', line 22
def path: () -> ::String
|
#policies(options = {}) ⇒ GroupPolicy::Collection
102 |
# File 'sig/group.rbs', line 102
def policies: (
|
#policy(name) ⇒ GroupPolicy
107 |
# File 'sig/group.rbs', line 107
def policy: (String name) -> GroupPolicy
|
#remove_user(options = {}) ⇒ EmptyStructure
83 |
# File 'sig/group.rbs', line 83
def remove_user: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/aws-sdk-iam/group.rb', line 201 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |