Class: Aws::IAM::InstanceProfile
- Inherits:
-
Object
- Object
- Aws::IAM::InstanceProfile
- Extended by:
- Deprecations
- Defined in:
- sig/instance_profile.rbs,
lib/aws-sdk-iam/instance_profile.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the instance profile.
-
#create_date ⇒ Time
The date when the instance profile was created.
-
#instance_profile_id ⇒ String
The stable and unique string identifying the instance profile.
- #name ⇒ String (also: #instance_profile_name)
-
#path ⇒ String
The path to the instance profile.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile.
Actions collapse
- #add_role(options = {}) ⇒ EmptyStructure
- #delete(options = {}) ⇒ EmptyStructure
- #remove_role(options = {}) ⇒ EmptyStructure
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #roles ⇒ Role::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::InstanceProfile
Returns the data for this InstanceProfile.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#exists?(options = {}) ⇒ Boolean
Returns
trueif the InstanceProfile exists. -
#initialize(*args) ⇒ InstanceProfile
constructor
A new instance of InstanceProfile.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current InstanceProfile.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
- #wait_until_exists(options = {}, &block) ⇒ InstanceProfile
Constructor Details
#initialize(name, options = {}) ⇒ InstanceProfile #initialize(options = {}) ⇒ InstanceProfile
Returns a new instance of InstanceProfile.
13 14 15 |
# File 'sig/instance_profile.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#add_role(options = {}) ⇒ EmptyStructure
57 |
# File 'sig/instance_profile.rbs', line 57
def add_role: (
|
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the instance profile. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide.
28 |
# File 'sig/instance_profile.rbs', line 28
def arn: () -> ::String
|
#create_date ⇒ Time
The date when the instance profile was created.
31 |
# File 'sig/instance_profile.rbs', line 31
def create_date: () -> ::Time
|
#data ⇒ Types::InstanceProfile
Returns the data for this Aws::IAM::InstanceProfile. Calls
Client#get_instance_profile if #data_loaded? is false.
43 |
# File 'sig/instance_profile.rbs', line 43
def data: () -> Types::InstanceProfile
|
#data_loaded? ⇒ Boolean
46 |
# File 'sig/instance_profile.rbs', line 46
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
63 |
# File 'sig/instance_profile.rbs', line 63
def delete: (
|
#exists?(options = {}) ⇒ Boolean
Returns true if the InstanceProfile exists.
49 50 |
# File 'sig/instance_profile.rbs', line 49
def exists?: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) -> bool
| (?Hash[Symbol, untyped]) -> bool
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
344 345 346 |
# File 'lib/aws-sdk-iam/instance_profile.rb', line 344 def identifiers { name: @name } end |
#instance_profile_id ⇒ String
The stable and unique string identifying the instance profile. For more information about IDs, see IAM identifiers in the IAM User Guide.
25 |
# File 'sig/instance_profile.rbs', line 25
def instance_profile_id: () -> ::String
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::InstanceProfile.
Returns self making it possible to chain methods.
instance_profile.reload.data
39 |
# File 'sig/instance_profile.rbs', line 39
def load: () -> self
|
#name ⇒ String Also known as: instance_profile_name
18 |
# File 'sig/instance_profile.rbs', line 18
def name: () -> String
|
#path ⇒ String
The path to the instance profile. For more information about paths, see IAM identifiers in the IAM User Guide.
22 |
# File 'sig/instance_profile.rbs', line 22
def path: () -> ::String
|
#remove_role(options = {}) ⇒ EmptyStructure
68 |
# File 'sig/instance_profile.rbs', line 68
def remove_role: (
|
#roles ⇒ Role::Collection
74 |
# File 'sig/instance_profile.rbs', line 74
def roles: () -> Role::Collection
|
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
34 |
# File 'sig/instance_profile.rbs', line 34
def tags: () -> ::Array[Types::Tag]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-iam/instance_profile.rb', line 241 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |
#wait_until_exists(options = {}, &block) ⇒ InstanceProfile
53 54 |
# File 'sig/instance_profile.rbs', line 53
def wait_until_exists: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> InstanceProfile
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> InstanceProfile
|