Class: Aws::IAM::PolicyVersion
- Inherits:
-
Object
- Object
- Aws::IAM::PolicyVersion
- Extended by:
- Deprecations
- Defined in:
- sig/policy_version.rbs,
lib/aws-sdk-iam/policy_version.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #arn ⇒ String
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the policy version was created.
-
#document ⇒ String
The policy document.
-
#is_default_version ⇒ Boolean
Specifies whether the policy version is set as the policy's default version.
- #version_id ⇒ String
Actions collapse
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #set_as_default(options = {}) ⇒ EmptyStructure
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::PolicyVersion
Returns the data for this PolicyVersion.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ PolicyVersion
constructor
A new instance of PolicyVersion.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current PolicyVersion.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(arn, version_id, options = {}) ⇒ PolicyVersion #initialize(options = {}) ⇒ PolicyVersion
Returns a new instance of PolicyVersion.
13 14 15 |
# File 'sig/policy_version.rbs', line 13
def initialize: (String arn, String version_id, Hash[Symbol, untyped] options) -> void
| (arn: String, version_id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#arn ⇒ String
18 |
# File 'sig/policy_version.rbs', line 18
def arn: () -> String
|
#create_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the policy version was created.
30 |
# File 'sig/policy_version.rbs', line 30
def create_date: () -> ::Time
|
#data ⇒ Types::PolicyVersion
Returns the data for this Aws::IAM::PolicyVersion. Calls
Client#get_policy_version if #data_loaded? is false.
39 |
# File 'sig/policy_version.rbs', line 39
def data: () -> Types::PolicyVersion
|
#data_loaded? ⇒ Boolean
42 |
# File 'sig/policy_version.rbs', line 42
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
46 |
# File 'sig/policy_version.rbs', line 46
def delete: (
|
#document ⇒ String
The policy document.
The policy document is returned in the response to the GetPolicyVersion and GetAccountAuthorizationDetails operations. It is not returned in the response to the CreatePolicyVersion or ListPolicyVersions operations.
The policy document returned in this structure is URL-encoded
compliant with RFC 3986. You can use a URL decoding method to
convert the policy back to plain JSON text. For example, if you use
Java, you can use the decode method of the java.net.URLDecoder
utility class in the Java SDK. Other languages and SDKs provide
similar functionality.
24 |
# File 'sig/policy_version.rbs', line 24
def document: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
264 265 266 267 268 269 |
# File 'lib/aws-sdk-iam/policy_version.rb', line 264 def identifiers { arn: @arn, version_id: @version_id } end |
#is_default_version ⇒ Boolean
Specifies whether the policy version is set as the policy's default version.
27 |
# File 'sig/policy_version.rbs', line 27
def is_default_version: () -> bool
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::PolicyVersion.
Returns self making it possible to chain methods.
policy_version.reload.data
35 |
# File 'sig/policy_version.rbs', line 35
def load: () -> self
|
#set_as_default(options = {}) ⇒ EmptyStructure
51 |
# File 'sig/policy_version.rbs', line 51
def set_as_default: (
|
#version_id ⇒ String
21 |
# File 'sig/policy_version.rbs', line 21
def version_id: () -> String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/aws-sdk-iam/policy_version.rb', line 209 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |