Class: Aws::IAM::Resource
- Inherits:
-
Object
- Object
- Aws::IAM::Resource
- Defined in:
- sig/resource.rbs,
lib/aws-sdk-iam/customizations/resource.rb,
lib/aws-sdk-iam/resource.rb
Overview
This class provides a resource oriented interface for IAM. To create a resource object:
resource = Aws::IAM::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations.
If you do not pass :client, a default client will be constructed.
client = Aws::IAM::Client.new(region: 'us-west-2')
resource = Aws::IAM::Resource.new(client: client)
Actions collapse
- #change_password(options = {}) ⇒ EmptyStructure
- #create_account_alias(options = {}) ⇒ EmptyStructure
- #create_account_password_policy(options = {}) ⇒ AccountPasswordPolicy
- #create_group(options = {}) ⇒ Group
- #create_instance_profile(options = {}) ⇒ InstanceProfile
- #create_policy(options = {}) ⇒ Policy
- #create_role(options = {}) ⇒ Role
- #create_saml_provider(options = {}) ⇒ SamlProvider
- #create_server_certificate(options = {}) ⇒ ServerCertificate
- #create_signing_certificate(options = {}) ⇒ SigningCertificate
- #create_user(options = {}) ⇒ User
- #create_virtual_mfa_device(options = {}) ⇒ VirtualMfaDevice
Associations collapse
- #account_password_policy ⇒ AccountPasswordPolicy
- #account_summary ⇒ AccountSummary
- #current_user ⇒ CurrentUser
- #group(name) ⇒ Group
- #groups(options = {}) ⇒ Group::Collection
- #instance_profile(name) ⇒ InstanceProfile
- #instance_profiles(options = {}) ⇒ InstanceProfile::Collection
- #policies(options = {}) ⇒ Policy::Collection
- #policy(arn) ⇒ Policy
- #role(name) ⇒ Role
- #roles(options = {}) ⇒ Role::Collection
- #saml_provider(arn) ⇒ SamlProvider
- #saml_providers(options = {}) ⇒ SamlProvider::Collection
- #server_certificate(name) ⇒ ServerCertificate
- #server_certificates(options = {}) ⇒ ServerCertificate::Collection
- #user(name) ⇒ User
- #users(options = {}) ⇒ User::Collection
- #virtual_mfa_device(serial_number) ⇒ VirtualMfaDevice
- #virtual_mfa_devices(options = {}) ⇒ VirtualMfaDevice::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#delete_account_alias ⇒ Seahorse::Client::Response, false
Returns the response from Client#delete_account_alias if an alias was deleted.
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
#initialize(options = {}) ⇒ Resource
Returns a new instance of Resource.
13 |
# File 'sig/resource.rbs', line 13
def initialize: (
|
Instance Method Details
#account_password_policy ⇒ AccountPasswordPolicy
229 |
# File 'sig/resource.rbs', line 229
def account_password_policy: () -> AccountPasswordPolicy
|
#account_summary ⇒ AccountSummary
232 |
# File 'sig/resource.rbs', line 232
def account_summary: () -> AccountSummary
|
#change_password(options = {}) ⇒ EmptyStructure
84 |
# File 'sig/resource.rbs', line 84
def change_password: (
|
#create_account_alias(options = {}) ⇒ EmptyStructure
91 |
# File 'sig/resource.rbs', line 91
def create_account_alias: (
|
#create_account_password_policy(options = {}) ⇒ AccountPasswordPolicy
97 |
# File 'sig/resource.rbs', line 97
def create_account_password_policy: (
|
#create_instance_profile(options = {}) ⇒ InstanceProfile
118 |
# File 'sig/resource.rbs', line 118
def create_instance_profile: (
|
#create_saml_provider(options = {}) ⇒ SamlProvider
163 |
# File 'sig/resource.rbs', line 163
def create_saml_provider: (
|
#create_server_certificate(options = {}) ⇒ ServerCertificate
178 |
# File 'sig/resource.rbs', line 178
def create_server_certificate: (
|
#create_signing_certificate(options = {}) ⇒ SigningCertificate
194 |
# File 'sig/resource.rbs', line 194
def create_signing_certificate: (
|
#create_virtual_mfa_device(options = {}) ⇒ VirtualMfaDevice
215 |
# File 'sig/resource.rbs', line 215
def create_virtual_mfa_device: (
|
#current_user ⇒ CurrentUser
235 |
# File 'sig/resource.rbs', line 235
def current_user: () -> CurrentUser
|
#delete_account_alias ⇒ Seahorse::Client::Response, false
Returns the response
from Client#delete_account_alias if an alias was deleted.
Returns false if this account had no alias to remove.
11 12 13 14 15 16 17 18 19 |
# File 'lib/aws-sdk-iam/customizations/resource.rb', line 11 def delete_account_alias Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do if name = @client.list_account_aliases.account_aliases.first @client.delete_account_alias(account_alias: name) else false end end end |
#instance_profile(name) ⇒ InstanceProfile
247 |
# File 'sig/resource.rbs', line 247
def instance_profile: (String name) -> InstanceProfile
|
#instance_profiles(options = {}) ⇒ InstanceProfile::Collection
250 |
# File 'sig/resource.rbs', line 250
def instance_profiles: (
|
#policies(options = {}) ⇒ Policy::Collection
256 |
# File 'sig/resource.rbs', line 256
def policies: (
|
#saml_provider(arn) ⇒ SamlProvider
277 |
# File 'sig/resource.rbs', line 277
def saml_provider: (String arn) -> SamlProvider
|
#saml_providers(options = {}) ⇒ SamlProvider::Collection
280 |
# File 'sig/resource.rbs', line 280
def saml_providers: (
|
#server_certificate(name) ⇒ ServerCertificate
285 |
# File 'sig/resource.rbs', line 285
def server_certificate: (String name) -> ServerCertificate
|
#server_certificates(options = {}) ⇒ ServerCertificate::Collection
288 |
# File 'sig/resource.rbs', line 288
def server_certificates: (
|
#virtual_mfa_device(serial_number) ⇒ VirtualMfaDevice
303 |
# File 'sig/resource.rbs', line 303
def virtual_mfa_device: (String serial_number) -> VirtualMfaDevice
|
#virtual_mfa_devices(options = {}) ⇒ VirtualMfaDevice::Collection
306 |
# File 'sig/resource.rbs', line 306
def virtual_mfa_devices: (
|