Class: Aws::IAM::Role

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/role.rbs,
lib/aws-sdk-iam/role.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ Role #initialize(options = {}) ⇒ Role

Returns a new instance of Role.

Overloads:

  • #initialize(name, options = {}) ⇒ Role

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Role

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/role.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#arnString

The Amazon Resource Name (ARN) specifying the role. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide guide.

Returns:

  • (String)


28
# File 'sig/role.rbs', line 28

def arn: () -> ::String

#assume_role_policyAssumeRolePolicy

Returns:



82
# File 'sig/role.rbs', line 82

def assume_role_policy: () -> AssumeRolePolicy

#assume_role_policy_documentString

The policy that grants an entity permission to assume the role.

Returns:

  • (String)


34
# File 'sig/role.rbs', line 34

def assume_role_policy_document: () -> ::String

#attach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


role.attach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to attach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


65
# File 'sig/role.rbs', line 65

def attach_policy: (

#attached_policies(options = {}) ⇒ Policy::Collection

Examples:

Request syntax with placeholder values


attached_policies = role.attached_policies({
  path_prefix: "policyPathType",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :path_prefix (String)

    The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all policies.

    This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters.

Returns:



85
# File 'sig/role.rbs', line 85

def attached_policies: (

#clientClient

Returns:



149
# File 'lib/aws-sdk-iam/role.rb', line 149

def client: () -> Client

#create_dateTime

The date and time, in ISO 8601 date-time format, when the role was created.

Returns:

  • (Time)


31
# File 'sig/role.rbs', line 31

def create_date: () -> ::Time

#dataTypes::Role

Returns the data for this Aws::IAM::Role. Calls Client#get_role if #data_loaded? is false.

Returns:



58
# File 'sig/role.rbs', line 58

def data: () -> Types::Role

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



61
# File 'sig/role.rbs', line 61

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


role.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


71
# File 'sig/role.rbs', line 71

def delete: (

#descriptionString

A description of the role that you provide.

Returns:

  • (String)


37
# File 'sig/role.rbs', line 37

def description: () -> ::String

#detach_policy(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


role.detach_policy({
  policy_arn: "arnType", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :policy_arn (required, String)

    The Amazon Resource Name (ARN) of the IAM policy you want to detach.

    For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (EmptyStructure)


76
# File 'sig/role.rbs', line 76

def detach_policy: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


461
462
463
# File 'lib/aws-sdk-iam/role.rb', line 461

def identifiers
  { name: @name }
end

#instance_profiles(options = {}) ⇒ InstanceProfile::Collection

Examples:

Request syntax with placeholder values


role.instance_profiles()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



91
# File 'sig/role.rbs', line 91

def instance_profiles: (

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::IAM::Role. Returns self making it possible to chain methods.

role.reload.data

Returns:

  • (self)


54
# File 'sig/role.rbs', line 54

def load: () -> self

#max_session_durationInteger

The maximum session duration (in seconds) for the specified role. Anyone who uses the CLI, or API to assume the role can specify the duration using the optional DurationSeconds API parameter or duration-seconds CLI parameter.

Returns:

  • (Integer)


40
# File 'sig/role.rbs', line 40

def max_session_duration: () -> ::Integer

#nameString Also known as: role_name

Returns:

  • (String)


18
# File 'sig/role.rbs', line 18

def name: () -> String

#pathString

The path to the role. For more information about paths, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


22
# File 'sig/role.rbs', line 22

def path: () -> ::String

#permissions_boundaryTypes::AttachedPermissionsBoundary

The ARN of the policy used to set the permissions boundary for the role.

For more information about permissions boundaries, see Permissions boundaries for IAM identities in the IAM User Guide.



43
# File 'sig/role.rbs', line 43

def permissions_boundary: () -> Types::AttachedPermissionsBoundary

#policies(options = {}) ⇒ RolePolicy::Collection

Examples:

Request syntax with placeholder values


role.policies()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



96
# File 'sig/role.rbs', line 96

def policies: (

#policy(name) ⇒ RolePolicy

Parameters:

  • name (String)

Returns:



101
# File 'sig/role.rbs', line 101

def policy: (String name) -> RolePolicy

#role_idString

The stable and unique string identifying the role. For more information about IDs, see IAM identifiers in the IAM User Guide.

Returns:

  • (String)


25
# File 'sig/role.rbs', line 25

def role_id: () -> ::String

#role_last_usedTypes::RoleLastUsed

Contains information about the last time that an IAM role was used. This includes the date and time and the Region in which the role was last used. Activity is only reported for the trailing 400 days. This period can be shorter if your Region began supporting these features within the last year. The role might have been used more than 400 days ago. For more information, see Regions where data is tracked in the IAM user Guide.

Returns:



49
# File 'sig/role.rbs', line 49

def role_last_used: () -> Types::RoleLastUsed

#tagsArray<Types::Tag>

A list of tags that are attached to the role. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

Returns:



46
# File 'sig/role.rbs', line 46

def tags: () -> ::Array[Types::Tag]

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::IAM::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-iam/role.rb', line 263

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end