Class: Aws::IAM::SamlProvider
- Inherits:
-
Object
- Object
- Aws::IAM::SamlProvider
- Extended by:
- Deprecations
- Defined in:
- sig/saml_provider.rbs,
lib/aws-sdk-iam/saml_provider.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #arn ⇒ String
-
#assertion_encryption_mode ⇒ String
Specifies the encryption setting for the SAML provider.
-
#create_date ⇒ Time
The date and time when the SAML provider was created.
-
#private_key_list ⇒ Array<Types::SAMLPrivateKey>
The private key metadata for the SAML provider.
-
#saml_metadata_document ⇒ String
The XML metadata document that includes information about an identity provider.
-
#saml_provider_uuid ⇒ String
The unique identifier assigned to the SAML provider.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the specified IAM SAML provider.
-
#valid_until ⇒ Time
The expiration date and time for the SAML provider.
Actions collapse
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #update(options = {}) ⇒ Types::UpdateSAMLProviderResponse
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::GetSAMLProviderResponse
Returns the data for this SamlProvider.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ SamlProvider
constructor
A new instance of SamlProvider.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current SamlProvider.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(arn, options = {}) ⇒ SamlProvider #initialize(options = {}) ⇒ SamlProvider
Returns a new instance of SamlProvider.
13 14 15 |
# File 'sig/saml_provider.rbs', line 13
def initialize: (String arn, Hash[Symbol, untyped] options) -> void
| (arn: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#arn ⇒ String
18 |
# File 'sig/saml_provider.rbs', line 18
def arn: () -> String
|
#assertion_encryption_mode ⇒ String
Specifies the encryption setting for the SAML provider.
36 |
# File 'sig/saml_provider.rbs', line 36
def assertion_encryption_mode: () -> ("Required" | "Allowed")
|
#create_date ⇒ Time
The date and time when the SAML provider was created.
27 |
# File 'sig/saml_provider.rbs', line 27
def create_date: () -> ::Time
|
#data ⇒ Types::GetSAMLProviderResponse
Returns the data for this Aws::IAM::SamlProvider. Calls
Client#get_saml_provider if #data_loaded? is false.
48 |
# File 'sig/saml_provider.rbs', line 48
def data: () -> Types::GetSAMLProviderResponse
|
#data_loaded? ⇒ Boolean
51 |
# File 'sig/saml_provider.rbs', line 51
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
55 |
# File 'sig/saml_provider.rbs', line 55
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
272 273 274 |
# File 'lib/aws-sdk-iam/saml_provider.rb', line 272 def identifiers { arn: @arn } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::SamlProvider.
Returns self making it possible to chain methods.
saml_provider.reload.data
44 |
# File 'sig/saml_provider.rbs', line 44
def load: () -> self
|
#private_key_list ⇒ Array<Types::SAMLPrivateKey>
The private key metadata for the SAML provider.
39 |
# File 'sig/saml_provider.rbs', line 39
def private_key_list: () -> ::Array[Types::SAMLPrivateKey]
|
#saml_metadata_document ⇒ String
The XML metadata document that includes information about an identity provider.
24 |
# File 'sig/saml_provider.rbs', line 24
def saml_metadata_document: () -> ::String
|
#saml_provider_uuid ⇒ String
The unique identifier assigned to the SAML provider.
21 |
# File 'sig/saml_provider.rbs', line 21
def saml_provider_uuid: () -> ::String
|
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the specified IAM SAML provider. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
33 |
# File 'sig/saml_provider.rbs', line 33
def tags: () -> ::Array[Types::Tag]
|
#update(options = {}) ⇒ Types::UpdateSAMLProviderResponse
60 |
# File 'sig/saml_provider.rbs', line 60
def update: (
|
#valid_until ⇒ Time
The expiration date and time for the SAML provider.
30 |
# File 'sig/saml_provider.rbs', line 30
def valid_until: () -> ::Time
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/aws-sdk-iam/saml_provider.rb', line 203 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |