Class: Aws::IAM::ServerCertificate
- Inherits:
-
Object
- Object
- Aws::IAM::ServerCertificate
- Extended by:
- Deprecations
- Defined in:
- sig/server_certificate.rbs,
lib/aws-sdk-iam/server_certificate.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#certificate_body ⇒ String
The contents of the public key certificate.
-
#certificate_chain ⇒ String
The contents of the public key certificate chain.
- #name ⇒ String
-
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the server certificate, such as its name, path, ID, and ARN.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the server certificate.
Actions collapse
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #update(options = {}) ⇒ ServerCertificate
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::ServerCertificate
Returns the data for this ServerCertificate.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ ServerCertificate
constructor
A new instance of ServerCertificate.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current ServerCertificate.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::IAM::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ ServerCertificate #initialize(options = {}) ⇒ ServerCertificate
Returns a new instance of ServerCertificate.
13 14 15 |
# File 'sig/server_certificate.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#certificate_body ⇒ String
The contents of the public key certificate.
24 |
# File 'sig/server_certificate.rbs', line 24
def certificate_body: () -> ::String
|
#certificate_chain ⇒ String
The contents of the public key certificate chain.
27 |
# File 'sig/server_certificate.rbs', line 27
def certificate_chain: () -> ::String
|
#client ⇒ Client
71 |
# File 'lib/aws-sdk-iam/server_certificate.rb', line 71
def client: () -> Client
|
#data ⇒ Types::ServerCertificate
Returns the data for this Aws::IAM::ServerCertificate. Calls
Client#get_server_certificate if #data_loaded? is false.
39 |
# File 'sig/server_certificate.rbs', line 39
def data: () -> Types::ServerCertificate
|
#data_loaded? ⇒ Boolean
42 |
# File 'sig/server_certificate.rbs', line 42
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
46 |
# File 'sig/server_certificate.rbs', line 46
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
267 268 269 |
# File 'lib/aws-sdk-iam/server_certificate.rb', line 267 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::IAM::ServerCertificate.
Returns self making it possible to chain methods.
server_certificate.reload.data
35 |
# File 'sig/server_certificate.rbs', line 35
def load: () -> self
|
#name ⇒ String
18 |
# File 'sig/server_certificate.rbs', line 18
def name: () -> String
|
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the server certificate, such as its name, path, ID, and ARN.
21 |
# File 'sig/server_certificate.rbs', line 21
def server_certificate_metadata: () -> Types::ServerCertificateMetadata
|
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the server certificate. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
30 |
# File 'sig/server_certificate.rbs', line 30
def tags: () -> ::Array[Types::Tag]
|
#update(options = {}) ⇒ ServerCertificate
51 |
# File 'sig/server_certificate.rbs', line 51
def update: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::IAM::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/aws-sdk-iam/server_certificate.rb', line 185 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |