Class: Aws::IAM::Types::AcquireRoleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::AcquireRoleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#replacement_values ⇒ Hash<String,Types::ReplacementValueEntry>
A map of values to substitute for the parameters that are defined in the role template version.
-
#template_arn ⇒ String
The Amazon Resource Name (ARN) of the role template to create the role from.
-
#template_minor_version ⇒ Integer
The minor version of the role template to use.
Instance Attribute Details
#replacement_values ⇒ Hash<String,Types::ReplacementValueEntry>
A map of values to substitute for the parameters that are defined in the role template version. Each key is a parameter name from the template, and each value is a structure that contains the replacement values for that parameter.
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-iam/types.rb', line 321 class AcquireRoleRequest < Struct.new( :template_arn, :template_minor_version, :replacement_values) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The Amazon Resource Name (ARN) of the role template to create the role from.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-iam/types.rb', line 321 class AcquireRoleRequest < Struct.new( :template_arn, :template_minor_version, :replacement_values) SENSITIVE = [] include Aws::Structure end |
#template_minor_version ⇒ Integer
The minor version of the role template to use. If you do not specify a minor version, the service uses the template's default minor version.
321 322 323 324 325 326 327 |
# File 'lib/aws-sdk-iam/types.rb', line 321 class AcquireRoleRequest < Struct.new( :template_arn, :template_minor_version, :replacement_values) SENSITIVE = [] include Aws::Structure end |