Class: Aws::IAM::Types::CreateDelegationRequestResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::CreateDelegationRequestResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#console_deep_link ⇒ String
A deep link URL to the Amazon Web Services Management Console for managing the delegation request.
-
#delegation_request_id ⇒ String
The unique identifier for the created delegation request.
Instance Attribute Details
#console_deep_link ⇒ String
A deep link URL to the Amazon Web Services Management Console for managing the delegation request.
For a console based workflow, partners should redirect the customer to this URL. If the customer is not logged in to any Amazon Web Services account, the Amazon Web Services workflow will automatically direct the customer to log in and then display the delegation request approval page.
900 901 902 903 904 905 |
# File 'lib/aws-sdk-iam/types.rb', line 900 class CreateDelegationRequestResponse < Struct.new( :console_deep_link, :delegation_request_id) SENSITIVE = [] include Aws::Structure end |
#delegation_request_id ⇒ String
The unique identifier for the created delegation request.
900 901 902 903 904 905 |
# File 'lib/aws-sdk-iam/types.rb', line 900 class CreateDelegationRequestResponse < Struct.new( :console_deep_link, :delegation_request_id) SENSITIVE = [] include Aws::Structure end |