Class: Aws::IAM::Types::CreateServiceSpecificCredentialRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credential_age_daysInteger

The number of days until the service specific credential expires. This field is only valid for Bedrock and CloudWatch Logs API keys and must be a positive integer. When not specified, the credential will not expire.

Returns:

  • (Integer)


1774
1775
1776
1777
1778
1779
1780
# File 'lib/aws-sdk-iam/types.rb', line 1774

class CreateServiceSpecificCredentialRequest < Struct.new(
  :user_name,
  :service_name,
  :credential_age_days)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the Amazon Web Services service that is to be associated with the credentials. The service you specify here is the only service that can be accessed using these credentials.

Returns:

  • (String)


1774
1775
1776
1777
1778
1779
1780
# File 'lib/aws-sdk-iam/types.rb', line 1774

class CreateServiceSpecificCredentialRequest < Struct.new(
  :user_name,
  :service_name,
  :credential_age_days)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the IAM user that is to be associated with the credentials. The new service-specific credentials have the same permissions as the associated user except that they can be used only to access the specified service.

This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


1774
1775
1776
1777
1778
1779
1780
# File 'lib/aws-sdk-iam/types.rb', line 1774

class CreateServiceSpecificCredentialRequest < Struct.new(
  :user_name,
  :service_name,
  :credential_age_days)
  SENSITIVE = []
  include Aws::Structure
end