Class: Aws::IAM::Types::EntityTemporarilyUnmodifiableException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::EntityTemporarilyUnmodifiableException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
The request was rejected because it referenced an entity that is temporarily unmodifiable, such as a user name that was deleted and then recreated. The error indicates that the request is likely to succeed if you try again after waiting several minutes. The error message describes the entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
3300 3301 3302 3303 3304 |
# File 'lib/aws-sdk-iam/types.rb', line 3300 class EntityTemporarilyUnmodifiableException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |