Class: Aws::IAM::Types::GetOrganizationsAccessReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetOrganizationsAccessReportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_details ⇒ Array<Types::AccessDetail>
An object that contains details about the most recent attempt to access the service.
-
#error_details ⇒ Types::ErrorDetails
Contains information about the reason that the operation failed.
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#job_completion_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the generated report job was completed or failed.
-
#job_creation_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the report job was created.
-
#job_status ⇒ String
The status of the job.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#number_of_services_accessible ⇒ Integer
The number of services that the applicable SCPs allow account principals to access.
-
#number_of_services_not_accessed ⇒ Integer
The number of services that account principals are allowed but did not attempt to access.
Instance Attribute Details
#access_details ⇒ Array<Types::AccessDetail>
An object that contains details about the most recent attempt to access the service.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ Types::ErrorDetails
Contains information about the reason that the operation failed.
This data type is used as a response element in the GetOrganizationsAccessReport, GetServiceLastAccessedDetails, and GetServiceLastAccessedDetailsWithEntities operations.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If
your results were truncated, you can make a subsequent pagination
request using the Marker request parameter to retrieve more items.
Note that IAM might return fewer than the MaxItems number of
results even when there are more results available. We recommend
that you check IsTruncated after every call to ensure that you
receive all your results.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#job_completion_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the generated report job was completed or failed.
This field is null if the job is still in progress, as indicated by
a job status value of IN_PROGRESS.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#job_creation_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the report job was created.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The status of the job.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains
the value to use for the Marker parameter in a subsequent
pagination request.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#number_of_services_accessible ⇒ Integer
The number of services that the applicable SCPs allow account principals to access.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |
#number_of_services_not_accessed ⇒ Integer
The number of services that account principals are allowed but did not attempt to access.
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iam/types.rb', line 4584 class GetOrganizationsAccessReportResponse < Struct.new( :job_status, :job_creation_date, :job_completion_date, :number_of_services_accessible, :number_of_services_not_accessed, :access_details, :is_truncated, :marker, :error_details) SENSITIVE = [] include Aws::Structure end |