Class: Aws::IAM::Types::GetOutboundWebIdentityFederationInfoResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetOutboundWebIdentityFederationInfoResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#issuer_identifier ⇒ String
A unique issuer URL for your Amazon Web Services account that hosts the OpenID Connect (OIDC) discovery endpoints at
/.well-known/openid-configuration and /.well-known/jwks.json. -
#jwt_vending_enabled ⇒ Boolean
Indicates whether outbound identity federation is currently enabled for your Amazon Web Services account.
Instance Attribute Details
#issuer_identifier ⇒ String
A unique issuer URL for your Amazon Web Services account that hosts
the OpenID Connect (OIDC) discovery endpoints at
/.well-known/openid-configuration and /.well-known/jwks.json. The
OpenID Connect (OIDC) discovery endpoints contain verification keys
and metadata necessary for token verification.
4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-iam/types.rb', line 4615 class GetOutboundWebIdentityFederationInfoResponse < Struct.new( :issuer_identifier, :jwt_vending_enabled) SENSITIVE = [] include Aws::Structure end |
#jwt_vending_enabled ⇒ Boolean
Indicates whether outbound identity federation is currently enabled
for your Amazon Web Services account. When true, IAM principals in
the account can call the GetWebIdentityToken API to obtain JSON
Web Tokens (JWTs) for authentication with external services.
4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-iam/types.rb', line 4615 class GetOutboundWebIdentityFederationInfoResponse < Struct.new( :issuer_identifier, :jwt_vending_enabled) SENSITIVE = [] include Aws::Structure end |