Class: Aws::IAM::Types::GetOutboundWebIdentityFederationInfoResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#issuer_identifierString

A unique issuer URL for your Amazon Web Services account that hosts the OpenID Connect (OIDC) discovery endpoints at ‘/.well-known/openid-configuration and /.well-known/jwks.json`. The OpenID Connect (OIDC) discovery endpoints contain verification keys and metadata necessary for token verification.

Returns:

  • (String)


4567
4568
4569
4570
4571
4572
# File 'lib/aws-sdk-iam/types.rb', line 4567

class GetOutboundWebIdentityFederationInfoResponse < Struct.new(
  :issuer_identifier,
  :jwt_vending_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#jwt_vending_enabledBoolean

Indicates whether outbound identity federation is currently enabled for your Amazon Web Services account. When true, IAM principals in the account can call the ‘GetWebIdentityToken` API to obtain JSON Web Tokens (JWTs) for authentication with external services.

Returns:

  • (Boolean)


4567
4568
4569
4570
4571
4572
# File 'lib/aws-sdk-iam/types.rb', line 4567

class GetOutboundWebIdentityFederationInfoResponse < Struct.new(
  :issuer_identifier,
  :jwt_vending_enabled)
  SENSITIVE = []
  include Aws::Structure
end