Class: Aws::IAM::Types::GetRoleTemplateVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::GetRoleTemplateVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#minor_version ⇒ Integer
The minor version of the role template to retrieve.
-
#template_arn ⇒ String
The Amazon Resource Name (ARN) of the role template whose version you want to retrieve.
Instance Attribute Details
#minor_version ⇒ Integer
The minor version of the role template to retrieve. If you do not specify a minor version, the service returns the template's default minor version.
4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-iam/types.rb', line 4906 class GetRoleTemplateVersionRequest < Struct.new( :template_arn, :minor_version) SENSITIVE = [] include Aws::Structure end |
#template_arn ⇒ String
The Amazon Resource Name (ARN) of the role template whose version you want to retrieve.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-iam/types.rb', line 4906 class GetRoleTemplateVersionRequest < Struct.new( :template_arn, :minor_version) SENSITIVE = [] include Aws::Structure end |