Class: Aws::IAM::Types::InlinePolicyIdentifierType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Identifies one or more inline policies that are embedded in IAM users, groups, or roles, by the name of the policy together with the type and name of the entity that it is attached to. Wildcard characters in the entity name can match multiple entities, so a single identifier can select more than one attached inline policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_nameString

The name of the IAM user, group, or role that the inline policy is attached to. Wildcard characters are supported to match multiple entities: use at most one * (matches any sequence of characters, including none), and any number of ? (each matches exactly one character).

Returns:

  • (String)


5569
5570
5571
5572
5573
5574
5575
# File 'lib/aws-sdk-iam/types.rb', line 5569

class InlinePolicyIdentifierType < Struct.new(
  :policy_name,
  :attachment_type,
  :attachment_name)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_typeString

The type of IAM entity that the inline policy is attached to.

Returns:

  • (String)


5569
5570
5571
5572
5573
5574
5575
# File 'lib/aws-sdk-iam/types.rb', line 5569

class InlinePolicyIdentifierType < Struct.new(
  :policy_name,
  :attachment_type,
  :attachment_name)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

The name of the inline policy.

Returns:

  • (String)


5569
5570
5571
5572
5573
5574
5575
# File 'lib/aws-sdk-iam/types.rb', line 5569

class InlinePolicyIdentifierType < Struct.new(
  :policy_name,
  :attachment_type,
  :attachment_name)
  SENSITIVE = []
  include Aws::Structure
end