Class: Aws::IAM::Types::InstanceProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::InstanceProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about an instance profile.
This data type is used as a response element in the following operations:
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the instance profile.
-
#create_date ⇒ Time
The date when the instance profile was created.
-
#instance_profile_id ⇒ String
The stable and unique string identifying the instance profile.
-
#instance_profile_name ⇒ String
The name identifying the instance profile.
-
#path ⇒ String
The path to the instance profile.
-
#roles ⇒ Array<Types::Role>
The role associated with the instance profile.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) specifying the instance profile. For more information about ARNs and how to use them in policies, see IAM identifiers in the IAM User Guide.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ Time
The date when the instance profile was created.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_profile_id ⇒ String
The stable and unique string identifying the instance profile. For more information about IDs, see IAM identifiers in the IAM User Guide.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The name identifying the instance profile.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the instance profile. For more information about paths, see IAM identifiers in the IAM User Guide.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#roles ⇒ Array<Types::Role>
The role associated with the instance profile.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 |
# File 'lib/aws-sdk-iam/types.rb', line 5777 class InstanceProfile < Struct.new( :path, :instance_profile_name, :instance_profile_id, :arn, :create_date, :roles, :tags) SENSITIVE = [] include Aws::Structure end |