Class: Aws::IAM::Types::ListDelegationRequestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListDelegationRequestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#owner_id ⇒ String
The owner ID to filter delegation requests by.
Instance Attribute Details
#marker ⇒ String
Use this parameter only when paginating results and only after you
receive a response indicating that the results are truncated. Set it
to the value of the Marker element in the response that you
received to indicate where the next call should start.
6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-iam/types.rb', line 6355 class ListDelegationRequestsRequest < Struct.new( :owner_id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number
of items you want in the response. If additional items exist beyond
the maximum you specify, the IsTruncated response element is
true.
If you do not include this parameter, the number of items defaults
to 100. Note that IAM may return fewer results, even when there are
more results available. In that case, the IsTruncated response
element returns true, and Marker contains a value to include in
the subsequent call that tells the service where to continue from.
6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-iam/types.rb', line 6355 class ListDelegationRequestsRequest < Struct.new( :owner_id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#owner_id ⇒ String
The owner ID to filter delegation requests by.
6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-iam/types.rb', line 6355 class ListDelegationRequestsRequest < Struct.new( :owner_id, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |