Class: Aws::IAM::Types::ListGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [ListGroups][1] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroups.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#groups ⇒ Array<Types::Group>
A list of groups.
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request.
Instance Attribute Details
#groups ⇒ Array<Types::Group>
A list of groups.
6543 6544 6545 6546 6547 6548 6549 |
# File 'lib/aws-sdk-iam/types.rb', line 6543 class ListGroupsResponse < Struct.new( :groups, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
6543 6544 6545 6546 6547 6548 6549 |
# File 'lib/aws-sdk-iam/types.rb', line 6543 class ListGroupsResponse < Struct.new( :groups, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
6543 6544 6545 6546 6547 6548 6549 |
# File 'lib/aws-sdk-iam/types.rb', line 6543 class ListGroupsResponse < Struct.new( :groups, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |