Class: Aws::IAM::Types::ListPoliciesGrantingServiceAccessResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListPoliciesGrantingServiceAccessResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#policies_granting_service_access ⇒ Array<Types::ListPoliciesGrantingServiceAccessEntry>
A
ListPoliciesGrantingServiceAccessobject that contains details about the permissions policies attached to the specified identity (user, group, or role).
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
7171 7172 7173 7174 7175 7176 7177 |
# File 'lib/aws-sdk-iam/types.rb', line 7171 class ListPoliciesGrantingServiceAccessResponse < Struct.new( :policies_granting_service_access, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
7171 7172 7173 7174 7175 7176 7177 |
# File 'lib/aws-sdk-iam/types.rb', line 7171 class ListPoliciesGrantingServiceAccessResponse < Struct.new( :policies_granting_service_access, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#policies_granting_service_access ⇒ Array<Types::ListPoliciesGrantingServiceAccessEntry>
A ListPoliciesGrantingServiceAccess object that contains details about the permissions policies attached to the specified identity (user, group, or role).
7171 7172 7173 7174 7175 7176 7177 |
# File 'lib/aws-sdk-iam/types.rb', line 7171 class ListPoliciesGrantingServiceAccessResponse < Struct.new( :policies_granting_service_access, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |