Class: Aws::IAM::Types::ListServiceSpecificCredentialsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListServiceSpecificCredentialsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_users ⇒ Boolean
A flag indicating whether to list service specific credentials for all users.
-
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated.
-
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response.
-
#service_name ⇒ String
Filters the returned results to only those for the specified Amazon Web Services service.
-
#user_name ⇒ String
The name of the user whose service-specific credentials you want information about.
Instance Attribute Details
#all_users ⇒ Boolean
A flag indicating whether to list service specific credentials for all users. This parameter cannot be specified together with UserName. When true, returns all credentials associated with the specified service.
8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/aws-sdk-iam/types.rb', line 8096 class ListServiceSpecificCredentialsRequest < Struct.new( :user_name, :service_name, :all_users, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker from the response that you received to indicate where the next call should start.
8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/aws-sdk-iam/types.rb', line 8096 class ListServiceSpecificCredentialsRequest < Struct.new( :user_name, :service_name, :all_users, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true.
8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/aws-sdk-iam/types.rb', line 8096 class ListServiceSpecificCredentialsRequest < Struct.new( :user_name, :service_name, :all_users, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
Filters the returned results to only those for the specified Amazon Web Services service. If not specified, then Amazon Web Services returns service-specific credentials for all services.
8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/aws-sdk-iam/types.rb', line 8096 class ListServiceSpecificCredentialsRequest < Struct.new( :user_name, :service_name, :all_users, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the user whose service-specific credentials you want information about. If this value is not specified, then the operation assumes the user whose credentials are used to call the operation.
This parameter allows (through its [regex pattern]) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/aws-sdk-iam/types.rb', line 8096 class ListServiceSpecificCredentialsRequest < Struct.new( :user_name, :service_name, :all_users, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |