Class: Aws::IAM::Types::ListUsersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains the response to a successful [ListUsers] request.

[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListUsers.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_truncatedBoolean

A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.

Returns:

  • (Boolean)


8446
8447
8448
8449
8450
8451
8452
# File 'lib/aws-sdk-iam/types.rb', line 8446

class ListUsersResponse < Struct.new(
  :users,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.

Returns:

  • (String)


8446
8447
8448
8449
8450
8451
8452
# File 'lib/aws-sdk-iam/types.rb', line 8446

class ListUsersResponse < Struct.new(
  :users,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#usersArray<Types::User>

A list of users.

Returns:



8446
8447
8448
8449
8450
8451
8452
# File 'lib/aws-sdk-iam/types.rb', line 8446

class ListUsersResponse < Struct.new(
  :users,
  :is_truncated,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end