Class: Aws::IAM::Types::ListVirtualMFADevicesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ListVirtualMFADevicesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful [ListVirtualMFADevices] request.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_ListVirtualMFADevices.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return.
-
#marker ⇒ String
When
IsTruncatedistrue, this element is present and contains the value to use for theMarkerparameter in a subsequent pagination request. -
#virtual_mfa_devices ⇒ Array<Types::VirtualMFADevice>
The list of virtual MFA devices in the current account that match the
AssignmentStatusvalue that was passed in the request.
Instance Attribute Details
#is_truncated ⇒ Boolean
A flag that indicates whether there are more items to return. If your results were truncated, you can make a subsequent pagination request using the Marker request parameter to retrieve more items. Note that IAM might return fewer than the MaxItems number of results even when there are more results available. We recommend that you check IsTruncated after every call to ensure that you receive all your results.
8511 8512 8513 8514 8515 8516 8517 |
# File 'lib/aws-sdk-iam/types.rb', line 8511 class ListVirtualMFADevicesResponse < Struct.new( :virtual_mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
When IsTruncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent pagination request.
8511 8512 8513 8514 8515 8516 8517 |
# File 'lib/aws-sdk-iam/types.rb', line 8511 class ListVirtualMFADevicesResponse < Struct.new( :virtual_mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |
#virtual_mfa_devices ⇒ Array<Types::VirtualMFADevice>
The list of virtual MFA devices in the current account that match the AssignmentStatus value that was passed in the request.
8511 8512 8513 8514 8515 8516 8517 |
# File 'lib/aws-sdk-iam/types.rb', line 8511 class ListVirtualMFADevicesResponse < Struct.new( :virtual_mfa_devices, :is_truncated, :marker) SENSITIVE = [] include Aws::Structure end |