Class: Aws::IAM::Types::NameConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::NameConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
The request was rejected because the resulting role name conflicts with an existing role in the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
8988 8989 8990 8991 8992 |
# File 'lib/aws-sdk-iam/types.rb', line 8988 class NameConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |