Class: Aws::IAM::Types::OrderedOrganizationPolicyType
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::OrderedOrganizationPolicyType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Represents one level of an Organizations hierarchy—the organization root, an organizational unit (OU), or an account—together with the service control policies (SCPs) that apply at that level. Each element in the list represents one level of the hierarchy, ordered from the organization root down to the account.
For more information about SCPs, see Service control policies (SCPs) in the Organizations User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_control_policy_input_list ⇒ Array<String>
A list of SCP documents that apply at this level of the Organizations hierarchy.
Instance Attribute Details
#service_control_policy_input_list ⇒ Array<String>
A list of SCP documents that apply at this level of the Organizations hierarchy. Each document is specified as a string containing the complete, valid JSON text of an SCP.
8925 8926 8927 8928 8929 |
# File 'lib/aws-sdk-iam/types.rb', line 8925 class OrderedOrganizationPolicyType < Struct.new( :service_control_policy_input_list) SENSITIVE = [] include Aws::Structure end |