Class: Aws::IAM::Types::PasswordPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::PasswordPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about the account password policy.
This data type is used as a response element in the
- GetAccountPasswordPolicy][1
-
operation.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountPasswordPolicy.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_users_to_change_password ⇒ Boolean
Specifies whether IAM users are allowed to change their own password.
-
#expire_passwords ⇒ Boolean
Indicates whether passwords in the account expire.
-
#hard_expiry ⇒ Boolean
Specifies whether IAM users are prevented from setting a new password via the Amazon Web Services Management Console after their password has expired.
-
#max_password_age ⇒ Integer
The number of days that an IAM user password is valid.
-
#minimum_password_length ⇒ Integer
Minimum length to require for IAM user passwords.
-
#password_reuse_prevention ⇒ Integer
Specifies the number of previous passwords that IAM users are prevented from reusing.
-
#require_lowercase_characters ⇒ Boolean
Specifies whether IAM user passwords must contain at least one lowercase character (a to z).
-
#require_numbers ⇒ Boolean
Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).
-
#require_symbols ⇒ Boolean
Specifies whether IAM user passwords must contain at least one of the following symbols:.
-
#require_uppercase_characters ⇒ Boolean
Specifies whether IAM user passwords must contain at least one uppercase character (A to Z).
Instance Attribute Details
#allow_users_to_change_password ⇒ Boolean
Specifies whether IAM users are allowed to change their own password. Gives IAM users permissions to ‘iam:ChangePassword` for only their user and to the `iam:GetAccountPasswordPolicy` action. This option does not attach a permissions policy to each user, rather the permissions are applied at the account-level for all users by IAM.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#expire_passwords ⇒ Boolean
Indicates whether passwords in the account expire. Returns true if ‘MaxPasswordAge` contains a value greater than 0. Returns false if MaxPasswordAge is 0 or not present.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#hard_expiry ⇒ Boolean
Specifies whether IAM users are prevented from setting a new password via the Amazon Web Services Management Console after their password has expired. The IAM user cannot access the console until an administrator resets the password. IAM users with ‘iam:ChangePassword` permission and active access keys can reset their own expired console password using the CLI or API.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#max_password_age ⇒ Integer
The number of days that an IAM user password is valid.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#minimum_password_length ⇒ Integer
Minimum length to require for IAM user passwords.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#password_reuse_prevention ⇒ Integer
Specifies the number of previous passwords that IAM users are prevented from reusing.
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#require_lowercase_characters ⇒ Boolean
Specifies whether IAM user passwords must contain at least one lowercase character (a to z).
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#require_numbers ⇒ Boolean
Specifies whether IAM user passwords must contain at least one numeric character (0 to 9).
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#require_symbols ⇒ Boolean
Specifies whether IAM user passwords must contain at least one of the following symbols:
! @ # $ % ^ & * ( ) _ + - = [ ] { } | ‘
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |
#require_uppercase_characters ⇒ Boolean
Specifies whether IAM user passwords must contain at least one uppercase character (A to Z).
8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 |
# File 'lib/aws-sdk-iam/types.rb', line 8923 class PasswordPolicy < Struct.new( :minimum_password_length, :require_symbols, :require_numbers, :require_uppercase_characters, :require_lowercase_characters, :allow_users_to_change_password, :expire_passwords, :max_password_age, :password_reuse_prevention, :hard_expiry) SENSITIVE = [] include Aws::Structure end |