Class: Aws::IAM::Types::Policy
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::Policy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about a managed policy.
This data type is used as a response element in the CreatePolicy, GetPolicy, and ListPolicies operations.
For more information about managed policies, refer to Managed policies and inline policies in the IAM User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN).
-
#attachment_count ⇒ Integer
The number of entities (users, groups, and roles) that the policy is attached to.
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the policy was created.
-
#default_version_id ⇒ String
The identifier for the version of the policy that is set as the default version.
-
#description ⇒ String
A friendly description of the policy.
-
#is_attachable ⇒ Boolean
Specifies whether the policy can be attached to an IAM user, group, or role.
-
#path ⇒ String
The path to the policy.
-
#permissions_boundary_usage_count ⇒ Integer
The number of entities (users and roles) for which the policy is used to set the permissions boundary.
-
#policy_id ⇒ String
The stable and unique string identifying the policy.
-
#policy_name ⇒ String
The friendly name (not ARN) identifying the policy.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile.
-
#update_date ⇒ Time
The date and time, in [ISO 8601 date-time format][1], when the policy was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN). ARNs are unique identifiers for Amazon Web Services resources.
For more information about ARNs, go to Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#attachment_count ⇒ Integer
The number of entities (users, groups, and roles) that the policy is attached to.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the policy was created.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#default_version_id ⇒ String
The identifier for the version of the policy that is set as the default version.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A friendly description of the policy.
This element is included in the response to the GetPolicy operation. It is not included in the response to the ListPolicies operation.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#is_attachable ⇒ Boolean
Specifies whether the policy can be attached to an IAM user, group, or role.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the policy.
For more information about paths, see IAM identifiers in the IAM User Guide.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#permissions_boundary_usage_count ⇒ Integer
The number of entities (users and roles) for which the policy is used to set the permissions boundary.
For more information about permissions boundaries, see Permissions boundaries for IAM identities in the IAM User Guide.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
The stable and unique string identifying the policy.
For more information about IDs, see IAM identifiers in the IAM User Guide.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The friendly name (not ARN) identifying the policy.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the instance profile. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |
#update_date ⇒ Time
The date and time, in ISO 8601 date-time format, when the policy was last updated.
When a policy has only one version, this field contains the date and time when the policy was created. When a policy has more than one version, this field contains the date and time when the most recent policy version was created.
9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 |
# File 'lib/aws-sdk-iam/types.rb', line 9218 class Policy < Struct.new( :policy_name, :policy_id, :arn, :path, :default_version_id, :attachment_count, :permissions_boundary_usage_count, :is_attachable, :description, :create_date, :update_date, :tags) SENSITIVE = [] include Aws::Structure end |