Class: Aws::IAM::Types::PolicyIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::PolicyIdentifier
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
PolicyIdentifier is a union - when making an API calls you must set exactly one of the members.
Identifies one or more policies as a union type. Specify exactly one
of PolicyType, PolicyArn, or InlinePolicyIdentifier to identify
policies by their type, by Amazon Resource Name (ARN), or by the name
of an inline policy and the entity it is attached to.
Defined Under Namespace
Classes: InlinePolicyIdentifier, PolicyArn, PolicyType, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inline_policy_identifier ⇒ Types::InlinePolicyIdentifierType
An inline policy identifier consisting of a policy name and the entity it is attached to.
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services managed policy or a customer managed policy that is attached to an IAM user, group, or role.
-
#policy_type ⇒ String
The policy type to identify.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#inline_policy_identifier ⇒ Types::InlinePolicyIdentifierType
An inline policy identifier consisting of a policy name and the
entity it is attached to. Wildcard characters (* and ?) in the
entity name can match multiple entities.
9618 9619 9620 9621 9622 9623 9624 9625 9626 9627 9628 9629 9630 9631 |
# File 'lib/aws-sdk-iam/types.rb', line 9618 class PolicyIdentifier < Struct.new( :policy_type, :policy_arn, :inline_policy_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PolicyType < PolicyIdentifier; end class PolicyArn < PolicyIdentifier; end class InlinePolicyIdentifier < PolicyIdentifier; end class Unknown < PolicyIdentifier; end end |
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of an Amazon Web Services managed
policy or a customer managed policy that is attached to an IAM user,
group, or role. Wildcard characters are supported in the resource
name portion of the ARN to match multiple managed policies: use at
most one * (matches any sequence of characters, including none),
and any number of ? (each matches exactly one character).
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
9618 9619 9620 9621 9622 9623 9624 9625 9626 9627 9628 9629 9630 9631 |
# File 'lib/aws-sdk-iam/types.rb', line 9618 class PolicyIdentifier < Struct.new( :policy_type, :policy_arn, :inline_policy_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PolicyType < PolicyIdentifier; end class PolicyArn < PolicyIdentifier; end class InlinePolicyIdentifier < PolicyIdentifier; end class Unknown < PolicyIdentifier; end end |
#policy_type ⇒ String
The policy type to identify. All policies of the specified type are matched.
9618 9619 9620 9621 9622 9623 9624 9625 9626 9627 9628 9629 9630 9631 |
# File 'lib/aws-sdk-iam/types.rb', line 9618 class PolicyIdentifier < Struct.new( :policy_type, :policy_arn, :inline_policy_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PolicyType < PolicyIdentifier; end class PolicyArn < PolicyIdentifier; end class InlinePolicyIdentifier < PolicyIdentifier; end class Unknown < PolicyIdentifier; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9618 9619 9620 |
# File 'lib/aws-sdk-iam/types.rb', line 9618 def unknown @unknown end |