Class: Aws::IAM::Types::ResetServiceSpecificCredentialResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#service_specific_credentialTypes::ServiceSpecificCredential

A structure with details about the updated service-specific credential, including the new password.

This is the only time that you can access the password. You cannot recover the password later, but you can reset it again.



9922
9923
9924
9925
9926
# File 'lib/aws-sdk-iam/types.rb', line 9922

class ResetServiceSpecificCredentialResponse < Struct.new(
  :service_specific_credential)
  SENSITIVE = []
  include Aws::Structure
end