Class: Aws::IAM::Types::ResetServiceSpecificCredentialResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ResetServiceSpecificCredentialResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_specific_credential ⇒ Types::ServiceSpecificCredential
A structure with details about the updated service-specific credential, including the new password.
Instance Attribute Details
#service_specific_credential ⇒ Types::ServiceSpecificCredential
A structure with details about the updated service-specific credential, including the new password.
This is the only time that you can access the password. You cannot recover the password later, but you can reset it again.
9915 9916 9917 9918 9919 |
# File 'lib/aws-sdk-iam/types.rb', line 9915 class ResetServiceSpecificCredentialResponse < Struct.new( :service_specific_credential) SENSITIVE = [] include Aws::Structure end |