Class: Aws::IAM::Types::RoleDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::RoleDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about an IAM role, including all of the role’s policies.
This data type is used as a response element in the
- GetAccountAuthorizationDetails][1
-
operation.
[1]: docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountAuthorizationDetails.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN).
-
#assume_role_policy_document ⇒ String
The trust policy that grants permission to assume the role.
-
#attached_managed_policies ⇒ Array<Types::AttachedPolicy>
A list of managed policies attached to the role.
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the role was created.
-
#instance_profile_list ⇒ Array<Types::InstanceProfile>
A list of instance profiles that contain this role.
-
#path ⇒ String
The path to the role.
-
#permissions_boundary ⇒ Types::AttachedPermissionsBoundary
The ARN of the policy used to set the permissions boundary for the role.
-
#role_id ⇒ String
The stable and unique string identifying the role.
-
#role_last_used ⇒ Types::RoleLastUsed
Contains information about the last time that an IAM role was used.
-
#role_name ⇒ String
The friendly name that identifies the role.
-
#role_policy_list ⇒ Array<Types::PolicyDetail>
A list of inline policies embedded in the role.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the role.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN). ARNs are unique identifiers for Amazon Web Services resources.
For more information about ARNs, go to [Amazon Resource Names (ARNs)] in the *Amazon Web Services General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#assume_role_policy_document ⇒ String
The trust policy that grants permission to assume the role.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#attached_managed_policies ⇒ Array<Types::AttachedPolicy>
A list of managed policies attached to the role. These policies are the role’s access (permissions) policies.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the role was created.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#instance_profile_list ⇒ Array<Types::InstanceProfile>
A list of instance profiles that contain this role.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the role. For more information about paths, see [IAM identifiers] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#permissions_boundary ⇒ Types::AttachedPermissionsBoundary
The ARN of the policy used to set the permissions boundary for the role.
For more information about permissions boundaries, see [Permissions boundaries for IAM identities ][1] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#role_id ⇒ String
The stable and unique string identifying the role. For more information about IDs, see [IAM identifiers] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#role_last_used ⇒ Types::RoleLastUsed
Contains information about the last time that an IAM role was used. This includes the date and time and the Region in which the role was last used. Activity is only reported for the trailing 400 days. This period can be shorter if your Region began supporting these features within the last year. The role might have been used more than 400 days ago. For more information, see [Regions where data is tracked] in the *IAM User Guide*.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#role_name ⇒ String
The friendly name that identifies the role.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#role_policy_list ⇒ Array<Types::PolicyDetail>
A list of inline policies embedded in the role. These policies are the role’s access (permissions) policies.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the role. For more information about tagging, see [Tagging IAM resources] in the *IAM User Guide*.
10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 |
# File 'lib/aws-sdk-iam/types.rb', line 10267 class RoleDetail < Struct.new( :path, :role_name, :role_id, :arn, :create_date, :assume_role_policy_document, :instance_profile_list, :role_policy_list, :attached_managed_policies, :permissions_boundary, :tags, :role_last_used) SENSITIVE = [] include Aws::Structure end |