Class: Aws::IAM::Types::ServerCertificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ServerCertificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains information about a server certificate.
This data type is used as a response element in the GetServerCertificate operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_body ⇒ String
The contents of the public key certificate.
-
#certificate_chain ⇒ String
The contents of the public key certificate chain.
-
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the server certificate, such as its name, path, ID, and ARN.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the server certificate.
Instance Attribute Details
#certificate_body ⇒ String
The contents of the public key certificate.
11180 11181 11182 11183 11184 11185 11186 11187 |
# File 'lib/aws-sdk-iam/types.rb', line 11180 class ServerCertificate < Struct.new( :server_certificate_metadata, :certificate_body, :certificate_chain, :tags) SENSITIVE = [] include Aws::Structure end |
#certificate_chain ⇒ String
The contents of the public key certificate chain.
11180 11181 11182 11183 11184 11185 11186 11187 |
# File 'lib/aws-sdk-iam/types.rb', line 11180 class ServerCertificate < Struct.new( :server_certificate_metadata, :certificate_body, :certificate_chain, :tags) SENSITIVE = [] include Aws::Structure end |
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the server certificate, such as its name, path, ID, and ARN.
11180 11181 11182 11183 11184 11185 11186 11187 |
# File 'lib/aws-sdk-iam/types.rb', line 11180 class ServerCertificate < Struct.new( :server_certificate_metadata, :certificate_body, :certificate_chain, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the server certificate. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
11180 11181 11182 11183 11184 11185 11186 11187 |
# File 'lib/aws-sdk-iam/types.rb', line 11180 class ServerCertificate < Struct.new( :server_certificate_metadata, :certificate_body, :certificate_chain, :tags) SENSITIVE = [] include Aws::Structure end |