Class: Aws::IAM::Types::ServiceSpecificCredential
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ServiceSpecificCredential
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the details of a service-specific credential.
Constant Summary collapse
- SENSITIVE =
[:service_password, :service_credential_secret]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the service-specific credential were created.
-
#expiration_date ⇒ Time
The date and time when the service specific credential expires.
-
#service_credential_alias ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the public portion of the credential that includes the IAM user name and a suffix containing version and creation information.
-
#service_credential_secret ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the secret portion of the credential that should be used to authenticate API calls.
-
#service_name ⇒ String
The name of the service associated with the service-specific credential.
-
#service_password ⇒ String
The generated password for the service-specific credential.
-
#service_specific_credential_id ⇒ String
The unique identifier for the service-specific credential.
-
#service_user_name ⇒ String
The generated user name for the service-specific credential.
-
#status ⇒ String
The status of the service-specific credential.
-
#user_name ⇒ String
The name of the IAM user associated with the service-specific credential.
Instance Attribute Details
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the service-specific credential were created.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#expiration_date ⇒ Time
The date and time when the service specific credential expires. This field is only present for Bedrock API keys and CloudWatch Logs API keys that were created with an expiration period.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_credential_alias ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the public portion of the credential that includes the IAM user name and a suffix containing version and creation information.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_credential_secret ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the secret portion of the credential that should be used to authenticate API calls. This value is returned only when the credential is created.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_name ⇒ String
The name of the service associated with the service-specific credential.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_password ⇒ String
The generated password for the service-specific credential.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_specific_credential_id ⇒ String
The unique identifier for the service-specific credential.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#service_user_name ⇒ String
The generated user name for the service-specific credential. This value is generated by combining the IAM user’s name combined with the ID number of the Amazon Web Services account, as in ‘jane-at-123456789012`, for example. This value cannot be configured by the user.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#status ⇒ String
The status of the service-specific credential. ‘Active` means that the key is valid for API calls, while `Inactive` means it is not.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |
#user_name ⇒ String
The name of the IAM user associated with the service-specific credential.
10849 10850 10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 |
# File 'lib/aws-sdk-iam/types.rb', line 10849 class ServiceSpecificCredential < Struct.new( :create_date, :expiration_date, :service_name, :service_user_name, :service_password, :service_credential_alias, :service_credential_secret, :service_specific_credential_id, :user_name, :status) SENSITIVE = [:service_password, :service_credential_secret] include Aws::Structure end |