Class: Aws::IAM::Types::ServiceSpecificCredentialMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::ServiceSpecificCredentialMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains additional details about a service-specific credential.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the service-specific credential were created.
-
#expiration_date ⇒ Time
The date and time when the service specific credential expires.
-
#service_credential_alias ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the public portion of the credential that includes the IAM user name and a suffix containing version and creation information.
-
#service_name ⇒ String
The name of the service associated with the service-specific credential.
-
#service_specific_credential_id ⇒ String
The unique identifier for the service-specific credential.
-
#service_user_name ⇒ String
The generated user name for the service-specific credential.
-
#status ⇒ String
The status of the service-specific credential.
-
#user_name ⇒ String
The name of the IAM user associated with the service-specific credential.
Instance Attribute Details
#create_date ⇒ Time
The date and time, in [ISO 8601 date-time format], when the service-specific credential were created.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The date and time when the service specific credential expires. This field is only present for Bedrock API keys and CloudWatch Logs API keys that were created with an expiration period.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#service_credential_alias ⇒ String
For Bedrock API keys and CloudWatch Logs API keys, this is the public portion of the credential that includes the IAM user name and a suffix containing version and creation information.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the service associated with the service-specific credential.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#service_specific_credential_id ⇒ String
The unique identifier for the service-specific credential.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#service_user_name ⇒ String
The generated user name for the service-specific credential.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the service-specific credential. Active means that the key is valid for API calls, while Inactive means it is not.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the IAM user associated with the service-specific credential.
10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 |
# File 'lib/aws-sdk-iam/types.rb', line 10899 class ServiceSpecificCredentialMetadata < Struct.new( :user_name, :status, :service_user_name, :service_credential_alias, :create_date, :expiration_date, :service_specific_credential_id, :service_name) SENSITIVE = [] include Aws::Structure end |