Class: Aws::IAM::Types::ServiceSpecificCredentialMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains additional details about a service-specific credential.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_dateTime

The date and time, in [ISO 8601 date-time format], when the service-specific credential were created.

[1]: www.iso.org/iso/iso8601



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_dateTime

The date and time when the service specific credential expires. This field is only present for Bedrock API keys that were created with an expiration period.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_credential_aliasString

For Bedrock API keys, this is the public portion of the credential that includes the IAM user name and a suffix containing version and creation information.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the service associated with the service-specific credential.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_specific_credential_idString

The unique identifier for the service-specific credential.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_user_nameString

The generated user name for the service-specific credential.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the service-specific credential. Active means that the key is valid for API calls, while Inactive means it is not.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the IAM user associated with the service-specific credential.



10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/aws-sdk-iam/types.rb', line 10888

class ServiceSpecificCredentialMetadata < Struct.new(
  :user_name,
  :status,
  :service_user_name,
  :service_credential_alias,
  :create_date,
  :expiration_date,
  :service_specific_credential_id,
  :service_name)
  SENSITIVE = []
  include Aws::Structure
end