Class: Aws::IAM::Types::SetDefaultPolicyVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::SetDefaultPolicyVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM policy whose default version you want to set.
-
#version_id ⇒ String
The version of the policy to set as the default (operative) version.
Instance Attribute Details
#policy_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM policy whose default version you want to set.
For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
11108 11109 11110 11111 11112 11113 |
# File 'lib/aws-sdk-iam/types.rb', line 11108 class SetDefaultPolicyVersionRequest < Struct.new( :policy_arn, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version of the policy to set as the default (operative) version.
For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.
11108 11109 11110 11111 11112 11113 |
# File 'lib/aws-sdk-iam/types.rb', line 11108 class SetDefaultPolicyVersionRequest < Struct.new( :policy_arn, :version_id) SENSITIVE = [] include Aws::Structure end |