Class: Aws::IAM::Types::UpdateOpenIDConnectProviderThumbprintRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#open_id_connect_provider_arnString

The Amazon Resource Name (ARN) of the IAM OIDC provider resource object for which you want to update the thumbprint. You can get a list of OIDC provider ARNs by using the ListOpenIDConnectProviders operation.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


13264
13265
13266
13267
13268
13269
# File 'lib/aws-sdk-iam/types.rb', line 13264

class UpdateOpenIDConnectProviderThumbprintRequest < Struct.new(
  :open_id_connect_provider_arn,
  :thumbprint_list)
  SENSITIVE = []
  include Aws::Structure
end

#thumbprint_listArray<String>

A list of certificate thumbprints that are associated with the specified IAM OpenID Connect provider. For more information, see CreateOpenIDConnectProvider.

Returns:

  • (Array<String>)


13264
13265
13266
13267
13268
13269
# File 'lib/aws-sdk-iam/types.rb', line 13264

class UpdateOpenIDConnectProviderThumbprintRequest < Struct.new(
  :open_id_connect_provider_arn,
  :thumbprint_list)
  SENSITIVE = []
  include Aws::Structure
end