Class: Aws::IAM::Types::UpdateSAMLProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:add_private_key]

Instance Attribute Summary collapse

Instance Attribute Details

#add_private_keyString

Specifies the new private key from your external identity provider. The private key must be a .pem file that uses AES-GCM or AES-CBC encryption algorithm to decrypt SAML assertions.

Returns:

  • (String)


12883
12884
12885
12886
12887
12888
12889
12890
12891
# File 'lib/aws-sdk-iam/types.rb', line 12883

class UpdateSAMLProviderRequest < Struct.new(
  :saml_metadata_document,
  :saml_provider_arn,
  :assertion_encryption_mode,
  :add_private_key,
  :remove_private_key)
  SENSITIVE = [:add_private_key]
  include Aws::Structure
end

#assertion_encryption_modeString

Specifies the encryption setting for the SAML provider.

Returns:

  • (String)


12883
12884
12885
12886
12887
12888
12889
12890
12891
# File 'lib/aws-sdk-iam/types.rb', line 12883

class UpdateSAMLProviderRequest < Struct.new(
  :saml_metadata_document,
  :saml_provider_arn,
  :assertion_encryption_mode,
  :add_private_key,
  :remove_private_key)
  SENSITIVE = [:add_private_key]
  include Aws::Structure
end

#remove_private_keyString

The Key ID of the private key to remove.

Returns:

  • (String)


12883
12884
12885
12886
12887
12888
12889
12890
12891
# File 'lib/aws-sdk-iam/types.rb', line 12883

class UpdateSAMLProviderRequest < Struct.new(
  :saml_metadata_document,
  :saml_provider_arn,
  :assertion_encryption_mode,
  :add_private_key,
  :remove_private_key)
  SENSITIVE = [:add_private_key]
  include Aws::Structure
end

#saml_metadata_documentString

An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your IdP.

Returns:

  • (String)


12883
12884
12885
12886
12887
12888
12889
12890
12891
# File 'lib/aws-sdk-iam/types.rb', line 12883

class UpdateSAMLProviderRequest < Struct.new(
  :saml_metadata_document,
  :saml_provider_arn,
  :assertion_encryption_mode,
  :add_private_key,
  :remove_private_key)
  SENSITIVE = [:add_private_key]
  include Aws::Structure
end

#saml_provider_arnString

The Amazon Resource Name (ARN) of the SAML provider to update.

For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

Returns:

  • (String)


12883
12884
12885
12886
12887
12888
12889
12890
12891
# File 'lib/aws-sdk-iam/types.rb', line 12883

class UpdateSAMLProviderRequest < Struct.new(
  :saml_metadata_document,
  :saml_provider_arn,
  :assertion_encryption_mode,
  :add_private_key,
  :remove_private_key)
  SENSITIVE = [:add_private_key]
  include Aws::Structure
end