Class: Aws::IAM::Types::UpdateSAMLProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::UpdateSAMLProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:add_private_key]
Instance Attribute Summary collapse
-
#add_private_key ⇒ String
Specifies the new private key from your external identity provider.
-
#assertion_encryption_mode ⇒ String
Specifies the encryption setting for the SAML provider.
-
#remove_private_key ⇒ String
The Key ID of the private key to remove.
-
#saml_metadata_document ⇒ String
An XML document generated by an identity provider (IdP) that supports SAML 2.0.
-
#saml_provider_arn ⇒ String
The Amazon Resource Name (ARN) of the SAML provider to update.
Instance Attribute Details
#add_private_key ⇒ String
Specifies the new private key from your external identity provider. The private key must be a .pem file that uses AES-GCM or AES-CBC encryption algorithm to decrypt SAML assertions.
12674 12675 12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/aws-sdk-iam/types.rb', line 12674 class UpdateSAMLProviderRequest < Struct.new( :saml_metadata_document, :saml_provider_arn, :assertion_encryption_mode, :add_private_key, :remove_private_key) SENSITIVE = [:add_private_key] include Aws::Structure end |
#assertion_encryption_mode ⇒ String
Specifies the encryption setting for the SAML provider.
12674 12675 12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/aws-sdk-iam/types.rb', line 12674 class UpdateSAMLProviderRequest < Struct.new( :saml_metadata_document, :saml_provider_arn, :assertion_encryption_mode, :add_private_key, :remove_private_key) SENSITIVE = [:add_private_key] include Aws::Structure end |
#remove_private_key ⇒ String
The Key ID of the private key to remove.
12674 12675 12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/aws-sdk-iam/types.rb', line 12674 class UpdateSAMLProviderRequest < Struct.new( :saml_metadata_document, :saml_provider_arn, :assertion_encryption_mode, :add_private_key, :remove_private_key) SENSITIVE = [:add_private_key] include Aws::Structure end |
#saml_metadata_document ⇒ String
An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer’s name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your IdP.
12674 12675 12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/aws-sdk-iam/types.rb', line 12674 class UpdateSAMLProviderRequest < Struct.new( :saml_metadata_document, :saml_provider_arn, :assertion_encryption_mode, :add_private_key, :remove_private_key) SENSITIVE = [:add_private_key] include Aws::Structure end |
#saml_provider_arn ⇒ String
The Amazon Resource Name (ARN) of the SAML provider to update.
For more information about ARNs, see [Amazon Resource Names (ARNs)] in the *Amazon Web Services General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
12674 12675 12676 12677 12678 12679 12680 12681 12682 |
# File 'lib/aws-sdk-iam/types.rb', line 12674 class UpdateSAMLProviderRequest < Struct.new( :saml_metadata_document, :saml_provider_arn, :assertion_encryption_mode, :add_private_key, :remove_private_key) SENSITIVE = [:add_private_key] include Aws::Structure end |