Class: Aws::IAM::Types::UploadServerCertificateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAM::Types::UploadServerCertificateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iam/types.rb
Overview
Contains the response to a successful UploadServerCertificate request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the uploaded server certificate without its certificate body, certificate chain, and private key.
-
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the new IAM server certificate.
Instance Attribute Details
#server_certificate_metadata ⇒ Types::ServerCertificateMetadata
The meta information of the uploaded server certificate without its certificate body, certificate chain, and private key.
13358 13359 13360 13361 13362 13363 |
# File 'lib/aws-sdk-iam/types.rb', line 13358 class UploadServerCertificateResponse < Struct.new( :server_certificate_metadata, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that are attached to the new IAM server certificate. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.
13358 13359 13360 13361 13362 13363 |
# File 'lib/aws-sdk-iam/types.rb', line 13358 class UploadServerCertificateResponse < Struct.new( :server_certificate_metadata, :tags) SENSITIVE = [] include Aws::Structure end |