Class: Aws::IAM::Types::VirtualMFADevice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iam/types.rb

Overview

Contains information about a virtual MFA device.

Constant Summary collapse

SENSITIVE =
[:base_32_string_seed, :qr_code_png]

Instance Attribute Summary collapse

Instance Attribute Details

#base_32_string_seedString

The base32 seed defined as specified in [RFC3548]. The Base32StringSeed is base32-encoded.

[1]: tools.ietf.org/html/rfc3548.txt

Returns:

  • (String)


13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#enable_dateTime

The date and time on which the virtual MFA device was enabled.

Returns:

  • (Time)


13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#qr_code_pngString

A QR code PNG image that encodes ‘otpauth://totp/$virtualMFADeviceName@$AccountName?secret=$Base32String` where `$virtualMFADeviceName` is one of the create call arguments. AccountName is the user name if set (otherwise, the account ID otherwise), and Base32String is the seed in base32 format. The Base32String value is base64-encoded.

Returns:

  • (String)


13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#serial_numberString

The serial number associated with VirtualMFADevice.

Returns:

  • (String)


13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that are attached to the virtual MFA device. For more information about tagging, see [Tagging IAM resources] in the *IAM User Guide*.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html

Returns:



13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end

#userTypes::User

The IAM user associated with this virtual MFA device.

Returns:



13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
# File 'lib/aws-sdk-iam/types.rb', line 13476

class VirtualMFADevice < Struct.new(
  :serial_number,
  :base_32_string_seed,
  :qr_code_png,
  :user,
  :enable_date,
  :tags)
  SENSITIVE = [:base_32_string_seed, :qr_code_png]
  include Aws::Structure
end