Class: Aws::IAM::Waiters::RoleExists
- Inherits:
-
Object
- Object
- Aws::IAM::Waiters::RoleExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-iam/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RoleExists
constructor
A new instance of RoleExists.
-
#wait(params = {}) ⇒ Types::GetRoleResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RoleExists
Returns a new instance of RoleExists.
171 172 |
# File 'lib/aws-sdk-iam/waiters.rb', line 171
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
201 202 203 |
# File 'lib/aws-sdk-iam/waiters.rb', line 201 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRoleResponse
Returns a response object which responds to the following methods:
- #role => Types::Role
196 |
# File 'lib/aws-sdk-iam/waiters.rb', line 196
def wait: (
|